@@ -201,6 +201,14 @@ public class TestCloseableIterable {
     Assertions.assertThat(counter.get()).isEqualTo(items.size());
   }
 
+  @Test
+  public void concatIterablesWithIterator() throws IOException {
+    CloseableIterable<Object> closeableIterable = CloseableIterable.concat(Collections.emptyList());
+    closeableIterable.iterator();
+    // shouldn't throw a NPE
+    closeableIterable.close();
+  }
+
   @Test
   public void count() {
     Counter counter = new DefaultMetricsContext().counter("x");
