@@ -16,23 +16,8 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.transforms;
 
-import org.apache.iceberg.PartitionSpec;
-import org.apache.iceberg.Schema;
-import org.apache.iceberg.TestHelpers.Row;
-import org.apache.iceberg.exceptions.ValidationException;
-import org.apache.iceberg.expressions.Expression;
-import org.apache.iceberg.expressions.Expressions;
-import org.apache.iceberg.expressions.Literal;
-import org.apache.iceberg.expressions.Predicate;
-import org.apache.iceberg.expressions.ResidualEvaluator;
-import org.apache.iceberg.expressions.UnboundPredicate;
-import org.apache.iceberg.types.Types;
-import org.junit.Assert;
-import org.junit.Test;
-
 import static org.apache.iceberg.TestHelpers.assertAndUnwrapUnbound;
 import static org.apache.iceberg.expressions.Expression.Operation.GT;
 import static org.apache.iceberg.expressions.Expression.Operation.LT;
@@ -48,24 +33,40 @@ import static org.apache.iceberg.expressions.Expressions.notIn;
 import static org.apache.iceberg.expressions.Expressions.notNaN;
 import static org.apache.iceberg.expressions.Expressions.or;
 
+import java.util.function.Function;
+import org.apache.iceberg.PartitionSpec;
+import org.apache.iceberg.Schema;
+import org.apache.iceberg.TestHelpers.Row;
+import org.apache.iceberg.exceptions.ValidationException;
+import org.apache.iceberg.expressions.Expression;
+import org.apache.iceberg.expressions.Expressions;
+import org.apache.iceberg.expressions.Literal;
+import org.apache.iceberg.expressions.ResidualEvaluator;
+import org.apache.iceberg.expressions.UnboundPredicate;
+import org.apache.iceberg.types.Types;
+import org.assertj.core.api.Assertions;
+import org.junit.Assert;
+import org.junit.Test;
+
 public class TestResiduals {
   @Test
   public void testIdentityTransformResiduals() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
-        Types.NestedField.optional(51, "hour", Types.IntegerType.get())
-    );
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
+            Types.NestedField.optional(51, "hour", Types.IntegerType.get()));
 
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .identity("dateint")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).identity("dateint").build();
 
-    ResidualEvaluator resEval = ResidualEvaluator.of(spec, or(or(
-        and(lessThan("dateint", 20170815), greaterThan("dateint", 20170801)),
-        and(equal("dateint", 20170815), lessThan("hour", 12))),
-        and(equal("dateint", 20170801), greaterThan("hour", 11))),
-        true
-    );
+    ResidualEvaluator resEval =
+        ResidualEvaluator.of(
+            spec,
+            or(
+                or(
+                    and(lessThan("dateint", 20170815), greaterThan("dateint", 20170801)),
+                    and(equal("dateint", 20170815), lessThan("hour", 12))),
+                and(equal("dateint", 20170801), greaterThan("hour", 11))),
+            true);
 
     // equal to the upper date bound
     Expression residual = resEval.residualFor(Row.of(20170815));
@@ -92,19 +93,22 @@ public class TestResiduals {
 
   @Test
   public void testCaseInsensitiveIdentityTransformResiduals() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
-        Types.NestedField.optional(51, "hour", Types.IntegerType.get()));
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
+            Types.NestedField.optional(51, "hour", Types.IntegerType.get()));
 
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .identity("dateint")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).identity("dateint").build();
 
-    ResidualEvaluator resEval = ResidualEvaluator.of(spec, or(or(
-        and(lessThan("DATEINT", 20170815), greaterThan("dateint", 20170801)),
-        and(equal("dateint", 20170815), lessThan("HOUR", 12))),
-        and(equal("DateInt", 20170801), greaterThan("hOUr", 11))),
-        false);
+    ResidualEvaluator resEval =
+        ResidualEvaluator.of(
+            spec,
+            or(
+                or(
+                    and(lessThan("DATEINT", 20170815), greaterThan("dateint", 20170801)),
+                    and(equal("dateint", 20170815), lessThan("HOUR", 12))),
+                and(equal("DateInt", 20170801), greaterThan("hOUr", 11))),
+            false);
 
     // equal to the upper date bound
     Expression residual = resEval.residualFor(Row.of(20170815));
@@ -129,59 +133,59 @@ public class TestResiduals {
     Assert.assertEquals("Residual should be alwaysFalse", alwaysFalse(), residual);
   }
 
-  @Test(expected = ValidationException.class)
+  @Test
   public void testCaseSensitiveIdentityTransformResiduals() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
-        Types.NestedField.optional(51, "hour", Types.IntegerType.get())
-    );
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
+            Types.NestedField.optional(51, "hour", Types.IntegerType.get()));
 
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .identity("dateint")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).identity("dateint").build();
 
     ResidualEvaluator resEval = ResidualEvaluator.of(spec, lessThan("DATEINT", 20170815), true);
 
-    resEval.residualFor(Row.of(20170815));
+    Assertions.assertThatThrownBy(() -> resEval.residualFor(Row.of(20170815)))
+        .isInstanceOf(ValidationException.class)
+        .hasMessageContaining("Cannot find field 'DATEINT' in struct");
   }
 
   @Test
   public void testUnpartitionedResiduals() {
-    Expression[] expressions = new Expression[] {
-        Expressions.alwaysTrue(),
-        Expressions.alwaysFalse(),
-        Expressions.lessThan("a", 5),
-        Expressions.greaterThanOrEqual("b", 16),
-        Expressions.notNull("c"),
-        Expressions.isNull("d"),
-        Expressions.in("e", 1, 2, 3),
-        Expressions.notIn("f", 1, 2, 3),
-        Expressions.notNaN("g"),
-        Expressions.isNaN("h"),
-        Expressions.startsWith("data", "abcd"),
-        Expressions.notStartsWith("data", "abcd")
-    };
+    Expression[] expressions =
+        new Expression[] {
+          Expressions.alwaysTrue(),
+          Expressions.alwaysFalse(),
+          Expressions.lessThan("a", 5),
+          Expressions.greaterThanOrEqual("b", 16),
+          Expressions.notNull("c"),
+          Expressions.isNull("d"),
+          Expressions.in("e", 1, 2, 3),
+          Expressions.notIn("f", 1, 2, 3),
+          Expressions.notNaN("g"),
+          Expressions.isNaN("h"),
+          Expressions.startsWith("data", "abcd"),
+          Expressions.notStartsWith("data", "abcd")
+        };
 
     for (Expression expr : expressions) {
-      ResidualEvaluator residualEvaluator = ResidualEvaluator.of(PartitionSpec.unpartitioned(), expr, true);
-      Assert.assertEquals("Should return expression",
-          expr, residualEvaluator.residualFor(Row.of()));
+      ResidualEvaluator residualEvaluator =
+          ResidualEvaluator.of(PartitionSpec.unpartitioned(), expr, true);
+      Assert.assertEquals(
+          "Should return expression", expr, residualEvaluator.residualFor(Row.of()));
     }
   }
 
   @Test
   public void testIn() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
-        Types.NestedField.optional(51, "hour", Types.IntegerType.get())
-    );
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
+            Types.NestedField.optional(51, "hour", Types.IntegerType.get()));
 
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .identity("dateint")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).identity("dateint").build();
 
-    ResidualEvaluator resEval = ResidualEvaluator.of(spec,
-        in("dateint", 20170815, 20170816, 20170817), true);
+    ResidualEvaluator resEval =
+        ResidualEvaluator.of(spec, in("dateint", 20170815, 20170816, 20170817), true);
 
     Expression residual = resEval.residualFor(Row.of(20170815));
     Assert.assertEquals("Residual should be alwaysTrue", alwaysTrue(), residual);
@@ -192,26 +196,25 @@ public class TestResiduals {
 
   @Test
   public void testInTimestamp() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "ts", Types.TimestampType.withoutZone()),
-        Types.NestedField.optional(51, "dateint", Types.IntegerType.get())
-    );
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "ts", Types.TimestampType.withoutZone()),
+            Types.NestedField.optional(51, "dateint", Types.IntegerType.get()));
 
-    Long date20191201 = (Long) Literal.of("2019-12-01T00:00:00.00000")
-        .to(Types.TimestampType.withoutZone()).value();
-    Long date20191202 = (Long) Literal.of("2019-12-02T00:00:00.00000")
-        .to(Types.TimestampType.withoutZone()).value();
+    Long date20191201 =
+        (Long)
+            Literal.of("2019-12-01T00:00:00.00000").to(Types.TimestampType.withoutZone()).value();
+    Long date20191202 =
+        (Long)
+            Literal.of("2019-12-02T00:00:00.00000").to(Types.TimestampType.withoutZone()).value();
 
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .day("ts")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).day("ts").build();
 
-    Transform day = spec.getFieldsBySourceId(50).get(0).transform();
-    Integer tsDay = (Integer) day.apply(date20191201);
+    Function<Object, Integer> day = Transforms.day().bind(Types.TimestampType.withoutZone());
+    Integer tsDay = day.apply(date20191201);
 
-    Predicate pred = in("ts", date20191201, date20191202);
-    ResidualEvaluator resEval = ResidualEvaluator.of(spec,
-        pred, true);
+    Expression pred = in("ts", date20191201, date20191202);
+    ResidualEvaluator resEval = ResidualEvaluator.of(spec, pred, true);
 
     Expression residual = resEval.residualFor(Row.of(tsDay));
     Assert.assertEquals("Residual should be the original in predicate", pred, residual);
@@ -222,17 +225,15 @@ public class TestResiduals {
 
   @Test
   public void testNotIn() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
-        Types.NestedField.optional(51, "hour", Types.IntegerType.get())
-    );
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "dateint", Types.IntegerType.get()),
+            Types.NestedField.optional(51, "hour", Types.IntegerType.get()));
 
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .identity("dateint")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).identity("dateint").build();
 
-    ResidualEvaluator resEval = ResidualEvaluator.of(spec,
-        notIn("dateint", 20170815, 20170816, 20170817), true);
+    ResidualEvaluator resEval =
+        ResidualEvaluator.of(spec, notIn("dateint", 20170815, 20170816, 20170817), true);
 
     Expression residual = resEval.residualFor(Row.of(20180815));
     Assert.assertEquals("Residual should be alwaysTrue", alwaysTrue(), residual);
@@ -243,18 +244,15 @@ public class TestResiduals {
 
   @Test
   public void testIsNaN() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "double", Types.DoubleType.get()),
-        Types.NestedField.optional(51, "float", Types.FloatType.get())
-    );
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "double", Types.DoubleType.get()),
+            Types.NestedField.optional(51, "float", Types.FloatType.get()));
 
     // test double field
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .identity("double")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).identity("double").build();
 
-    ResidualEvaluator resEval = ResidualEvaluator.of(spec,
-        isNaN("double"), true);
+    ResidualEvaluator resEval = ResidualEvaluator.of(spec, isNaN("double"), true);
 
     Expression residual = resEval.residualFor(Row.of(Double.NaN));
     Assert.assertEquals("Residual should be alwaysTrue", alwaysTrue(), residual);
@@ -263,12 +261,9 @@ public class TestResiduals {
     Assert.assertEquals("Residual should be alwaysFalse", alwaysFalse(), residual);
 
     // test float field
-    spec = PartitionSpec.builderFor(schema)
-        .identity("float")
-        .build();
+    spec = PartitionSpec.builderFor(schema).identity("float").build();
 
-    resEval = ResidualEvaluator.of(spec,
-        isNaN("float"), true);
+    resEval = ResidualEvaluator.of(spec, isNaN("float"), true);
 
     residual = resEval.residualFor(Row.of(Float.NaN));
     Assert.assertEquals("Residual should be alwaysTrue", alwaysTrue(), residual);
@@ -279,18 +274,15 @@ public class TestResiduals {
 
   @Test
   public void testNotNaN() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "double", Types.DoubleType.get()),
-        Types.NestedField.optional(51, "float", Types.FloatType.get())
-    );
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "double", Types.DoubleType.get()),
+            Types.NestedField.optional(51, "float", Types.FloatType.get()));
 
     // test double field
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .identity("double")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).identity("double").build();
 
-    ResidualEvaluator resEval = ResidualEvaluator.of(spec,
-        notNaN("double"), true);
+    ResidualEvaluator resEval = ResidualEvaluator.of(spec, notNaN("double"), true);
 
     Expression residual = resEval.residualFor(Row.of(Double.NaN));
     Assert.assertEquals("Residual should be alwaysFalse", alwaysFalse(), residual);
@@ -299,12 +291,9 @@ public class TestResiduals {
     Assert.assertEquals("Residual should be alwaysTrue", alwaysTrue(), residual);
 
     // test float field
-    spec = PartitionSpec.builderFor(schema)
-        .identity("float")
-        .build();
+    spec = PartitionSpec.builderFor(schema).identity("float").build();
 
-    resEval = ResidualEvaluator.of(spec,
-        notNaN("float"), true);
+    resEval = ResidualEvaluator.of(spec, notNaN("float"), true);
 
     residual = resEval.residualFor(Row.of(Float.NaN));
     Assert.assertEquals("Residual should be alwaysFalse", alwaysFalse(), residual);
@@ -315,26 +304,25 @@ public class TestResiduals {
 
   @Test
   public void testNotInTimestamp() {
-    Schema schema = new Schema(
-        Types.NestedField.optional(50, "ts", Types.TimestampType.withoutZone()),
-        Types.NestedField.optional(51, "dateint", Types.IntegerType.get())
-    );
+    Schema schema =
+        new Schema(
+            Types.NestedField.optional(50, "ts", Types.TimestampType.withoutZone()),
+            Types.NestedField.optional(51, "dateint", Types.IntegerType.get()));
 
-    Long date20191201 = (Long) Literal.of("2019-12-01T00:00:00.00000")
-        .to(Types.TimestampType.withoutZone()).value();
-    Long date20191202 = (Long) Literal.of("2019-12-02T00:00:00.00000")
-        .to(Types.TimestampType.withoutZone()).value();
+    Long date20191201 =
+        (Long)
+            Literal.of("2019-12-01T00:00:00.00000").to(Types.TimestampType.withoutZone()).value();
+    Long date20191202 =
+        (Long)
+            Literal.of("2019-12-02T00:00:00.00000").to(Types.TimestampType.withoutZone()).value();
 
-    PartitionSpec spec = PartitionSpec.builderFor(schema)
-        .day("ts")
-        .build();
+    PartitionSpec spec = PartitionSpec.builderFor(schema).day("ts").build();
 
-    Transform day = spec.getFieldsBySourceId(50).get(0).transform();
-    Integer tsDay = (Integer) day.apply(date20191201);
+    Function<Object, Integer> day = Transforms.day().bind(Types.TimestampType.withoutZone());
+    Integer tsDay = day.apply(date20191201);
 
-    Predicate pred = notIn("ts", date20191201, date20191202);
-    ResidualEvaluator resEval = ResidualEvaluator.of(spec,
-        pred, true);
+    Expression pred = notIn("ts", date20191201, date20191202);
+    ResidualEvaluator resEval = ResidualEvaluator.of(spec, pred, true);
 
     Expression residual = resEval.residualFor(Row.of(tsDay));
     Assert.assertEquals("Residual should be the original notIn predicate", pred, residual);
