@@ -16,20 +16,36 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.transforms;
 
 import java.math.BigDecimal;
 import java.nio.ByteBuffer;
+import java.nio.charset.StandardCharsets;
+import java.util.function.Function;
 import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.types.Types;
 import org.junit.Assert;
 import org.junit.Test;
 
 public class TestTruncate {
+  @Test
+  public void testDeprecatedTruncateInteger() {
+    Truncate<Object> trunc = Truncate.get(Types.IntegerType.get(), 10);
+    Assert.assertEquals(0, (int) trunc.apply(0));
+    Assert.assertEquals(0, (int) trunc.apply(1));
+    Assert.assertEquals(0, (int) trunc.apply(5));
+    Assert.assertEquals(0, (int) trunc.apply(9));
+    Assert.assertEquals(10, (int) trunc.apply(10));
+    Assert.assertEquals(10, (int) trunc.apply(11));
+    Assert.assertEquals(-10, (int) trunc.apply(-1));
+    Assert.assertEquals(-10, (int) trunc.apply(-5));
+    Assert.assertEquals(-10, (int) trunc.apply(-10));
+    Assert.assertEquals(-20, (int) trunc.apply(-11));
+  }
+
   @Test
   public void testTruncateInteger() {
-    Truncate<Integer> trunc = Truncate.get(Types.IntegerType.get(), 10);
+    Function<Object, Object> trunc = Truncate.get(10).bind(Types.IntegerType.get());
     Assert.assertEquals(0, (int) trunc.apply(0));
     Assert.assertEquals(0, (int) trunc.apply(1));
     Assert.assertEquals(0, (int) trunc.apply(5));
@@ -44,7 +60,7 @@ public class TestTruncate {
 
   @Test
   public void testTruncateLong() {
-    Truncate<Long> trunc = Truncate.get(Types.LongType.get(), 10);
+    Function<Object, Object> trunc = Truncate.get(10).bind(Types.LongType.get());
     Assert.assertEquals(0L, (long) trunc.apply(0L));
     Assert.assertEquals(0L, (long) trunc.apply(1L));
     Assert.assertEquals(0L, (long) trunc.apply(5L));
@@ -60,7 +76,7 @@ public class TestTruncate {
   @Test
   public void testTruncateDecimal() {
     // decimal truncation works by applying the decimal scale to the width: 10 scale 2 = 0.10
-    Truncate<BigDecimal> trunc = Truncate.get(Types.DecimalType.of(9, 2), 10);
+    Function<Object, Object> trunc = Truncate.get(10).bind(Types.DecimalType.of(9, 2));
     Assert.assertEquals(new BigDecimal("12.30"), trunc.apply(new BigDecimal("12.34")));
     Assert.assertEquals(new BigDecimal("12.30"), trunc.apply(new BigDecimal("12.30")));
     Assert.assertEquals(new BigDecimal("12.20"), trunc.apply(new BigDecimal("12.29")));
@@ -70,31 +86,32 @@ public class TestTruncate {
 
   @Test
   public void testTruncateString() {
-    Truncate<String> trunc = Truncate.get(Types.StringType.get(), 5);
-    Assert.assertEquals("Should truncate strings longer than length",
-        "abcde", trunc.apply("abcdefg"));
-    Assert.assertEquals("Should not pad strings shorter than length",
-        "abc", trunc.apply("abc"));
-    Assert.assertEquals("Should not alter strings equal to length",
-        "abcde", trunc.apply("abcde"));
+    Function<Object, Object> trunc = Truncate.get(5).bind(Types.StringType.get());
+    Assert.assertEquals(
+        "Should truncate strings longer than length", "abcde", trunc.apply("abcdefg"));
+    Assert.assertEquals("Should not pad strings shorter than length", "abc", trunc.apply("abc"));
+    Assert.assertEquals("Should not alter strings equal to length", "abcde", trunc.apply("abcde"));
   }
 
   @Test
-  public void testTruncateByteBuffer() throws Exception {
-    Truncate<ByteBuffer> trunc = Truncate.get(Types.BinaryType.get(), 4);
-    Assert.assertEquals("Should truncate binary longer than length",
-        ByteBuffer.wrap("abcd".getBytes("UTF-8")),
-        trunc.apply(ByteBuffer.wrap("abcdefg".getBytes("UTF-8"))));
-    Assert.assertEquals("Should not pad binary shorter than length",
-        ByteBuffer.wrap("abc".getBytes("UTF-8")),
-        trunc.apply(ByteBuffer.wrap("abc".getBytes("UTF-8"))));
+  public void testTruncateByteBuffer() {
+    Function<Object, Object> trunc = Truncate.get(4).bind(Types.BinaryType.get());
+    Assert.assertEquals(
+        "Should truncate binary longer than length",
+        ByteBuffer.wrap("abcd".getBytes(StandardCharsets.UTF_8)),
+        trunc.apply(ByteBuffer.wrap("abcdefg".getBytes(StandardCharsets.UTF_8))));
+    Assert.assertEquals(
+        "Should not pad binary shorter than length",
+        ByteBuffer.wrap("abc".getBytes(StandardCharsets.UTF_8)),
+        trunc.apply(ByteBuffer.wrap("abc".getBytes(StandardCharsets.UTF_8))));
   }
 
   @Test
   public void testVerifiedIllegalWidth() {
-    AssertHelpers.assertThrows("Should fail if width is less than or equal to zero",
+    AssertHelpers.assertThrows(
+        "Should fail if width is less than or equal to zero",
         IllegalArgumentException.class,
         "Invalid truncate width: 0 (must be > 0)",
-        () -> Truncate.get(Types.IntegerType.get(), 0));
+        () -> Truncate.get(0));
   }
 }
