@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.aws;
 
 import java.util.List;
@@ -42,11 +41,11 @@ public class AwsIntegTestUtil {
 
   private static final Logger LOG = LoggerFactory.getLogger(AwsIntegTestUtil.class);
 
-  private AwsIntegTestUtil() {
-  }
+  private AwsIntegTestUtil() {}
 
   /**
    * Get the environment variable AWS_REGION to use for testing
+   *
    * @return region
    */
   public static String testRegion() {
@@ -55,17 +54,20 @@ public class AwsIntegTestUtil {
 
   /**
    * Get the environment variable AWS_CROSS_REGION to use for testing
+   *
    * @return region
    */
   public static String testCrossRegion() {
     String crossRegion = System.getenv("AWS_CROSS_REGION");
-    Preconditions.checkArgument(!testRegion().equals(crossRegion), "AWS_REGION should not be equal to " +
-        "AWS_CROSS_REGION");
+    Preconditions.checkArgument(
+        !testRegion().equals(crossRegion),
+        "AWS_REGION should not be equal to " + "AWS_CROSS_REGION");
     return crossRegion;
   }
 
   /**
    * Set the environment variable AWS_TEST_BUCKET for a default bucket to use for testing
+   *
    * @return bucket name
    */
   public static String testBucketName() {
@@ -73,7 +75,9 @@ public class AwsIntegTestUtil {
   }
 
   /**
-   * Set the environment variable AWS_TEST_CROSS_REGION_BUCKET for a default bucket to use for testing
+   * Set the environment variable AWS_TEST_CROSS_REGION_BUCKET for a default bucket to use for
+   * testing
+   *
    * @return bucket name
    */
   public static String testCrossRegionBucketName() {
@@ -82,6 +86,7 @@ public class AwsIntegTestUtil {
 
   /**
    * Set the environment variable AWS_TEST_ACCOUNT_ID for a default account to use for testing
+   *
    * @return account id
    */
   public static String testAccountId() {
@@ -91,15 +96,22 @@ public class AwsIntegTestUtil {
   public static void cleanS3Bucket(S3Client s3, String bucketName, String prefix) {
     boolean hasContent = true;
     while (hasContent) {
-      ListObjectsV2Response response = s3.listObjectsV2(ListObjectsV2Request.builder()
-          .bucket(bucketName).prefix(prefix).build());
+      ListObjectsV2Response response =
+          s3.listObjectsV2(
+              ListObjectsV2Request.builder().bucket(bucketName).prefix(prefix).build());
       hasContent = response.hasContents();
       if (hasContent) {
-        s3.deleteObjects(DeleteObjectsRequest.builder().bucket(bucketName).delete(Delete.builder().objects(
-            response.contents().stream()
-                .map(obj -> ObjectIdentifier.builder().key(obj.key()).build())
-                .collect(Collectors.toList())
-        ).build()).build());
+        s3.deleteObjects(
+            DeleteObjectsRequest.builder()
+                .bucket(bucketName)
+                .delete(
+                    Delete.builder()
+                        .objects(
+                            response.contents().stream()
+                                .map(obj -> ObjectIdentifier.builder().key(obj.key()).build())
+                                .collect(Collectors.toList()))
+                        .build())
+                .build());
       }
     }
   }
@@ -122,15 +134,15 @@ public class AwsIntegTestUtil {
         .build();
   }
 
-  public static void createAccessPoint(S3ControlClient s3ControlClient, String accessPointName, String bucketName) {
+  public static void createAccessPoint(
+      S3ControlClient s3ControlClient, String accessPointName, String bucketName) {
     try {
-      s3ControlClient.createAccessPoint(CreateAccessPointRequest
-          .builder()
-          .name(accessPointName)
-          .bucket(bucketName)
-          .accountId(testAccountId())
-          .build()
-      );
+      s3ControlClient.createAccessPoint(
+          CreateAccessPointRequest.builder()
+              .name(accessPointName)
+              .bucket(bucketName)
+              .accountId(testAccountId())
+              .build());
     } catch (Exception e) {
       LOG.error("Cannot create access point {}", accessPointName, e);
     }
@@ -138,12 +150,11 @@ public class AwsIntegTestUtil {
 
   public static void deleteAccessPoint(S3ControlClient s3ControlClient, String accessPointName) {
     try {
-      s3ControlClient.deleteAccessPoint(DeleteAccessPointRequest
-          .builder()
-          .name(accessPointName)
-          .accountId(testAccountId())
-          .build()
-      );
+      s3ControlClient.deleteAccessPoint(
+          DeleteAccessPointRequest.builder()
+              .name(accessPointName)
+              .accountId(testAccountId())
+              .build());
     } catch (Exception e) {
       LOG.error("Cannot delete access point {}", accessPointName, e);
     }
