@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.aws;
 
 import java.util.Map;
@@ -25,19 +24,35 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.junit.Test;
 import software.amazon.awssdk.core.exception.SdkClientException;
 import software.amazon.awssdk.services.dynamodb.DynamoDbClient;
+import software.amazon.awssdk.services.glue.GlueClient;
+import software.amazon.awssdk.services.glue.model.GetDatabaseRequest;
 import software.amazon.awssdk.services.s3.S3Client;
 import software.amazon.awssdk.services.s3.model.GetObjectRequest;
 import software.amazon.awssdk.services.s3.model.S3Exception;
 
 public class TestDefaultAwsClientFactory {
 
+  @Test
+  public void testGlueEndpointOverride() {
+    Map<String, String> properties = Maps.newHashMap();
+    properties.put(AwsProperties.GLUE_CATALOG_ENDPOINT, "https://unknown:1234");
+    AwsClientFactory factory = AwsClientFactories.from(properties);
+    GlueClient glueClient = factory.glue();
+    AssertHelpers.assertThrowsCause(
+        "Should refuse connection to unknown endpoint",
+        SdkClientException.class,
+        "Unable to execute HTTP request: unknown",
+        () -> glueClient.getDatabase(GetDatabaseRequest.builder().name("TEST").build()));
+  }
+
   @Test
   public void testS3FileIoEndpointOverride() {
     Map<String, String> properties = Maps.newHashMap();
     properties.put(AwsProperties.S3FILEIO_ENDPOINT, "https://unknown:1234");
     AwsClientFactory factory = AwsClientFactories.from(properties);
     S3Client s3Client = factory.s3();
-    AssertHelpers.assertThrowsCause("Should refuse connection to unknown endpoint",
+    AssertHelpers.assertThrowsCause(
+        "Should refuse connection to unknown endpoint",
         SdkClientException.class,
         "Unable to execute HTTP request: unknown",
         () -> s3Client.getObject(GetObjectRequest.builder().bucket("bucket").key("key").build()));
@@ -50,10 +65,16 @@ public class TestDefaultAwsClientFactory {
     properties.put(AwsProperties.S3FILEIO_SECRET_ACCESS_KEY, "unknown");
     AwsClientFactory factory = AwsClientFactories.from(properties);
     S3Client s3Client = factory.s3();
-    AssertHelpers.assertThrows("Should fail request because of bad access key",
+    AssertHelpers.assertThrows(
+        "Should fail request because of bad access key",
         S3Exception.class,
         "The AWS Access Key Id you provided does not exist in our records",
-        () -> s3Client.getObject(GetObjectRequest.builder().bucket("bucket").key("key").build()));
+        () ->
+            s3Client.getObject(
+                GetObjectRequest.builder()
+                    .bucket(AwsIntegTestUtil.testBucketName())
+                    .key("key")
+                    .build()));
   }
 
   @Test
@@ -62,7 +83,8 @@ public class TestDefaultAwsClientFactory {
     properties.put(AwsProperties.DYNAMODB_ENDPOINT, "https://unknown:1234");
     AwsClientFactory factory = AwsClientFactories.from(properties);
     DynamoDbClient dynamoDbClient = factory.dynamo();
-    AssertHelpers.assertThrowsCause("Should refuse connection to unknown endpoint",
+    AssertHelpers.assertThrowsCause(
+        "Should refuse connection to unknown endpoint",
         SdkClientException.class,
         "Unable to execute HTTP request: unknown",
         dynamoDbClient::listTables);
