@@ -16,14 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.aws.s3;
 
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.stream.Collectors;
 import org.apache.iceberg.aws.AwsClientFactories;
@@ -67,14 +68,16 @@ import software.amazon.awssdk.services.s3.model.Tagging;
 
 /**
  * FileIO implementation backed by S3.
- * <p>
- * Locations used must follow the conventions for S3 URIs (e.g. s3://bucket/path...).
- * URIs with schemes s3a, s3n, https are also treated as s3 file paths.
- * Using this FileIO with other schemes will result in {@link org.apache.iceberg.exceptions.ValidationException}.
+ *
+ * <p>Locations used must follow the conventions for S3 URIs (e.g. s3://bucket/path...). URIs with
+ * schemes s3a, s3n, https are also treated as s3 file paths. Using this FileIO with other schemes
+ * will result in {@link org.apache.iceberg.exceptions.ValidationException}.
  */
-public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixOperations, CredentialSupplier {
+public class S3FileIO
+    implements FileIO, SupportsBulkOperations, SupportsPrefixOperations, CredentialSupplier {
   private static final Logger LOG = LoggerFactory.getLogger(S3FileIO.class);
-  private static final String DEFAULT_METRICS_IMPL = "org.apache.iceberg.hadoop.HadoopMetricsContext";
+  private static final String DEFAULT_METRICS_IMPL =
+      "org.apache.iceberg.hadoop.HadoopMetricsContext";
   private static volatile ExecutorService executorService;
 
   private String credential = null;
@@ -87,16 +90,16 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
 
   /**
    * No-arg constructor to load the FileIO dynamically.
-   * <p>
-   * All fields are initialized by calling {@link S3FileIO#initialize(Map)} later.
+   *
+   * <p>All fields are initialized by calling {@link S3FileIO#initialize(Map)} later.
    */
-  public S3FileIO() {
-  }
+  public S3FileIO() {}
 
   /**
    * Constructor with custom s3 supplier and default AWS properties.
-   * <p>
-   * Calling {@link S3FileIO#initialize(Map)} will overwrite information set in this constructor.
+   *
+   * <p>Calling {@link S3FileIO#initialize(Map)} will overwrite information set in this constructor.
+   *
    * @param s3 s3 supplier
    */
   public S3FileIO(SerializableSupplier<S3Client> s3) {
@@ -105,8 +108,9 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
 
   /**
    * Constructor with custom s3 supplier and AWS properties.
-   * <p>
-   * Calling {@link S3FileIO#initialize(Map)} will overwrite information set in this constructor.
+   *
+   * <p>Calling {@link S3FileIO#initialize(Map)} will overwrite information set in this constructor.
+   *
    * @param s3 s3 supplier
    * @param awsProperties aws properties
    */
@@ -158,9 +162,9 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
 
   /**
    * Deletes the given paths in a batched manner.
-   * <p>
-   * The paths are grouped by bucket, and deletion is triggered when we either reach the configured batch size
-   * or have a final remainder batch for each bucket.
+   *
+   * <p>The paths are grouped by bucket, and deletion is triggered when we either reach the
+   * configured batch size or have a final remainder batch for each bucket.
    *
    * @param paths paths to delete
    */
@@ -171,42 +175,63 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
           .noRetry()
           .executeWith(executorService())
           .suppressFailureWhenFinished()
-          .onFailure((path, exc) -> LOG.warn("Failed to add delete tags: {} to {}",
-              awsProperties.s3DeleteTags(), path, exc))
+          .onFailure(
+              (path, exc) ->
+                  LOG.warn(
+                      "Failed to add delete tags: {} to {}",
+                      awsProperties.s3DeleteTags(),
+                      path,
+                      exc))
           .run(path -> tagFileToDelete(path, awsProperties.s3DeleteTags()));
     }
 
-    if (!awsProperties.isS3DeleteEnabled()) {
-      return;
-    }
-
-    SetMultimap<String, String> bucketToObjects = Multimaps.newSetMultimap(Maps.newHashMap(), Sets::newHashSet);
-    int numberOfFailedDeletions = 0;
-    for (String path : paths) {
-      S3URI location = new S3URI(path, awsProperties.s3BucketToAccessPointMapping());
-      String bucket = location.bucket();
-      String objectKey = location.key();
-      Set<String> objectsInBucket = bucketToObjects.get(bucket);
-      if (objectsInBucket.size() == awsProperties.s3FileIoDeleteBatchSize()) {
-        List<String> failedDeletionsForBatch = deleteObjectsInBucket(bucket, objectsInBucket);
-        numberOfFailedDeletions += failedDeletionsForBatch.size();
-        failedDeletionsForBatch.forEach(failedPath -> LOG.warn("Failed to delete object at path {}", failedPath));
-        bucketToObjects.removeAll(bucket);
+    if (awsProperties.isS3DeleteEnabled()) {
+      SetMultimap<String, String> bucketToObjects =
+          Multimaps.newSetMultimap(Maps.newHashMap(), Sets::newHashSet);
+      List<Future<List<String>>> deletionTasks = Lists.newArrayList();
+      for (String path : paths) {
+        S3URI location = new S3URI(path, awsProperties.s3BucketToAccessPointMapping());
+        String bucket = location.bucket();
+        String objectKey = location.key();
+        bucketToObjects.get(bucket).add(objectKey);
+        if (bucketToObjects.get(bucket).size() == awsProperties.s3FileIoDeleteBatchSize()) {
+          Set<String> keys = Sets.newHashSet(bucketToObjects.get(bucket));
+          Future<List<String>> deletionTask =
+              executorService().submit(() -> deleteBatch(bucket, keys));
+          deletionTasks.add(deletionTask);
+          bucketToObjects.removeAll(bucket);
+        }
       }
-      bucketToObjects.get(bucket).add(objectKey);
-    }
 
-    // Delete the remainder
-    for (Map.Entry<String, Collection<String>> bucketToObjectsEntry : bucketToObjects.asMap().entrySet()) {
-      final String bucket = bucketToObjectsEntry.getKey();
-      final Collection<String> objects = bucketToObjectsEntry.getValue();
-      List<String> failedDeletions = deleteObjectsInBucket(bucket, objects);
-      failedDeletions.forEach(failedPath -> LOG.warn("Failed to delete object at path {}", failedPath));
-      numberOfFailedDeletions += failedDeletions.size();
-    }
+      // Delete the remainder
+      for (Map.Entry<String, Collection<String>> bucketToObjectsEntry :
+          bucketToObjects.asMap().entrySet()) {
+        String bucket = bucketToObjectsEntry.getKey();
+        Collection<String> keys = bucketToObjectsEntry.getValue();
+        Future<List<String>> deletionTask =
+            executorService().submit(() -> deleteBatch(bucket, keys));
+        deletionTasks.add(deletionTask);
+      }
 
-    if (numberOfFailedDeletions > 0) {
-      throw new BulkDeletionFailureException(numberOfFailedDeletions);
+      int totalFailedDeletions = 0;
+
+      for (Future<List<String>> deletionTask : deletionTasks) {
+        try {
+          List<String> failedDeletions = deletionTask.get();
+          failedDeletions.forEach(path -> LOG.warn("Failed to delete object at path {}", path));
+          totalFailedDeletions += failedDeletions.size();
+        } catch (ExecutionException e) {
+          LOG.warn("Caught unexpected exception during batch deletion: ", e.getCause());
+        } catch (InterruptedException e) {
+          Thread.currentThread().interrupt();
+          deletionTasks.stream().filter(task -> !task.isDone()).forEach(task -> task.cancel(true));
+          throw new RuntimeException("Interrupted when waiting for deletions to complete", e);
+        }
+      }
+
+      if (totalFailedDeletions > 0) {
+        throw new BulkDeletionFailureException(totalFailedDeletions);
+      }
     }
   }
 
@@ -214,12 +239,10 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
     S3URI location = new S3URI(path, awsProperties.s3BucketToAccessPointMapping());
     String bucket = location.bucket();
     String objectKey = location.key();
-    GetObjectTaggingRequest getObjectTaggingRequest = GetObjectTaggingRequest.builder()
-        .bucket(bucket)
-        .key(objectKey)
-        .build();
-    GetObjectTaggingResponse getObjectTaggingResponse = client()
-        .getObjectTagging(getObjectTaggingRequest);
+    GetObjectTaggingRequest getObjectTaggingRequest =
+        GetObjectTaggingRequest.builder().bucket(bucket).key(objectKey).build();
+    GetObjectTaggingResponse getObjectTaggingResponse =
+        client().getObjectTagging(getObjectTaggingRequest);
     // Get existing tags, if any and then add the delete tags
     Set<Tag> tags = Sets.newHashSet();
     if (getObjectTaggingResponse.hasTagSet()) {
@@ -227,55 +250,67 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
     }
 
     tags.addAll(deleteTags);
-    PutObjectTaggingRequest putObjectTaggingRequest = PutObjectTaggingRequest.builder()
-        .bucket(bucket)
-        .key(objectKey)
-        .tagging(Tagging.builder().tagSet(tags).build())
-        .build();
+    PutObjectTaggingRequest putObjectTaggingRequest =
+        PutObjectTaggingRequest.builder()
+            .bucket(bucket)
+            .key(objectKey)
+            .tagging(Tagging.builder().tagSet(tags).build())
+            .build();
     client().putObjectTagging(putObjectTaggingRequest);
   }
 
-  private List<String> deleteObjectsInBucket(String bucket, Collection<String> objects) {
-    if (!objects.isEmpty()) {
-      List<ObjectIdentifier> objectIds = objects
-          .stream()
-          .map(objectKey -> ObjectIdentifier.builder().key(objectKey).build())
-          .collect(Collectors.toList());
-      DeleteObjectsRequest deleteObjectsRequest = DeleteObjectsRequest.builder()
-          .bucket(bucket)
-          .delete(Delete.builder().objects(objectIds).build())
-          .build();
-      DeleteObjectsResponse response = client().deleteObjects(deleteObjectsRequest);
-      if (response.hasErrors()) {
-        return response.errors()
-            .stream()
-            .map(error -> String.format("s3://%s/%s", bucket, error.key()))
+  private List<String> deleteBatch(String bucket, Collection<String> keysToDelete) {
+    List<ObjectIdentifier> objectIds =
+        keysToDelete.stream()
+            .map(key -> ObjectIdentifier.builder().key(key).build())
             .collect(Collectors.toList());
+    DeleteObjectsRequest request =
+        DeleteObjectsRequest.builder()
+            .bucket(bucket)
+            .delete(Delete.builder().objects(objectIds).build())
+            .build();
+    List<String> failures = Lists.newArrayList();
+    try {
+      DeleteObjectsResponse response = client().deleteObjects(request);
+      if (response.hasErrors()) {
+        failures.addAll(
+            response.errors().stream()
+                .map(error -> String.format("s3://%s/%s", request.bucket(), error.key()))
+                .collect(Collectors.toList()));
       }
+    } catch (Exception e) {
+      LOG.warn("Encountered failure when deleting batch", e);
+      failures.addAll(
+          request.delete().objects().stream()
+              .map(obj -> String.format("s3://%s/%s", request.bucket(), obj.key()))
+              .collect(Collectors.toList()));
     }
-
-    return Lists.newArrayList();
+    return failures;
   }
 
   @Override
   public Iterable<FileInfo> listPrefix(String prefix) {
     S3URI s3uri = new S3URI(prefix, awsProperties.s3BucketToAccessPointMapping());
-    ListObjectsV2Request request = ListObjectsV2Request.builder().bucket(s3uri.bucket()).prefix(s3uri.key()).build();
+    ListObjectsV2Request request =
+        ListObjectsV2Request.builder().bucket(s3uri.bucket()).prefix(s3uri.key()).build();
 
-    return () -> client().listObjectsV2Paginator(request).stream()
-        .flatMap(r -> r.contents().stream())
-        .map(o -> new FileInfo(
-            String.format("%s://%s/%s", s3uri.scheme(), s3uri.bucket(), o.key()),
-            o.size(), o.lastModified().toEpochMilli())).iterator();
+    return () ->
+        client().listObjectsV2Paginator(request).stream()
+            .flatMap(r -> r.contents().stream())
+            .map(
+                o ->
+                    new FileInfo(
+                        String.format("%s://%s/%s", s3uri.scheme(), s3uri.bucket(), o.key()),
+                        o.size(),
+                        o.lastModified().toEpochMilli()))
+            .iterator();
   }
 
   /**
-   * This method provides a "best-effort" to delete all objects under the
-   * given prefix.
+   * This method provides a "best-effort" to delete all objects under the given prefix.
    *
-   * Bulk delete operations are used and no reattempt is made for deletes if
-   * they fail, but will log any individual objects that are not deleted as part
-   * of the bulk operation.
+   * <p>Bulk delete operations are used and no reattempt is made for deletes if they fail, but will
+   * log any individual objects that are not deleted as part of the bulk operation.
    *
    * @param prefix prefix to delete
    */
@@ -299,8 +334,9 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
     if (executorService == null) {
       synchronized (S3FileIO.class) {
         if (executorService == null) {
-          executorService = ThreadPools.newWorkerPool(
-              "iceberg-s3fileio-delete", awsProperties.s3FileIoDeleteThreads());
+          executorService =
+              ThreadPools.newWorkerPool(
+                  "iceberg-s3fileio-delete", awsProperties.s3FileIoDeleteThreads());
         }
       }
     }
@@ -325,6 +361,9 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
         this.credential = ((CredentialSupplier) clientFactory).getCredential();
       }
       this.s3 = clientFactory::s3;
+      if (awsProperties.s3PreloadClientEnabled()) {
+        client();
+      }
     }
 
     // Report Hadoop metrics if Hadoop is available
@@ -338,7 +377,10 @@ public class S3FileIO implements FileIO, SupportsBulkOperations, SupportsPrefixO
       context.initialize(properties);
       this.metrics = context;
     } catch (NoClassDefFoundError | NoSuchMethodException | ClassCastException e) {
-      LOG.warn("Unable to load metrics class: '{}', falling back to null metrics", DEFAULT_METRICS_IMPL, e);
+      LOG.warn(
+          "Unable to load metrics class: '{}', falling back to null metrics",
+          DEFAULT_METRICS_IMPL,
+          e);
     }
   }
 
