@@ -26,6 +26,7 @@ import org.apache.iceberg.io.FileIO;
 import org.apache.iceberg.io.LocationProvider;
 import org.apache.iceberg.metrics.LoggingMetricsReporter;
 import org.apache.iceberg.metrics.MetricsReporter;
+import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 
 /**
  * Base {@link Table} implementation.
@@ -42,12 +43,11 @@ public class BaseTable implements Table, HasTableOperations, Serializable {
   private final MetricsReporter reporter;
 
   public BaseTable(TableOperations ops, String name) {
-    this.ops = ops;
-    this.name = name;
-    this.reporter = new LoggingMetricsReporter();
+    this(ops, name, LoggingMetricsReporter.instance());
   }
 
   public BaseTable(TableOperations ops, String name, MetricsReporter reporter) {
+    Preconditions.checkNotNull(reporter, "reporter cannot be null");
     this.ops = ops;
     this.name = name;
     this.reporter = reporter;
@@ -70,18 +70,18 @@ public class BaseTable implements Table, HasTableOperations, Serializable {
 
   @Override
   public TableScan newScan() {
-    return new DataTableScan(ops, this, schema(), new TableScanContext().reportWith(reporter));
+    return new DataTableScan(this, schema(), new TableScanContext().reportWith(reporter));
   }
 
   @Override
   public IncrementalAppendScan newIncrementalAppendScan() {
     return new BaseIncrementalAppendScan(
-        ops, this, schema(), new TableScanContext().reportWith(reporter));
+        this, schema(), new TableScanContext().reportWith(reporter));
   }
 
   @Override
   public IncrementalChangelogScan newIncrementalChangelogScan() {
-    return new BaseIncrementalChangelogScan(ops, this);
+    return new BaseIncrementalChangelogScan(this);
   }
 
   @Override
@@ -171,42 +171,42 @@ public class BaseTable implements Table, HasTableOperations, Serializable {
 
   @Override
   public AppendFiles newAppend() {
-    return new MergeAppend(name, ops);
+    return new MergeAppend(name, ops).reportWith(reporter);
   }
 
   @Override
   public AppendFiles newFastAppend() {
-    return new FastAppend(name, ops);
+    return new FastAppend(name, ops).reportWith(reporter);
   }
 
   @Override
   public RewriteFiles newRewrite() {
-    return new BaseRewriteFiles(name, ops);
+    return new BaseRewriteFiles(name, ops).reportWith(reporter);
   }
 
   @Override
   public RewriteManifests rewriteManifests() {
-    return new BaseRewriteManifests(ops);
+    return new BaseRewriteManifests(ops).reportWith(reporter);
   }
 
   @Override
   public OverwriteFiles newOverwrite() {
-    return new BaseOverwriteFiles(name, ops);
+    return new BaseOverwriteFiles(name, ops).reportWith(reporter);
   }
 
   @Override
   public RowDelta newRowDelta() {
-    return new BaseRowDelta(name, ops);
+    return new BaseRowDelta(name, ops).reportWith(reporter);
   }
 
   @Override
   public ReplacePartitions newReplacePartitions() {
-    return new BaseReplacePartitions(name, ops);
+    return new BaseReplacePartitions(name, ops).reportWith(reporter);
   }
 
   @Override
   public DeleteFiles newDelete() {
-    return new StreamingDelete(name, ops);
+    return new StreamingDelete(name, ops).reportWith(reporter);
   }
 
   @Override
@@ -226,22 +226,22 @@ public class BaseTable implements Table, HasTableOperations, Serializable {
 
   @Override
   public Transaction newTransaction() {
-    return Transactions.newTransaction(name, ops);
+    return Transactions.newTransaction(name, ops, reporter);
   }
 
   @Override
   public FileIO io() {
-    return operations().io();
+    return ops.io();
   }
 
   @Override
   public EncryptionManager encryption() {
-    return operations().encryption();
+    return ops.encryption();
   }
 
   @Override
   public LocationProvider locationProvider() {
-    return operations().locationProvider();
+    return ops.locationProvider();
   }
 
   @Override
