@@ -39,16 +39,25 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.function.Consumer;
+import org.apache.iceberg.events.CreateSnapshotEvent;
 import org.apache.iceberg.events.Listeners;
 import org.apache.iceberg.exceptions.CommitFailedException;
 import org.apache.iceberg.exceptions.CommitStateUnknownException;
 import org.apache.iceberg.exceptions.RuntimeIOException;
 import org.apache.iceberg.io.OutputFile;
+import org.apache.iceberg.metrics.CommitMetrics;
+import org.apache.iceberg.metrics.CommitMetricsResult;
+import org.apache.iceberg.metrics.DefaultMetricsContext;
+import org.apache.iceberg.metrics.ImmutableCommitReport;
+import org.apache.iceberg.metrics.LoggingMetricsReporter;
+import org.apache.iceberg.metrics.MetricsReporter;
+import org.apache.iceberg.metrics.Timer.Timed;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.util.Exceptions;
+import org.apache.iceberg.util.SnapshotUtil;
 import org.apache.iceberg.util.Tasks;
 import org.apache.iceberg.util.ThreadPools;
 import org.slf4j.Logger;
@@ -76,6 +85,7 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
   private final AtomicInteger manifestCount = new AtomicInteger(0);
   private final AtomicInteger attempt = new AtomicInteger(0);
   private final List<String> manifestLists = Lists.newArrayList();
+  private MetricsReporter reporter = LoggingMetricsReporter.instance();
   private volatile Long snapshotId = null;
   private TableMetadata base;
   private boolean stageOnly = false;
@@ -83,6 +93,7 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
 
   private ExecutorService workerPool = ThreadPools.getWorkerPool();
   private String targetBranch = SnapshotRef.MAIN_BRANCH;
+  private CommitMetrics commitMetrics;
 
   protected SnapshotProducer(TableOperations ops) {
     this.ops = ops;
@@ -112,6 +123,19 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
     return self();
   }
 
+  protected CommitMetrics commitMetrics() {
+    if (commitMetrics == null) {
+      this.commitMetrics = CommitMetrics.of(new DefaultMetricsContext());
+    }
+
+    return commitMetrics;
+  }
+
+  protected ThisT reportWith(MetricsReporter newReporter) {
+    this.reporter = newReporter;
+    return self();
+  }
+
   /**
    * * A setter for the target branch on which snapshot producer operation should be performed
    *
@@ -126,6 +150,10 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
     this.targetBranch = branch;
   }
 
+  protected String targetBranch() {
+    return targetBranch;
+  }
+
   protected ExecutorService workerPool() {
     return this.workerPool;
   }
@@ -157,20 +185,6 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
    */
   protected abstract String operation();
 
-  /**
-   * Validate the current metadata.
-   *
-   * <p>Child operations can override this to add custom validation.
-   *
-   * @param currentMetadata current table metadata to validate
-   * @deprecated Will be removed in 1.2.0, use {@link SnapshotProducer#validate(TableMetadata,
-   *     Snapshot)}.
-   */
-  @Deprecated
-  protected void validate(TableMetadata currentMetadata) {
-    validate(currentMetadata, base.currentSnapshot());
-  }
-
   /**
    * Validate the current metadata.
    *
@@ -181,19 +195,6 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
    */
   protected void validate(TableMetadata currentMetadata, Snapshot snapshot) {}
 
-  /**
-   * Apply the update's changes to the base table metadata and return the new manifest list.
-   *
-   * @param metadataToUpdate the base table metadata to apply changes to
-   * @return a manifest list for the new snapshot.
-   * @deprecated Will be removed in 1.2.0, use {@link SnapshotProducer#apply(TableMetadata,
-   *     Snapshot)}.
-   */
-  @Deprecated
-  protected List<ManifestFile> apply(TableMetadata metadataToUpdate) {
-    return apply(metadataToUpdate, base.currentSnapshot());
-  }
-
   /**
    * Apply the update's changes to the given metadata and snapshot. Return the new manifest list.
    *
@@ -206,15 +207,7 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
   @Override
   public Snapshot apply() {
     refresh();
-    Snapshot parentSnapshot = base.currentSnapshot();
-    if (targetBranch != null) {
-      SnapshotRef branch = base.ref(targetBranch);
-      if (branch != null) {
-        parentSnapshot = base.snapshot(branch.snapshotId());
-      } else if (base.currentSnapshot() != null) {
-        parentSnapshot = base.currentSnapshot();
-      }
-    }
+    Snapshot parentSnapshot = SnapshotUtil.latestSnapshot(base, targetBranch);
 
     long sequenceNumber = base.nextSequenceNumber();
     Long parentSnapshotId = parentSnapshot == null ? null : parentSnapshot.snapshotId();
@@ -271,9 +264,10 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
     }
 
     Map<String, String> previousSummary;
-    if (previous.currentSnapshot() != null) {
-      if (previous.currentSnapshot().summary() != null) {
-        previousSummary = previous.currentSnapshot().summary();
+    SnapshotRef previousBranchHead = previous.ref(targetBranch);
+    if (previousBranchHead != null) {
+      if (previous.snapshot(previousBranchHead.snapshotId()).summary() != null) {
+        previousSummary = previous.snapshot(previousBranchHead.snapshotId()).summary();
       } else {
         // previous snapshot had no summary, use an empty summary
         previousSummary = ImmutableMap.of();
@@ -355,6 +349,7 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
   public void commit() {
     // this is always set to the latest commit attempt's snapshot id.
     AtomicLong newSnapshotId = new AtomicLong(-1L);
+    Timed totalDuration = commitMetrics().totalDuration().start();
     try {
       Tasks.foreach(ops)
           .retry(base.propertyAsInt(COMMIT_NUM_RETRIES, COMMIT_NUM_RETRIES_DEFAULT))
@@ -364,6 +359,7 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
               base.propertyAsInt(COMMIT_TOTAL_RETRY_TIME_MS, COMMIT_TOTAL_RETRY_TIME_MS_DEFAULT),
               2.0 /* exponential */)
           .onlyRetryOn(CommitFailedException.class)
+          .countAttempts(commitMetrics().attempts())
           .run(
               taskOps -> {
                 Snapshot newSnapshot = apply();
@@ -424,6 +420,8 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
           "Failed to load committed table metadata or during cleanup, skipping further cleanup", e);
     }
 
+    totalDuration.stop();
+
     try {
       notifyListeners();
     } catch (Throwable e) {
@@ -436,6 +434,21 @@ abstract class SnapshotProducer<ThisT> implements SnapshotUpdate<ThisT> {
       Object event = updateEvent();
       if (event != null) {
         Listeners.notifyAll(event);
+
+        if (event instanceof CreateSnapshotEvent) {
+          CreateSnapshotEvent createSnapshotEvent = (CreateSnapshotEvent) event;
+
+          reporter.report(
+              ImmutableCommitReport.builder()
+                  .tableName(createSnapshotEvent.tableName())
+                  .snapshotId(createSnapshotEvent.snapshotId())
+                  .operation(createSnapshotEvent.operation())
+                  .sequenceNumber(createSnapshotEvent.sequenceNumber())
+                  .metadata(EnvironmentContext.get())
+                  .commitMetrics(
+                      CommitMetricsResult.from(commitMetrics(), createSnapshotEvent.summary()))
+                  .build());
+        }
       }
     } catch (RuntimeException e) {
       LOG.warn("Failed to notify listeners", e);
