@@ -19,6 +19,7 @@
 package org.apache.iceberg;
 
 import org.apache.iceberg.BaseTransaction.TransactionType;
+import org.apache.iceberg.metrics.MetricsReporter;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 
 public final class Transactions {
@@ -34,6 +35,11 @@ public final class Transactions {
     return new BaseTransaction(tableName, ops, TransactionType.REPLACE_TABLE, start);
   }
 
+  public static Transaction replaceTableTransaction(
+      String tableName, TableOperations ops, TableMetadata start, MetricsReporter reporter) {
+    return new BaseTransaction(tableName, ops, TransactionType.REPLACE_TABLE, start, reporter);
+  }
+
   public static Transaction createTableTransaction(
       String tableName, TableOperations ops, TableMetadata start) {
     Preconditions.checkArgument(
@@ -41,7 +47,19 @@ public final class Transactions {
     return new BaseTransaction(tableName, ops, TransactionType.CREATE_TABLE, start);
   }
 
+  public static Transaction createTableTransaction(
+      String tableName, TableOperations ops, TableMetadata start, MetricsReporter reporter) {
+    Preconditions.checkArgument(
+        ops.current() == null, "Cannot start create table transaction: table already exists");
+    return new BaseTransaction(tableName, ops, TransactionType.CREATE_TABLE, start, reporter);
+  }
+
   public static Transaction newTransaction(String tableName, TableOperations ops) {
     return new BaseTransaction(tableName, ops, TransactionType.SIMPLE, ops.refresh());
   }
+
+  public static Transaction newTransaction(
+      String tableName, TableOperations ops, MetricsReporter reporter) {
+    return new BaseTransaction(tableName, ops, TransactionType.SIMPLE, ops.refresh(), reporter);
+  }
 }
