@@ -24,13 +24,26 @@ import org.apache.iceberg.actions.RewriteDataFiles.FileGroupRewriteResult;
 public class BaseFileGroupRewriteResult implements FileGroupRewriteResult {
   private final int addedDataFilesCount;
   private final int rewrittenDataFilesCount;
+  private final long rewrittenBytesCount;
   private final FileGroupInfo info;
 
+  /**
+   * @deprecated Will be removed in 1.3.0; use {@link
+   *     BaseFileGroupRewriteResult#BaseFileGroupRewriteResult(FileGroupInfo, int, int, long)}
+   *     instead.
+   */
+  @Deprecated
   public BaseFileGroupRewriteResult(
       FileGroupInfo info, int addedFilesCount, int rewrittenFilesCount) {
+    this(info, addedFilesCount, rewrittenFilesCount, 0L);
+  }
+
+  public BaseFileGroupRewriteResult(
+      FileGroupInfo info, int addedFilesCount, int rewrittenFilesCount, long rewrittenBytesCount) {
     this.info = info;
     this.addedDataFilesCount = addedFilesCount;
     this.rewrittenDataFilesCount = rewrittenFilesCount;
+    this.rewrittenBytesCount = rewrittenBytesCount;
   }
 
   @Override
@@ -47,4 +60,9 @@ public class BaseFileGroupRewriteResult implements FileGroupRewriteResult {
   public int rewrittenDataFilesCount() {
     return rewrittenDataFilesCount;
   }
+
+  @Override
+  public long rewrittenBytesCount() {
+    return rewrittenBytesCount;
+  }
 }
