@@ -16,9 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.avro;
 
+import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION;
+import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION_DEFAULT;
+import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION_LEVEL;
+import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION_LEVEL_DEFAULT;
+import static org.apache.iceberg.TableProperties.DELETE_AVRO_COMPRESSION;
+import static org.apache.iceberg.TableProperties.DELETE_AVRO_COMPRESSION_LEVEL;
+
 import java.io.IOException;
 import java.util.List;
 import java.util.Locale;
@@ -60,16 +66,8 @@ import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.util.ArrayUtil;
 
-import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION;
-import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION_DEFAULT;
-import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION_LEVEL;
-import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION_LEVEL_DEFAULT;
-import static org.apache.iceberg.TableProperties.DELETE_AVRO_COMPRESSION;
-import static org.apache.iceberg.TableProperties.DELETE_AVRO_COMPRESSION_LEVEL;
-
 public class Avro {
-  private Avro() {
-  }
+  private Avro() {}
 
   private enum Codec {
     UNCOMPRESSED,
@@ -165,7 +163,8 @@ public class Avro {
     }
 
     // supposed to always be a private method used strictly by data and delete write builders
-    private WriteBuilder createContextFunc(Function<Map<String, String>, Context> newCreateContextFunc) {
+    private WriteBuilder createContextFunc(
+        Function<Map<String, String>, Context> newCreateContextFunc) {
       this.createContextFunc = newCreateContextFunc;
       return this;
     }
@@ -188,7 +187,14 @@ public class Avro {
       CodecFactory codec = context.codec();
 
       return new AvroFileAppender<>(
-          schema, AvroSchemaUtil.convert(schema, name), file, writerFunc, codec, metadata, metricsConfig, overwrite);
+          schema,
+          AvroSchemaUtil.convert(schema, name),
+          file,
+          writerFunc,
+          codec,
+          metadata,
+          metricsConfig,
+          overwrite);
     }
 
     private static class Context {
@@ -200,7 +206,8 @@ public class Avro {
 
       static Context dataContext(Map<String, String> config) {
         String codecAsString = config.getOrDefault(AVRO_COMPRESSION, AVRO_COMPRESSION_DEFAULT);
-        String compressionLevel = config.getOrDefault(AVRO_COMPRESSION_LEVEL, AVRO_COMPRESSION_LEVEL_DEFAULT);
+        String compressionLevel =
+            config.getOrDefault(AVRO_COMPRESSION_LEVEL, AVRO_COMPRESSION_LEVEL_DEFAULT);
         CodecFactory codec = toCodec(codecAsString, compressionLevel);
 
         return new Context(codec);
@@ -211,8 +218,10 @@ public class Avro {
         Context dataContext = dataContext(config);
 
         String codecAsString = config.get(DELETE_AVRO_COMPRESSION);
-        String compressionLevel = config.getOrDefault(DELETE_AVRO_COMPRESSION_LEVEL, AVRO_COMPRESSION_LEVEL_DEFAULT);
-        CodecFactory codec = codecAsString != null ? toCodec(codecAsString, compressionLevel) : dataContext.codec();
+        String compressionLevel =
+            config.getOrDefault(DELETE_AVRO_COMPRESSION_LEVEL, AVRO_COMPRESSION_LEVEL_DEFAULT);
+        CodecFactory codec =
+            codecAsString != null ? toCodec(codecAsString, compressionLevel) : dataContext.codec();
 
         return new Context(codec);
       }
@@ -228,12 +237,14 @@ public class Avro {
               codecFactory = CodecFactory.snappyCodec();
               break;
             case ZSTD:
-              codecFactory = CodecFactory.zstandardCodec(
-                  compressionLevelAsInt(compressionLevel, ZSTD_COMPRESSION_LEVEL_DEFAULT));
+              codecFactory =
+                  CodecFactory.zstandardCodec(
+                      compressionLevelAsInt(compressionLevel, ZSTD_COMPRESSION_LEVEL_DEFAULT));
               break;
             case GZIP:
-              codecFactory = CodecFactory.deflateCodec(
-                  compressionLevelAsInt(compressionLevel, GZIP_COMPRESSION_LEVEL_DEFAULT));
+              codecFactory =
+                  CodecFactory.deflateCodec(
+                      compressionLevelAsInt(compressionLevel, GZIP_COMPRESSION_LEVEL_DEFAULT));
               break;
             default:
               throw new IllegalArgumentException("Unsupported compression codec: " + codecAsString);
@@ -244,8 +255,11 @@ public class Avro {
         return codecFactory;
       }
 
-      private static int compressionLevelAsInt(String tableCompressionLevel, int defaultCompressionLevel) {
-        return tableCompressionLevel != null ? Integer.parseInt(tableCompressionLevel) : defaultCompressionLevel;
+      private static int compressionLevelAsInt(
+          String tableCompressionLevel, int defaultCompressionLevel) {
+        return tableCompressionLevel != null
+            ? Integer.parseInt(tableCompressionLevel)
+            : defaultCompressionLevel;
       }
 
       CodecFactory codec() {
@@ -340,11 +354,13 @@ public class Avro {
 
     public <T> DataWriter<T> build() throws IOException {
       Preconditions.checkArgument(spec != null, "Cannot create data writer without spec");
-      Preconditions.checkArgument(spec.isUnpartitioned() || partition != null,
+      Preconditions.checkArgument(
+          spec.isUnpartitioned() || partition != null,
           "Partition must not be null when creating data writer for partitioned spec");
 
       FileAppender<T> fileAppender = appenderBuilder.build();
-      return new DataWriter<>(fileAppender, FileFormat.AVRO, location, spec, partition, keyMetadata, sortOrder);
+      return new DataWriter<>(
+          fileAppender, FileFormat.AVRO, location, spec, partition, keyMetadata, sortOrder);
     }
   }
 
@@ -451,18 +467,25 @@ public class Avro {
     }
 
     public <T> EqualityDeleteWriter<T> buildEqualityWriter() throws IOException {
-      Preconditions.checkState(rowSchema != null, "Cannot create equality delete file without a schema");
-      Preconditions.checkState(equalityFieldIds != null, "Cannot create equality delete file without delete field ids");
-      Preconditions.checkState(createWriterFunc != null,
+      Preconditions.checkState(
+          rowSchema != null, "Cannot create equality delete file without a schema");
+      Preconditions.checkState(
+          equalityFieldIds != null, "Cannot create equality delete file without delete field ids");
+      Preconditions.checkState(
+          createWriterFunc != null,
           "Cannot create equality delete file unless createWriterFunc is set");
-      Preconditions.checkArgument(spec != null, "Spec must not be null when creating equality delete writer");
-      Preconditions.checkArgument(spec.isUnpartitioned() || partition != null,
+      Preconditions.checkArgument(
+          spec != null, "Spec must not be null when creating equality delete writer");
+      Preconditions.checkArgument(
+          spec.isUnpartitioned() || partition != null,
           "Partition must not be null for partitioned writes");
 
       meta("delete-type", "equality");
-      meta("delete-field-ids", IntStream.of(equalityFieldIds)
-          .mapToObj(Objects::toString)
-          .collect(Collectors.joining(", ")));
+      meta(
+          "delete-field-ids",
+          IntStream.of(equalityFieldIds)
+              .mapToObj(Objects::toString)
+              .collect(Collectors.joining(", ")));
 
       // the appender uses the row schema without extra columns
       appenderBuilder.schema(rowSchema);
@@ -470,16 +493,26 @@ public class Avro {
       appenderBuilder.createContextFunc(WriteBuilder.Context::deleteContext);
 
       return new EqualityDeleteWriter<>(
-          appenderBuilder.build(), FileFormat.AVRO, location, spec, partition, keyMetadata, sortOrder,
+          appenderBuilder.build(),
+          FileFormat.AVRO,
+          location,
+          spec,
+          partition,
+          keyMetadata,
+          sortOrder,
           equalityFieldIds);
     }
 
     public <T> PositionDeleteWriter<T> buildPositionWriter() throws IOException {
-      Preconditions.checkState(equalityFieldIds == null, "Cannot create position delete file using delete field ids");
-      Preconditions.checkArgument(spec != null, "Spec must not be null when creating position delete writer");
-      Preconditions.checkArgument(spec.isUnpartitioned() || partition != null,
+      Preconditions.checkState(
+          equalityFieldIds == null, "Cannot create position delete file using delete field ids");
+      Preconditions.checkArgument(
+          spec != null, "Spec must not be null when creating position delete writer");
+      Preconditions.checkArgument(
+          spec.isUnpartitioned() || partition != null,
           "Partition must not be null for partitioned writes");
-      Preconditions.checkArgument(rowSchema == null || createWriterFunc != null,
+      Preconditions.checkArgument(
+          rowSchema == null || createWriterFunc != null,
           "Create function should be provided if we write row data");
 
       meta("delete-type", "position");
@@ -494,7 +527,8 @@ public class Avro {
       } else {
         appenderBuilder.schema(DeleteSchemaUtil.pathPosSchema());
 
-        // We ignore the 'createWriterFunc' and 'rowSchema' even if is provided, since we do not write row data itself
+        // We ignore the 'createWriterFunc' and 'rowSchema' even if is provided, since we do not
+        // write row data itself
         appenderBuilder.createWriterFunc(ignored -> new PositionDatumWriter());
       }
 
@@ -505,16 +539,13 @@ public class Avro {
     }
   }
 
-  /**
-   * A {@link DatumWriter} implementation that wraps another to produce position deletes.
-   */
+  /** A {@link DatumWriter} implementation that wraps another to produce position deletes. */
   private static class PositionDatumWriter implements MetricsAwareDatumWriter<PositionDelete<?>> {
     private static final ValueWriter<Object> PATH_WRITER = ValueWriters.strings();
     private static final ValueWriter<Long> POS_WRITER = ValueWriters.longs();
 
     @Override
-    public void setSchema(Schema schema) {
-    }
+    public void setSchema(Schema schema) {}
 
     @Override
     public void write(PositionDelete<?> delete, Encoder out) throws IOException {
@@ -529,11 +560,13 @@ public class Avro {
   }
 
   /**
-   * A {@link DatumWriter} implementation that wraps another to produce position deletes with row data.
+   * A {@link DatumWriter} implementation that wraps another to produce position deletes with row
+   * data.
    *
    * @param <D> the type of datum written as a deleted row
    */
-  private static class PositionAndRowDatumWriter<D> implements MetricsAwareDatumWriter<PositionDelete<D>> {
+  private static class PositionAndRowDatumWriter<D>
+      implements MetricsAwareDatumWriter<PositionDelete<D>> {
     private static final ValueWriter<Object> PATH_WRITER = ValueWriters.strings();
     private static final ValueWriter<Long> POS_WRITER = ValueWriters.longs();
 
@@ -577,12 +610,15 @@ public class Avro {
     private org.apache.iceberg.Schema schema = null;
     private Function<Schema, DatumReader<?>> createReaderFunc = null;
     private BiFunction<org.apache.iceberg.Schema, Schema, DatumReader<?>> createReaderBiFunc = null;
+
     @SuppressWarnings("UnnecessaryLambda")
-    private final Function<Schema, DatumReader<?>> defaultCreateReaderFunc = readSchema -> {
-      GenericAvroReader<?> reader = new GenericAvroReader<>(readSchema);
-      reader.setClassLoader(loader);
-      return reader;
-    };
+    private final Function<Schema, DatumReader<?>> defaultCreateReaderFunc =
+        readSchema -> {
+          GenericAvroReader<?> reader = new GenericAvroReader<>(readSchema);
+          reader.setClassLoader(loader);
+          return reader;
+        };
+
     private Long start = null;
     private Long length = null;
 
@@ -597,7 +633,8 @@ public class Avro {
       return this;
     }
 
-    public ReadBuilder createReaderFunc(BiFunction<org.apache.iceberg.Schema, Schema, DatumReader<?>> readerFunction) {
+    public ReadBuilder createReaderFunc(
+        BiFunction<org.apache.iceberg.Schema, Schema, DatumReader<?>> readerFunction) {
       Preconditions.checkState(createReaderFunc == null, "Cannot set multiple createReaderFunc");
       this.createReaderBiFunc = readerFunction;
       return this;
@@ -657,14 +694,18 @@ public class Avro {
         readerFunc = defaultCreateReaderFunc;
       }
 
-      return new AvroIterable<>(file,
+      return new AvroIterable<>(
+          file,
           new ProjectionDatumReader<>(readerFunc, schema, renames, nameMapping),
-          start, length, reuseContainers);
+          start,
+          length,
+          reuseContainers);
     }
   }
 
   /**
    * Returns number of rows in specified Avro file
+   *
    * @param file Avro file
    * @return number of rows in file
    */
