@@ -26,28 +26,36 @@ import java.net.URI;
 import java.net.URISyntaxException;
 import java.util.Map;
 import java.util.function.Consumer;
+import java.util.stream.Collectors;
 import org.apache.hc.client5.http.classic.methods.HttpUriRequest;
 import org.apache.hc.client5.http.classic.methods.HttpUriRequestBase;
 import org.apache.hc.client5.http.impl.classic.CloseableHttpClient;
 import org.apache.hc.client5.http.impl.classic.CloseableHttpResponse;
+import org.apache.hc.client5.http.impl.classic.HttpClientBuilder;
 import org.apache.hc.client5.http.impl.classic.HttpClients;
 import org.apache.hc.core5.http.ContentType;
+import org.apache.hc.core5.http.Header;
 import org.apache.hc.core5.http.HttpHeaders;
+import org.apache.hc.core5.http.HttpRequestInterceptor;
 import org.apache.hc.core5.http.HttpStatus;
 import org.apache.hc.core5.http.Method;
 import org.apache.hc.core5.http.ParseException;
 import org.apache.hc.core5.http.impl.EnglishReasonPhraseCatalog;
 import org.apache.hc.core5.http.io.entity.EntityUtils;
 import org.apache.hc.core5.http.io.entity.StringEntity;
+import org.apache.hc.core5.http.message.BasicHeader;
 import org.apache.hc.core5.io.CloseMode;
 import org.apache.hc.core5.net.URIBuilder;
 import org.apache.iceberg.IcebergBuild;
+import org.apache.iceberg.common.DynConstructors;
+import org.apache.iceberg.common.DynMethods;
 import org.apache.iceberg.exceptions.RESTException;
 import org.apache.iceberg.relocated.com.google.common.annotations.VisibleForTesting;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.rest.responses.ErrorResponse;
+import org.apache.iceberg.util.PropertyUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -55,6 +63,9 @@ import org.slf4j.LoggerFactory;
 public class HTTPClient implements RESTClient {
 
   private static final Logger LOG = LoggerFactory.getLogger(HTTPClient.class);
+  private static final String SIGV4_ENABLED = "rest.sigv4-enabled";
+  private static final String SIGV4_REQUEST_INTERCEPTOR_IMPL =
+      "org.apache.iceberg.aws.RESTSigV4Signer";
   @VisibleForTesting static final String CLIENT_VERSION_HEADER = "X-Client-Version";
 
   @VisibleForTesting
@@ -63,13 +74,29 @@ public class HTTPClient implements RESTClient {
   private final String uri;
   private final CloseableHttpClient httpClient;
   private final ObjectMapper mapper;
-  private final Map<String, String> baseHeaders;
 
-  private HTTPClient(String uri, Map<String, String> baseHeaders, ObjectMapper objectMapper) {
+  private HTTPClient(
+      String uri,
+      Map<String, String> baseHeaders,
+      ObjectMapper objectMapper,
+      HttpRequestInterceptor requestInterceptor) {
     this.uri = uri;
-    this.httpClient = HttpClients.createDefault();
-    this.baseHeaders = baseHeaders != null ? baseHeaders : ImmutableMap.of();
     this.mapper = objectMapper;
+
+    HttpClientBuilder clientBuilder = HttpClients.custom();
+
+    if (baseHeaders != null) {
+      clientBuilder.setDefaultHeaders(
+          baseHeaders.entrySet().stream()
+              .map(e -> new BasicHeader(e.getKey(), e.getValue()))
+              .collect(Collectors.toList()));
+    }
+
+    if (requestInterceptor != null) {
+      clientBuilder.addRequestInterceptorLast(requestInterceptor);
+    }
+
+    this.httpClient = clientBuilder.build();
   }
 
   private static String extractResponseBodyAsString(CloseableHttpResponse response) {
@@ -190,6 +217,35 @@ public class HTTPClient implements RESTClient {
       Class<T> responseType,
       Map<String, String> headers,
       Consumer<ErrorResponse> errorHandler) {
+    return execute(
+        method, path, queryParams, requestBody, responseType, headers, errorHandler, h -> {});
+  }
+
+  /**
+   * Method to execute an HTTP request and process the corresponding response.
+   *
+   * @param method - HTTP method, such as GET, POST, HEAD, etc.
+   * @param queryParams - A map of query parameters
+   * @param path - URL path to send the request to
+   * @param requestBody - Content to place in the request body
+   * @param responseType - Class of the Response type. Needs to have serializer registered with
+   *     ObjectMapper
+   * @param errorHandler - Error handler delegated for HTTP responses which handles server error
+   *     responses
+   * @param responseHeaders The consumer of the response headers
+   * @param <T> - Class type of the response for deserialization. Must be registered with the
+   *     ObjectMapper.
+   * @return The response entity, parsed and converted to its type T
+   */
+  private <T> T execute(
+      Method method,
+      String path,
+      Map<String, String> queryParams,
+      Object requestBody,
+      Class<T> responseType,
+      Map<String, String> headers,
+      Consumer<ErrorResponse> errorHandler,
+      Consumer<Map<String, String>> responseHeaders) {
     if (path.startsWith("/")) {
       throw new RESTException(
           "Received a malformed path for a REST request: %s. Paths should not start with /", path);
@@ -210,6 +266,12 @@ public class HTTPClient implements RESTClient {
     }
 
     try (CloseableHttpResponse response = httpClient.execute(request)) {
+      Map<String, String> respHeaders = Maps.newHashMap();
+      for (Header header : response.getHeaders()) {
+        respHeaders.put(header.getName(), header.getValue());
+      }
+
+      responseHeaders.accept(respHeaders);
 
       // Skip parsing the response stream for any successful request not expecting a response body
       if (response.getCode() == HttpStatus.SC_NO_CONTENT
@@ -269,6 +331,18 @@ public class HTTPClient implements RESTClient {
     return execute(Method.POST, path, null, body, responseType, headers, errorHandler);
   }
 
+  @Override
+  public <T extends RESTResponse> T post(
+      String path,
+      RESTRequest body,
+      Class<T> responseType,
+      Map<String, String> headers,
+      Consumer<ErrorResponse> errorHandler,
+      Consumer<Map<String, String>> responseHeaders) {
+    return execute(
+        Method.POST, path, null, body, responseType, headers, errorHandler, responseHeaders);
+  }
+
   @Override
   public <T extends RESTResponse> T delete(
       String path,
@@ -304,7 +378,6 @@ public class HTTPClient implements RESTClient {
     // Many systems require that content type is set regardless and will fail, even on an empty
     // bodied request.
     request.setHeader(HttpHeaders.CONTENT_TYPE, bodyMimeType);
-    baseHeaders.forEach(request::setHeader);
     requestHeaders.forEach(request::setHeader);
   }
 
@@ -313,16 +386,63 @@ public class HTTPClient implements RESTClient {
     httpClient.close(CloseMode.GRACEFUL);
   }
 
+  @VisibleForTesting
+  static HttpRequestInterceptor loadInterceptorDynamically(
+      String impl, Map<String, String> properties) {
+    HttpRequestInterceptor instance;
+
+    DynConstructors.Ctor<HttpRequestInterceptor> ctor;
+    try {
+      ctor =
+          DynConstructors.builder(HttpRequestInterceptor.class)
+              .loader(HTTPClient.class.getClassLoader())
+              .impl(impl)
+              .buildChecked();
+    } catch (NoSuchMethodException e) {
+      throw new IllegalArgumentException(
+          String.format(
+              "Cannot initialize RequestInterceptor, missing no-arg constructor: %s", impl),
+          e);
+    }
+
+    try {
+      instance = ctor.newInstance();
+    } catch (ClassCastException e) {
+      throw new IllegalArgumentException(
+          String.format("Cannot initialize, %s does not implement RequestInterceptor", impl), e);
+    }
+
+    DynMethods.builder("initialize")
+        .hiddenImpl(impl, Map.class)
+        .orNoop()
+        .build(instance)
+        .invoke(properties);
+
+    return instance;
+  }
+
+  /**
+   * @return http client builder
+   * @deprecated will be removed in 1.3.0; use {@link HTTPClient#builder(Map)}
+   */
+  @Deprecated
   public static Builder builder() {
-    return new Builder();
+    return new Builder(ImmutableMap.of());
+  }
+
+  public static Builder builder(Map<String, String> properties) {
+    return new Builder(properties);
   }
 
   public static class Builder {
+    private final Map<String, String> properties;
     private final Map<String, String> baseHeaders = Maps.newHashMap();
     private String uri;
     private ObjectMapper mapper = RESTObjectMapper.mapper();
 
-    private Builder() {}
+    private Builder(Map<String, String> properties) {
+      this.properties = properties;
+    }
 
     public Builder uri(String baseUri) {
       Preconditions.checkNotNull(baseUri, "Invalid uri for http client: null");
@@ -348,7 +468,14 @@ public class HTTPClient implements RESTClient {
     public HTTPClient build() {
       withHeader(CLIENT_VERSION_HEADER, IcebergBuild.fullVersion());
       withHeader(CLIENT_GIT_COMMIT_SHORT_HEADER, IcebergBuild.gitCommitShortId());
-      return new HTTPClient(uri, baseHeaders, mapper);
+
+      HttpRequestInterceptor interceptor = null;
+
+      if (PropertyUtil.propertyAsBoolean(properties, SIGV4_ENABLED, false)) {
+        interceptor = loadInterceptorDynamically(SIGV4_REQUEST_INTERCEPTOR_IMPL, properties);
+      }
+
+      return new HTTPClient(uri, baseHeaders, mapper, interceptor);
     }
   }
 
