@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.rest;
 
 import com.fasterxml.jackson.core.JsonGenerator;
@@ -43,6 +42,9 @@ import org.apache.iceberg.catalog.Namespace;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.catalog.TableIdentifierParser;
 import org.apache.iceberg.rest.auth.OAuth2Util;
+import org.apache.iceberg.rest.requests.ImmutableReportMetricsRequest;
+import org.apache.iceberg.rest.requests.ReportMetricsRequest;
+import org.apache.iceberg.rest.requests.ReportMetricsRequestParser;
 import org.apache.iceberg.rest.requests.UpdateRequirementParser;
 import org.apache.iceberg.rest.requests.UpdateTableRequest.UpdateRequirement;
 import org.apache.iceberg.rest.responses.ErrorResponse;
@@ -52,8 +54,7 @@ import org.apache.iceberg.util.JsonUtil;
 
 public class RESTSerializers {
 
-  private RESTSerializers() {
-  }
+  private RESTSerializers() {}
 
   public static void registerAll(ObjectMapper mapper) {
     SimpleModule module = new SimpleModule();
@@ -77,7 +78,12 @@ public class RESTSerializers {
         .addSerializer(UpdateRequirement.class, new UpdateRequirementSerializer())
         .addDeserializer(UpdateRequirement.class, new UpdateRequirementDeserializer())
         .addSerializer(OAuthTokenResponse.class, new OAuthTokenResponseSerializer())
-        .addDeserializer(OAuthTokenResponse.class, new OAuthTokenResponseDeserializer());
+        .addDeserializer(OAuthTokenResponse.class, new OAuthTokenResponseDeserializer())
+        .addSerializer(ReportMetricsRequest.class, new ReportMetricsRequestSerializer<>())
+        .addDeserializer(ReportMetricsRequest.class, new ReportMetricsRequestDeserializer<>())
+        .addSerializer(ImmutableReportMetricsRequest.class, new ReportMetricsRequestSerializer<>())
+        .addDeserializer(
+            ImmutableReportMetricsRequest.class, new ReportMetricsRequestDeserializer<>());
     mapper.registerModule(module);
   }
 
@@ -92,7 +98,8 @@ public class RESTSerializers {
 
   public static class UpdateRequirementSerializer extends JsonSerializer<UpdateRequirement> {
     @Override
-    public void serialize(UpdateRequirement value, JsonGenerator gen, SerializerProvider serializers)
+    public void serialize(
+        UpdateRequirement value, JsonGenerator gen, SerializerProvider serializers)
         throws IOException {
       UpdateRequirementParser.toJson(value, gen);
     }
@@ -100,7 +107,8 @@ public class RESTSerializers {
 
   public static class TableMetadataDeserializer extends JsonDeserializer<TableMetadata> {
     @Override
-    public TableMetadata deserialize(JsonParser p, DeserializationContext context) throws IOException {
+    public TableMetadata deserialize(JsonParser p, DeserializationContext context)
+        throws IOException {
       JsonNode node = p.getCodec().readTree(p);
       return TableMetadataParser.fromJson(node);
     }
@@ -133,7 +141,8 @@ public class RESTSerializers {
 
   public static class ErrorResponseDeserializer extends JsonDeserializer<ErrorResponse> {
     @Override
-    public ErrorResponse deserialize(JsonParser p, DeserializationContext context) throws IOException {
+    public ErrorResponse deserialize(JsonParser p, DeserializationContext context)
+        throws IOException {
       JsonNode node = p.getCodec().readTree(p);
       return ErrorResponseParser.fromJson(node);
     }
@@ -141,7 +150,8 @@ public class RESTSerializers {
 
   public static class ErrorResponseSerializer extends JsonSerializer<ErrorResponse> {
     @Override
-    public void serialize(ErrorResponse errorResponse, JsonGenerator gen, SerializerProvider serializers)
+    public void serialize(
+        ErrorResponse errorResponse, JsonGenerator gen, SerializerProvider serializers)
         throws IOException {
       ErrorResponseParser.toJson(errorResponse, gen);
     }
@@ -175,7 +185,8 @@ public class RESTSerializers {
 
   public static class TableIdentifierSerializer extends JsonSerializer<TableIdentifier> {
     @Override
-    public void serialize(TableIdentifier identifier, JsonGenerator gen, SerializerProvider serializers)
+    public void serialize(
+        TableIdentifier identifier, JsonGenerator gen, SerializerProvider serializers)
         throws IOException {
       TableIdentifierParser.toJson(identifier, gen);
     }
@@ -206,7 +217,8 @@ public class RESTSerializers {
     }
   }
 
-  public static class UnboundPartitionSpecDeserializer extends JsonDeserializer<UnboundPartitionSpec> {
+  public static class UnboundPartitionSpecDeserializer
+      extends JsonDeserializer<UnboundPartitionSpec> {
     @Override
     public UnboundPartitionSpec deserialize(JsonParser p, DeserializationContext context)
         throws IOException {
@@ -217,7 +229,8 @@ public class RESTSerializers {
 
   public static class UnboundSortOrderSerializer extends JsonSerializer<UnboundSortOrder> {
     @Override
-    public void serialize(UnboundSortOrder sortOrder, JsonGenerator gen, SerializerProvider serializers)
+    public void serialize(
+        UnboundSortOrder sortOrder, JsonGenerator gen, SerializerProvider serializers)
         throws IOException {
       SortOrderParser.toJson(sortOrder, gen);
     }
@@ -225,7 +238,8 @@ public class RESTSerializers {
 
   public static class UnboundSortOrderDeserializer extends JsonDeserializer<UnboundSortOrder> {
     @Override
-    public UnboundSortOrder deserialize(JsonParser p, DeserializationContext context) throws IOException {
+    public UnboundSortOrder deserialize(JsonParser p, DeserializationContext context)
+        throws IOException {
       JsonNode jsonNode = p.getCodec().readTree(p);
       return SortOrderParser.fromJson(jsonNode);
     }
@@ -233,7 +247,8 @@ public class RESTSerializers {
 
   public static class OAuthTokenResponseSerializer extends JsonSerializer<OAuthTokenResponse> {
     @Override
-    public void serialize(OAuthTokenResponse tokenResponse, JsonGenerator gen, SerializerProvider serializers)
+    public void serialize(
+        OAuthTokenResponse tokenResponse, JsonGenerator gen, SerializerProvider serializers)
         throws IOException {
       OAuth2Util.tokenResponseToJson(tokenResponse, gen);
     }
@@ -241,9 +256,28 @@ public class RESTSerializers {
 
   public static class OAuthTokenResponseDeserializer extends JsonDeserializer<OAuthTokenResponse> {
     @Override
-    public OAuthTokenResponse deserialize(JsonParser p, DeserializationContext context) throws IOException {
+    public OAuthTokenResponse deserialize(JsonParser p, DeserializationContext context)
+        throws IOException {
       JsonNode jsonNode = p.getCodec().readTree(p);
       return OAuth2Util.tokenResponseFromJson(jsonNode);
     }
   }
+
+  public static class ReportMetricsRequestSerializer<T extends ReportMetricsRequest>
+      extends JsonSerializer<T> {
+    @Override
+    public void serialize(T request, JsonGenerator gen, SerializerProvider serializers)
+        throws IOException {
+      ReportMetricsRequestParser.toJson(request, gen);
+    }
+  }
+
+  public static class ReportMetricsRequestDeserializer<T extends ReportMetricsRequest>
+      extends JsonDeserializer<T> {
+    @Override
+    public T deserialize(JsonParser p, DeserializationContext context) throws IOException {
+      JsonNode jsonNode = p.getCodec().readTree(p);
+      return (T) ReportMetricsRequestParser.fromJson(jsonNode);
+    }
+  }
 }
