@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg;
 
 import java.io.File;
@@ -56,26 +55,54 @@ public class TestManifestListVersions {
   private static final long EXISTING_ROWS = 857273L;
   private static final int DELETED_FILES = 1;
   private static final long DELETED_ROWS = 22910L;
-  private static final List<ManifestFile.PartitionFieldSummary> PARTITION_SUMMARIES = ImmutableList.of();
+  private static final List<ManifestFile.PartitionFieldSummary> PARTITION_SUMMARIES =
+      ImmutableList.of();
   private static final ByteBuffer KEY_METADATA = null;
 
-  private static final ManifestFile TEST_MANIFEST = new GenericManifestFile(
-      PATH, LENGTH, SPEC_ID, ManifestContent.DATA, SEQ_NUM, MIN_SEQ_NUM, SNAPSHOT_ID,
-      ADDED_FILES, ADDED_ROWS, EXISTING_FILES, EXISTING_ROWS, DELETED_FILES, DELETED_ROWS,
-      PARTITION_SUMMARIES, KEY_METADATA);
+  private static final ManifestFile TEST_MANIFEST =
+      new GenericManifestFile(
+          PATH,
+          LENGTH,
+          SPEC_ID,
+          ManifestContent.DATA,
+          SEQ_NUM,
+          MIN_SEQ_NUM,
+          SNAPSHOT_ID,
+          ADDED_FILES,
+          ADDED_ROWS,
+          EXISTING_FILES,
+          EXISTING_ROWS,
+          DELETED_FILES,
+          DELETED_ROWS,
+          PARTITION_SUMMARIES,
+          KEY_METADATA);
 
-  private static final ManifestFile TEST_DELETE_MANIFEST = new GenericManifestFile(
-      PATH, LENGTH, SPEC_ID, ManifestContent.DELETES, SEQ_NUM, MIN_SEQ_NUM, SNAPSHOT_ID,
-      ADDED_FILES, ADDED_ROWS, EXISTING_FILES, EXISTING_ROWS, DELETED_FILES, DELETED_ROWS,
-      PARTITION_SUMMARIES, KEY_METADATA);
+  private static final ManifestFile TEST_DELETE_MANIFEST =
+      new GenericManifestFile(
+          PATH,
+          LENGTH,
+          SPEC_ID,
+          ManifestContent.DELETES,
+          SEQ_NUM,
+          MIN_SEQ_NUM,
+          SNAPSHOT_ID,
+          ADDED_FILES,
+          ADDED_ROWS,
+          EXISTING_FILES,
+          EXISTING_ROWS,
+          DELETED_FILES,
+          DELETED_ROWS,
+          PARTITION_SUMMARIES,
+          KEY_METADATA);
 
-  @Rule
-  public TemporaryFolder temp = new TemporaryFolder();
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
   @Test
   public void testV1WriteDeleteManifest() {
-    AssertHelpers.assertThrows("Should fail to write a DELETE manifest to v1",
-        IllegalArgumentException.class, "Cannot store delete manifests in a v1 table",
+    AssertHelpers.assertThrows(
+        "Should fail to write a DELETE manifest to v1",
+        IllegalArgumentException.class,
+        "Cannot store delete manifests in a v1 table",
         () -> writeManifestList(TEST_DELETE_MANIFEST, 1));
   }
 
@@ -84,8 +111,10 @@ public class TestManifestListVersions {
     ManifestFile manifest = writeAndReadManifestList(1);
 
     // v2 fields are not written and are defaulted
-    Assert.assertEquals("Should not contain sequence number, default to 0", 0, manifest.sequenceNumber());
-    Assert.assertEquals("Should not contain min sequence number, default to 0", 0, manifest.minSequenceNumber());
+    Assert.assertEquals(
+        "Should not contain sequence number, default to 0", 0, manifest.sequenceNumber());
+    Assert.assertEquals(
+        "Should not contain min sequence number, default to 0", 0, manifest.minSequenceNumber());
 
     // v1 fields are read correctly, even though order changed
     Assert.assertEquals("Path", PATH, manifest.path());
@@ -94,7 +123,8 @@ public class TestManifestListVersions {
     Assert.assertEquals("Content", ManifestContent.DATA, manifest.content());
     Assert.assertEquals("Snapshot id", SNAPSHOT_ID, (long) manifest.snapshotId());
     Assert.assertEquals("Added files count", ADDED_FILES, (int) manifest.addedFilesCount());
-    Assert.assertEquals("Existing files count", EXISTING_FILES, (int) manifest.existingFilesCount());
+    Assert.assertEquals(
+        "Existing files count", EXISTING_FILES, (int) manifest.existingFilesCount());
     Assert.assertEquals("Deleted files count", DELETED_FILES, (int) manifest.deletedFilesCount());
     Assert.assertEquals("Added rows count", ADDED_ROWS, (long) manifest.addedRowsCount());
     Assert.assertEquals("Existing rows count", EXISTING_ROWS, (long) manifest.existingRowsCount());
@@ -115,7 +145,8 @@ public class TestManifestListVersions {
     Assert.assertEquals("Snapshot id", SNAPSHOT_ID, (long) manifest.snapshotId());
     Assert.assertEquals("Added files count", ADDED_FILES, (int) manifest.addedFilesCount());
     Assert.assertEquals("Added rows count", ADDED_ROWS, (long) manifest.addedRowsCount());
-    Assert.assertEquals("Existing files count", EXISTING_FILES, (int) manifest.existingFilesCount());
+    Assert.assertEquals(
+        "Existing files count", EXISTING_FILES, (int) manifest.existingFilesCount());
     Assert.assertEquals("Existing rows count", EXISTING_ROWS, (long) manifest.existingRowsCount());
     Assert.assertEquals("Deleted files count", DELETED_FILES, (int) manifest.deletedFilesCount());
     Assert.assertEquals("Deleted rows count", DELETED_ROWS, (long) manifest.deletedRowsCount());
@@ -131,12 +162,17 @@ public class TestManifestListVersions {
     Assert.assertEquals("Length", LENGTH, generic.get("manifest_length"));
     Assert.assertEquals("Spec id", SPEC_ID, generic.get("partition_spec_id"));
     Assert.assertEquals("Snapshot id", SNAPSHOT_ID, (long) generic.get("added_snapshot_id"));
-    Assert.assertEquals("Added files count", ADDED_FILES, (int) generic.get("added_data_files_count"));
-    Assert.assertEquals("Existing files count", EXISTING_FILES, (int) generic.get("existing_data_files_count"));
-    Assert.assertEquals("Deleted files count", DELETED_FILES, (int) generic.get("deleted_data_files_count"));
+    Assert.assertEquals(
+        "Added files count", ADDED_FILES, (int) generic.get("added_data_files_count"));
+    Assert.assertEquals(
+        "Existing files count", EXISTING_FILES, (int) generic.get("existing_data_files_count"));
+    Assert.assertEquals(
+        "Deleted files count", DELETED_FILES, (int) generic.get("deleted_data_files_count"));
     Assert.assertEquals("Added rows count", ADDED_ROWS, (long) generic.get("added_rows_count"));
-    Assert.assertEquals("Existing rows count", EXISTING_ROWS, (long) generic.get("existing_rows_count"));
-    Assert.assertEquals("Deleted rows count", DELETED_ROWS, (long) generic.get("deleted_rows_count"));
+    Assert.assertEquals(
+        "Existing rows count", EXISTING_ROWS, (long) generic.get("existing_rows_count"));
+    Assert.assertEquals(
+        "Deleted rows count", DELETED_ROWS, (long) generic.get("deleted_rows_count"));
     AssertHelpers.assertEmptyAvroField(generic, ManifestFile.MANIFEST_CONTENT.name());
     AssertHelpers.assertEmptyAvroField(generic, ManifestFile.SEQUENCE_NUMBER.name());
     AssertHelpers.assertEmptyAvroField(generic, ManifestFile.MIN_SEQUENCE_NUMBER.name());
@@ -144,7 +180,8 @@ public class TestManifestListVersions {
 
   @Test
   public void testV2ForwardCompatibility() throws IOException {
-    // v2 manifest list files can be read by v1 readers, but the sequence numbers and content will be ignored.
+    // v2 manifest list files can be read by v1 readers, but the sequence numbers and content will
+    // be ignored.
     InputFile manifestList = writeManifestList(TEST_MANIFEST, 2);
     GenericData.Record generic = readGeneric(manifestList, V1Metadata.MANIFEST_LIST_SCHEMA);
 
@@ -153,12 +190,17 @@ public class TestManifestListVersions {
     Assert.assertEquals("Length", LENGTH, generic.get("manifest_length"));
     Assert.assertEquals("Spec id", SPEC_ID, generic.get("partition_spec_id"));
     Assert.assertEquals("Snapshot id", SNAPSHOT_ID, (long) generic.get("added_snapshot_id"));
-    Assert.assertEquals("Added files count", ADDED_FILES, (int) generic.get("added_data_files_count"));
-    Assert.assertEquals("Existing files count", EXISTING_FILES, (int) generic.get("existing_data_files_count"));
-    Assert.assertEquals("Deleted files count", DELETED_FILES, (int) generic.get("deleted_data_files_count"));
+    Assert.assertEquals(
+        "Added files count", ADDED_FILES, (int) generic.get("added_data_files_count"));
+    Assert.assertEquals(
+        "Existing files count", EXISTING_FILES, (int) generic.get("existing_data_files_count"));
+    Assert.assertEquals(
+        "Deleted files count", DELETED_FILES, (int) generic.get("deleted_data_files_count"));
     Assert.assertEquals("Added rows count", ADDED_ROWS, (long) generic.get("added_rows_count"));
-    Assert.assertEquals("Existing rows count", EXISTING_ROWS, (long) generic.get("existing_rows_count"));
-    Assert.assertEquals("Deleted rows count", DELETED_ROWS, (long) generic.get("deleted_rows_count"));
+    Assert.assertEquals(
+        "Existing rows count", EXISTING_ROWS, (long) generic.get("existing_rows_count"));
+    Assert.assertEquals(
+        "Deleted rows count", DELETED_ROWS, (long) generic.get("deleted_rows_count"));
     AssertHelpers.assertEmptyAvroField(generic, ManifestFile.MANIFEST_CONTENT.name());
     AssertHelpers.assertEmptyAvroField(generic, ManifestFile.SEQUENCE_NUMBER.name());
     AssertHelpers.assertEmptyAvroField(generic, ManifestFile.MIN_SEQUENCE_NUMBER.name());
@@ -169,30 +211,40 @@ public class TestManifestListVersions {
     File manifestListFile = temp.newFile("manifest-list.avro");
     Assert.assertTrue(manifestListFile.delete());
 
-    Collection<String> columnNamesWithoutRowStats = ImmutableList.of(
-        "manifest_path", "manifest_length", "partition_spec_id", "added_snapshot_id",
-        "added_data_files_count", "existing_data_files_count", "deleted_data_files_count",
-        "partitions");
-    Schema schemaWithoutRowStats = V1Metadata.MANIFEST_LIST_SCHEMA.select(columnNamesWithoutRowStats);
+    Collection<String> columnNamesWithoutRowStats =
+        ImmutableList.of(
+            "manifest_path",
+            "manifest_length",
+            "partition_spec_id",
+            "added_snapshot_id",
+            "added_data_files_count",
+            "existing_data_files_count",
+            "deleted_data_files_count",
+            "partitions");
+    Schema schemaWithoutRowStats =
+        V1Metadata.MANIFEST_LIST_SCHEMA.select(columnNamesWithoutRowStats);
 
     OutputFile outputFile = Files.localOutput(manifestListFile);
-    try (FileAppender<GenericData.Record> appender = Avro.write(outputFile)
-        .schema(schemaWithoutRowStats)
-        .named("manifest_file")
-        .overwrite()
-        .build()) {
+    try (FileAppender<GenericData.Record> appender =
+        Avro.write(outputFile)
+            .schema(schemaWithoutRowStats)
+            .named("manifest_file")
+            .overwrite()
+            .build()) {
 
-      org.apache.avro.Schema avroSchema = AvroSchemaUtil.convert(schemaWithoutRowStats, "manifest_file");
-      GenericData.Record withoutRowStats = new GenericRecordBuilder(avroSchema)
-          .set("manifest_path", "path/to/manifest.avro")
-          .set("manifest_length", 1024L)
-          .set("partition_spec_id", 1)
-          .set("added_snapshot_id", 100L)
-          .set("added_data_files_count", 2)
-          .set("existing_data_files_count", 3)
-          .set("deleted_data_files_count", 4)
-          .set("partitions", null)
-          .build();
+      org.apache.avro.Schema avroSchema =
+          AvroSchemaUtil.convert(schemaWithoutRowStats, "manifest_file");
+      GenericData.Record withoutRowStats =
+          new GenericRecordBuilder(avroSchema)
+              .set("manifest_path", "path/to/manifest.avro")
+              .set("manifest_length", 1024L)
+              .set("partition_spec_id", 1)
+              .set("added_snapshot_id", 100L)
+              .set("added_data_files_count", 2)
+              .set("existing_data_files_count", 3)
+              .set("deleted_data_files_count", 4)
+              .set("partitions", null)
+              .build();
       appender.add(withoutRowStats);
     }
 
@@ -204,7 +256,8 @@ public class TestManifestListVersions {
     Assert.assertNull("Added rows count should be null", manifest.addedRowsCount());
 
     Assert.assertTrue("Existing files should be present", manifest.hasExistingFiles());
-    Assert.assertEquals("Existing files count should match", 3, (int) manifest.existingFilesCount());
+    Assert.assertEquals(
+        "Existing files count should match", 3, (int) manifest.existingFilesCount());
     Assert.assertNull("Existing rows count should be null", manifest.existingRowsCount());
 
     Assert.assertTrue("Deleted files should be present", manifest.hasDeletedFiles());
@@ -219,52 +272,82 @@ public class TestManifestListVersions {
     ByteBuffer secondSummaryLowerBound = Conversions.toByteBuffer(Types.IntegerType.get(), 20);
     ByteBuffer secondSummaryUpperBound = Conversions.toByteBuffer(Types.IntegerType.get(), 200);
 
-    List<ManifestFile.PartitionFieldSummary> partitionFieldSummaries = Lists.newArrayList(
-        new GenericPartitionFieldSummary(false, firstSummaryLowerBound, firstSummaryUpperBound),
-        new GenericPartitionFieldSummary(true, false, secondSummaryLowerBound, secondSummaryUpperBound));
-    ManifestFile manifest = new GenericManifestFile(
-        PATH, LENGTH, SPEC_ID, ManifestContent.DATA, SEQ_NUM, MIN_SEQ_NUM, SNAPSHOT_ID,
-        ADDED_FILES, ADDED_ROWS, EXISTING_FILES, EXISTING_ROWS, DELETED_FILES, DELETED_ROWS,
-        partitionFieldSummaries, KEY_METADATA);
+    List<ManifestFile.PartitionFieldSummary> partitionFieldSummaries =
+        Lists.newArrayList(
+            new GenericPartitionFieldSummary(false, firstSummaryLowerBound, firstSummaryUpperBound),
+            new GenericPartitionFieldSummary(
+                true, false, secondSummaryLowerBound, secondSummaryUpperBound));
+    ManifestFile manifest =
+        new GenericManifestFile(
+            PATH,
+            LENGTH,
+            SPEC_ID,
+            ManifestContent.DATA,
+            SEQ_NUM,
+            MIN_SEQ_NUM,
+            SNAPSHOT_ID,
+            ADDED_FILES,
+            ADDED_ROWS,
+            EXISTING_FILES,
+            EXISTING_ROWS,
+            DELETED_FILES,
+            DELETED_ROWS,
+            partitionFieldSummaries,
+            KEY_METADATA);
 
     InputFile manifestList = writeManifestList(manifest, 2);
 
     List<ManifestFile> files = ManifestLists.read(manifestList);
     ManifestFile returnedManifest = Iterables.getOnlyElement(files);
-    Assert.assertEquals("Number of partition field summaries should match",
-        2, returnedManifest.partitions().size());
+    Assert.assertEquals(
+        "Number of partition field summaries should match",
+        2,
+        returnedManifest.partitions().size());
 
     ManifestFile.PartitionFieldSummary first = returnedManifest.partitions().get(0);
-    Assert.assertFalse("First partition field summary should not contain null", first.containsNull());
+    Assert.assertFalse(
+        "First partition field summary should not contain null", first.containsNull());
     Assert.assertNull("First partition field summary has unknown NaN", first.containsNaN());
-    Assert.assertEquals("Lower bound for first partition field summary should match",
-        firstSummaryLowerBound, first.lowerBound());
-    Assert.assertEquals("Upper bound for first partition field summary should match",
-        firstSummaryUpperBound, first.upperBound());
+    Assert.assertEquals(
+        "Lower bound for first partition field summary should match",
+        firstSummaryLowerBound,
+        first.lowerBound());
+    Assert.assertEquals(
+        "Upper bound for first partition field summary should match",
+        firstSummaryUpperBound,
+        first.upperBound());
 
     ManifestFile.PartitionFieldSummary second = returnedManifest.partitions().get(1);
     Assert.assertTrue("Second partition field summary should contain null", second.containsNull());
-    Assert.assertFalse("Second partition field summary should not contain NaN", second.containsNaN());
-    Assert.assertEquals("Lower bound for second partition field summary should match",
-        secondSummaryLowerBound, second.lowerBound());
-    Assert.assertEquals("Upper bound for second partition field summary should match",
-        secondSummaryUpperBound, second.upperBound());
+    Assert.assertFalse(
+        "Second partition field summary should not contain NaN", second.containsNaN());
+    Assert.assertEquals(
+        "Lower bound for second partition field summary should match",
+        secondSummaryLowerBound,
+        second.lowerBound());
+    Assert.assertEquals(
+        "Upper bound for second partition field summary should match",
+        secondSummaryUpperBound,
+        second.upperBound());
   }
 
   private InputFile writeManifestList(ManifestFile manifest, int formatVersion) throws IOException {
     OutputFile manifestList = new InMemoryOutputFile();
-    try (FileAppender<ManifestFile> writer = ManifestLists.write(
-        formatVersion, manifestList, SNAPSHOT_ID, SNAPSHOT_ID - 1, formatVersion > 1 ? SEQ_NUM : 0)) {
+    try (FileAppender<ManifestFile> writer =
+        ManifestLists.write(
+            formatVersion,
+            manifestList,
+            SNAPSHOT_ID,
+            SNAPSHOT_ID - 1,
+            formatVersion > 1 ? SEQ_NUM : 0)) {
       writer.add(manifest);
     }
     return manifestList.toInputFile();
   }
 
   private GenericData.Record readGeneric(InputFile manifestList, Schema schema) throws IOException {
-    try (CloseableIterable<GenericData.Record> files = Avro.read(manifestList)
-        .project(schema)
-        .reuseContainers(false)
-        .build()) {
+    try (CloseableIterable<GenericData.Record> files =
+        Avro.read(manifestList).project(schema).reuseContainers(false).build()) {
       List<GenericData.Record> records = Lists.newLinkedList(files);
       Assert.assertEquals("Should contain one manifest", 1, records.size());
       return records.get(0);
@@ -272,7 +355,8 @@ public class TestManifestListVersions {
   }
 
   private ManifestFile writeAndReadManifestList(int formatVersion) throws IOException {
-    List<ManifestFile> manifests = ManifestLists.read(writeManifestList(TEST_MANIFEST, formatVersion));
+    List<ManifestFile> manifests =
+        ManifestLists.read(writeManifestList(TEST_MANIFEST, formatVersion));
     Assert.assertEquals("Should contain one manifest", 1, manifests.size());
     return manifests.get(0);
   }
