@@ -78,6 +78,11 @@ public class TestPartitioning {
             NestedField.optional(1001, "category_bucket_8", Types.IntegerType.get()));
     StructType actualType = Partitioning.partitionType(table);
     Assert.assertEquals("Types must match", expectedType, actualType);
+
+    table.updateSpec().removeField("data").removeField("category_bucket_8").commit();
+
+    Assert.assertEquals("Should have 3 specs", 3, table.specs().size());
+    Assert.assertTrue("PartitionSpec should be unpartitioned", table.spec().isUnpartitioned());
   }
 
   @Test
@@ -180,7 +185,7 @@ public class TestPartitioning {
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -195,7 +200,7 @@ public class TestPartitioning {
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -211,7 +216,7 @@ public class TestPartitioning {
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -227,7 +232,7 @@ public class TestPartitioning {
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -243,7 +248,7 @@ public class TestPartitioning {
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "p2", Types.StringType.get()));
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -259,7 +264,7 @@ public class TestPartitioning {
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "p2", Types.StringType.get()));
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -273,7 +278,7 @@ public class TestPartitioning {
     Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
 
     StructType expectedType = StructType.of();
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -287,7 +292,7 @@ public class TestPartitioning {
     Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
 
     StructType expectedType = StructType.of();
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -302,7 +307,7 @@ public class TestPartitioning {
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "category", Types.StringType.get()));
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -317,7 +322,7 @@ public class TestPartitioning {
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "category", Types.StringType.get()));
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -330,7 +335,7 @@ public class TestPartitioning {
     Assert.assertEquals("Should have 1 spec", 1, table.specs().size());
 
     StructType expectedType = StructType.of();
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -345,7 +350,20 @@ public class TestPartitioning {
     Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
 
     StructType expectedType = StructType.of();
-    StructType actualType = Partitioning.groupingKeyType(table.specs().values());
+    StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
+    Assert.assertEquals("Types must match", expectedType, actualType);
+  }
+
+  @Test
+  public void testGroupingKeyTypeWithProjectedSchema() {
+    TestTables.TestTable table =
+        TestTables.create(tableDir, "test", SCHEMA, BY_CATEGORY_DATA_SPEC, V1_FORMAT_VERSION);
+
+    Schema projectedSchema = table.schema().select("id", "data");
+
+    StructType expectedType =
+        StructType.of(NestedField.optional(1001, "data", Types.StringType.get()));
+    StructType actualType = Partitioning.groupingKeyType(projectedSchema, table.specs().values());
     Assert.assertEquals("Types must match", expectedType, actualType);
   }
 
@@ -366,6 +384,6 @@ public class TestPartitioning {
         "Should complain about incompatible specs",
         ValidationException.class,
         "Conflicting partition fields",
-        () -> Partitioning.groupingKeyType(table.specs().values()));
+        () -> Partitioning.groupingKeyType(table.schema(), table.specs().values()));
   }
 }
