@@ -18,6 +18,8 @@
  */
 package org.apache.iceberg;
 
+import static org.apache.iceberg.util.SnapshotUtil.latestSnapshot;
+
 import java.io.File;
 import java.io.IOException;
 import org.apache.iceberg.ManifestEntry.Status;
@@ -70,40 +72,48 @@ public class TestReplacePartitions extends TableTestBase {
           .withRecordCount(1)
           .build();
 
-  @Parameterized.Parameters(name = "formatVersion = {0}")
+  private final String branch;
+
+  @Parameterized.Parameters(name = "formatVersion = {0}, branch = {1}")
   public static Object[] parameters() {
-    return new Object[] {1, 2};
+    return new Object[][] {
+      new Object[] {1, "main"},
+      new Object[] {1, "testBranch"},
+      new Object[] {2, "main"},
+      new Object[] {2, "testBranch"}
+    };
   }
 
-  public TestReplacePartitions(int formatVersion) {
+  public TestReplacePartitions(int formatVersion, String branch) {
     super(formatVersion);
+    this.branch = branch;
   }
 
   @Test
   public void testReplaceOnePartition() {
-    table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
-    table.newReplacePartitions().addFile(FILE_E).commit();
+    commit(table, table.newReplacePartitions().addFile(FILE_E), branch);
 
-    long replaceId = readMetadata().currentSnapshot().snapshotId();
+    long replaceId = latestSnapshot(readMetadata(), branch).snapshotId();
     Assert.assertNotEquals("Should create a new snapshot", baseId, replaceId);
     Assert.assertEquals(
         "Table should have 2 manifests",
         2,
-        table.currentSnapshot().allManifests(table.io()).size());
+        latestSnapshot(table, branch).allManifests(table.io()).size());
 
     // manifest is not merged because it is less than the minimum
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(replaceId),
         files(FILE_E),
         statuses(Status.ADDED));
 
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(1),
+        latestSnapshot(table, branch).allManifests(table.io()).get(1),
         ids(replaceId, baseId),
         files(FILE_A, FILE_B),
         statuses(Status.DELETED, Status.EXISTING));
@@ -114,20 +124,22 @@ public class TestReplacePartitions extends TableTestBase {
     // ensure the overwrite results in a merge
     table.updateProperties().set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "1").commit();
 
-    table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
-    table.newReplacePartitions().addFile(FILE_E).commit();
+    commit(table, table.newReplacePartitions().addFile(FILE_E), branch);
 
-    long replaceId = readMetadata().currentSnapshot().snapshotId();
+    long replaceId = latestSnapshot(table, branch).snapshotId();
     Assert.assertNotEquals("Should create a new snapshot", baseId, replaceId);
     Assert.assertEquals(
-        "Table should have 1 manifest", 1, table.currentSnapshot().allManifests(table.io()).size());
+        "Table should have 1 manifest",
+        1,
+        latestSnapshot(table, branch).allManifests(table.io()).size());
 
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(replaceId, replaceId, baseId),
         files(FILE_E, FILE_A, FILE_B),
         statuses(Status.ADDED, Status.DELETED, Status.EXISTING));
@@ -145,33 +157,34 @@ public class TestReplacePartitions extends TableTestBase {
     Assert.assertEquals(
         "Table version should be 0", 0, (long) TestTables.metadataVersion("unpartitioned"));
 
-    unpartitioned.newAppend().appendFile(FILE_A).commit();
-
+    commit(table, unpartitioned.newAppend().appendFile(FILE_A), branch);
     // make sure the data was successfully added
     Assert.assertEquals(
         "Table version should be 1", 1, (long) TestTables.metadataVersion("unpartitioned"));
-    validateSnapshot(null, TestTables.readMetadata("unpartitioned").currentSnapshot(), FILE_A);
+    validateSnapshot(
+        null, latestSnapshot(TestTables.readMetadata("unpartitioned"), branch), FILE_A);
 
-    unpartitioned.newReplacePartitions().addFile(FILE_B).commit();
+    ReplacePartitions replacePartitions = unpartitioned.newReplacePartitions().addFile(FILE_B);
+    commit(table, replacePartitions, branch);
 
     Assert.assertEquals(
         "Table version should be 2", 2, (long) TestTables.metadataVersion("unpartitioned"));
     TableMetadata replaceMetadata = TestTables.readMetadata("unpartitioned");
-    long replaceId = replaceMetadata.currentSnapshot().snapshotId();
+    long replaceId = latestSnapshot(replaceMetadata, branch).snapshotId();
 
     Assert.assertEquals(
         "Table should have 2 manifests",
         2,
-        replaceMetadata.currentSnapshot().allManifests(unpartitioned.io()).size());
+        latestSnapshot(replaceMetadata, branch).allManifests(unpartitioned.io()).size());
 
     validateManifestEntries(
-        replaceMetadata.currentSnapshot().allManifests(unpartitioned.io()).get(0),
+        latestSnapshot(replaceMetadata, branch).allManifests(unpartitioned.io()).get(0),
         ids(replaceId),
         files(FILE_B),
         statuses(Status.ADDED));
 
     validateManifestEntries(
-        replaceMetadata.currentSnapshot().allManifests(unpartitioned.io()).get(1),
+        latestSnapshot(replaceMetadata, branch).allManifests(unpartitioned.io()).get(1),
         ids(replaceId),
         files(FILE_A),
         statuses(Status.DELETED));
@@ -192,27 +205,30 @@ public class TestReplacePartitions extends TableTestBase {
     Assert.assertEquals(
         "Table version should be 1", 1, (long) TestTables.metadataVersion("unpartitioned"));
 
-    unpartitioned.newAppend().appendFile(FILE_A).commit();
+    AppendFiles appendFiles = unpartitioned.newAppend().appendFile(FILE_A);
+    commit(table, appendFiles, branch);
 
     // make sure the data was successfully added
     Assert.assertEquals(
         "Table version should be 2", 2, (long) TestTables.metadataVersion("unpartitioned"));
-    validateSnapshot(null, TestTables.readMetadata("unpartitioned").currentSnapshot(), FILE_A);
+    validateSnapshot(
+        null, latestSnapshot(TestTables.readMetadata("unpartitioned"), branch), FILE_A);
 
-    unpartitioned.newReplacePartitions().addFile(FILE_B).commit();
+    ReplacePartitions replacePartitions = unpartitioned.newReplacePartitions().addFile(FILE_B);
+    commit(table, replacePartitions, branch);
 
     Assert.assertEquals(
         "Table version should be 3", 3, (long) TestTables.metadataVersion("unpartitioned"));
     TableMetadata replaceMetadata = TestTables.readMetadata("unpartitioned");
-    long replaceId = replaceMetadata.currentSnapshot().snapshotId();
+    long replaceId = latestSnapshot(replaceMetadata, branch).snapshotId();
 
     Assert.assertEquals(
         "Table should have 1 manifest",
         1,
-        replaceMetadata.currentSnapshot().allManifests(unpartitioned.io()).size());
+        latestSnapshot(replaceMetadata, branch).allManifests(unpartitioned.io()).size());
 
     validateManifestEntries(
-        replaceMetadata.currentSnapshot().allManifests(unpartitioned.io()).get(0),
+        latestSnapshot(replaceMetadata, branch).allManifests(unpartitioned.io()).get(0),
         ids(replaceId, replaceId),
         files(FILE_B, FILE_A),
         statuses(Status.ADDED, Status.DELETED));
@@ -220,10 +236,10 @@ public class TestReplacePartitions extends TableTestBase {
 
   @Test
   public void testValidationFailure() {
-    table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
     ReplacePartitions replace =
         table.newReplacePartitions().addFile(FILE_F).addFile(FILE_G).validateAppendOnly();
@@ -232,37 +248,39 @@ public class TestReplacePartitions extends TableTestBase {
         "Should reject commit with file not matching delete expression",
         ValidationException.class,
         "Cannot commit file that conflicts with existing partition",
-        replace::commit);
+        () -> commit(table, replace, branch));
 
     Assert.assertEquals(
-        "Should not create a new snapshot", baseId, readMetadata().currentSnapshot().snapshotId());
+        "Should not create a new snapshot",
+        baseId,
+        latestSnapshot(readMetadata(), branch).snapshotId());
   }
 
   @Test
   public void testValidationSuccess() {
-    table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
-    table.newReplacePartitions().addFile(FILE_G).validateAppendOnly().commit();
+    commit(table, table.newReplacePartitions().addFile(FILE_G).validateAppendOnly(), branch);
 
-    long replaceId = readMetadata().currentSnapshot().snapshotId();
+    long replaceId = latestSnapshot(readMetadata(), branch).snapshotId();
     Assert.assertNotEquals("Should create a new snapshot", baseId, replaceId);
     Assert.assertEquals(
         "Table should have 2 manifests",
         2,
-        table.currentSnapshot().allManifests(table.io()).size());
+        latestSnapshot(table, branch).allManifests(table.io()).size());
 
     // manifest is not merged because it is less than the minimum
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(replaceId),
         files(FILE_G),
         statuses(Status.ADDED));
 
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(1),
+        latestSnapshot(table, branch).allManifests(table.io()).get(1),
         ids(baseId, baseId),
         files(FILE_A, FILE_B),
         statuses(Status.ADDED, Status.ADDED));
@@ -270,33 +288,39 @@ public class TestReplacePartitions extends TableTestBase {
 
   @Test
   public void testValidationNotInvoked() {
-    table.newFastAppend().appendFile(FILE_A).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A), branch);
 
     TableMetadata base = readMetadata();
 
     // Two concurrent ReplacePartitions with No Validation Enabled
-    table
-        .newReplacePartitions()
-        .addFile(FILE_E)
-        .validateFromSnapshot(base.currentSnapshot().snapshotId())
-        .commit();
-    table
-        .newReplacePartitions()
-        .addFile(FILE_A) // Replaces FILE_E which becomes Deleted
-        .addFile(FILE_B)
-        .validateFromSnapshot(base.currentSnapshot().snapshotId())
-        .commit();
+    commit(
+        table,
+        table
+            .newReplacePartitions()
+            .addFile(FILE_E)
+            .validateFromSnapshot(latestSnapshot(base, branch).snapshotId()),
+        branch);
+    commit(
+        table,
+        table
+            .newReplacePartitions()
+            .addFile(FILE_A) // Replaces FILE_E which becomes Deleted
+            .addFile(FILE_B)
+            .validateFromSnapshot(latestSnapshot(base, branch).snapshotId()),
+        branch);
 
-    long replaceId = readMetadata().currentSnapshot().snapshotId();
+    long replaceId = latestSnapshot(readMetadata(), branch).snapshotId();
     Assert.assertEquals(
-        "Table should have 2 manifest", 2, table.currentSnapshot().allManifests(table.io()).size());
+        "Table should have 2 manifest",
+        2,
+        latestSnapshot(table, branch).allManifests(table.io()).size());
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(replaceId, replaceId),
         files(FILE_A, FILE_B),
         statuses(Status.ADDED, Status.ADDED));
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(1),
+        latestSnapshot(table, branch).allManifests(table.io()).get(1),
         ids(replaceId),
         files(FILE_E),
         statuses(Status.DELETED));
@@ -304,7 +328,7 @@ public class TestReplacePartitions extends TableTestBase {
 
   @Test
   public void testValidateWithDefaultSnapshotId() {
-    table.newReplacePartitions().addFile(FILE_A).commit();
+    commit(table, table.newReplacePartitions().addFile(FILE_A), branch);
 
     // Concurrent Replace Partitions should fail with ValidationException
     ReplacePartitions replace = table.newReplacePartitions();
@@ -314,23 +338,25 @@ public class TestReplacePartitions extends TableTestBase {
         "Found conflicting files that can contain records matching partitions "
             + "[data_bucket=0, data_bucket=1]: [/path/to/data-a.parquet]",
         () ->
-            replace
-                .addFile(FILE_A)
-                .addFile(FILE_B)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .commit());
+            commit(
+                table,
+                replace
+                    .addFile(FILE_A)
+                    .addFile(FILE_B)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes(),
+                branch));
   }
 
   @Test
   public void testConcurrentReplaceConflict() {
-    table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
     // Concurrent Replace Partitions should fail with ValidationException
-    table.newReplacePartitions().addFile(FILE_A).commit();
+    commit(table, table.newReplacePartitions().addFile(FILE_A), branch);
 
     AssertHelpers.assertThrows(
         "Should reject commit with file matching partitions replaced",
@@ -338,47 +364,51 @@ public class TestReplacePartitions extends TableTestBase {
         "Found conflicting files that can contain records matching partitions "
             + "[data_bucket=0, data_bucket=1]: [/path/to/data-a.parquet]",
         () ->
-            table
-                .newReplacePartitions()
-                .validateFromSnapshot(baseId)
-                .addFile(FILE_A)
-                .addFile(FILE_B)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .commit());
+            commit(
+                table,
+                table
+                    .newReplacePartitions()
+                    .validateFromSnapshot(baseId)
+                    .addFile(FILE_A)
+                    .addFile(FILE_B)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes(),
+                branch));
   }
 
   @Test
   public void testConcurrentReplaceNoConflict() {
-    table.newFastAppend().appendFile(FILE_A).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A), branch);
 
     TableMetadata base = readMetadata();
-    long id1 = base.currentSnapshot().snapshotId();
+    long id1 = latestSnapshot(base, branch).snapshotId();
 
     // Concurrent Replace Partitions should not fail if concerning different partitions
-    table.newReplacePartitions().addFile(FILE_A).commit();
-    long id2 = readMetadata().currentSnapshot().snapshotId();
+    commit(table, table.newReplacePartitions().addFile(FILE_A), branch);
+    long id2 = latestSnapshot(readMetadata(), branch).snapshotId();
 
-    table
-        .newReplacePartitions()
-        .validateFromSnapshot(id1)
-        .validateNoConflictingData()
-        .validateNoConflictingDeletes()
-        .addFile(FILE_B)
-        .commit();
+    commit(
+        table,
+        table
+            .newReplacePartitions()
+            .validateFromSnapshot(id1)
+            .validateNoConflictingData()
+            .validateNoConflictingDeletes()
+            .addFile(FILE_B),
+        branch);
 
-    long id3 = readMetadata().currentSnapshot().snapshotId();
+    long id3 = latestSnapshot(readMetadata(), branch).snapshotId();
     Assert.assertEquals(
         "Table should have 2 manifests",
         2,
-        table.currentSnapshot().allManifests(table.io()).size());
+        latestSnapshot(table, branch).allManifests(table.io()).size());
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(id3),
         files(FILE_B),
         statuses(Status.ADDED));
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(1),
+        latestSnapshot(table, branch).allManifests(table.io()).get(1),
         ids(id2),
         files(FILE_A),
         statuses(Status.ADDED));
@@ -389,13 +419,13 @@ public class TestReplacePartitions extends TableTestBase {
     Table unpartitioned =
         TestTables.create(
             tableDir, "unpartitioned", SCHEMA, PartitionSpec.unpartitioned(), formatVersion);
-    unpartitioned.newAppend().appendFile(FILE_UNPARTITIONED_A).commit();
+    commit(table, unpartitioned.newAppend().appendFile(FILE_UNPARTITIONED_A), branch);
 
     TableMetadata replaceMetadata = TestTables.readMetadata("unpartitioned");
-    long replaceBaseId = replaceMetadata.currentSnapshot().snapshotId();
+    long replaceBaseId = latestSnapshot(replaceMetadata, branch).snapshotId();
 
     // Concurrent ReplacePartitions should fail with ValidationException
-    unpartitioned.newReplacePartitions().addFile(FILE_UNPARTITIONED_A).commit();
+    commit(table, unpartitioned.newReplacePartitions().addFile(FILE_UNPARTITIONED_A), branch);
 
     AssertHelpers.assertThrows(
         "Should reject commit with file matching partitions replaced",
@@ -403,24 +433,26 @@ public class TestReplacePartitions extends TableTestBase {
         "Found conflicting files that can contain records matching true: "
             + "[/path/to/data-unpartitioned-a.parquet]",
         () ->
-            unpartitioned
-                .newReplacePartitions()
-                .validateFromSnapshot(replaceBaseId)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .addFile(FILE_UNPARTITIONED_A)
-                .commit());
+            commit(
+                table,
+                unpartitioned
+                    .newReplacePartitions()
+                    .validateFromSnapshot(replaceBaseId)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes()
+                    .addFile(FILE_UNPARTITIONED_A),
+                branch));
   }
 
   @Test
   public void testAppendReplaceConflict() {
-    table.newFastAppend().appendFile(FILE_A).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
     // Concurrent Append and ReplacePartition should fail with ValidationException
-    table.newFastAppend().appendFile(FILE_B).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_B), branch);
 
     AssertHelpers.assertThrows(
         "Should reject commit with file matching partitions replaced",
@@ -428,53 +460,57 @@ public class TestReplacePartitions extends TableTestBase {
         "Found conflicting files that can contain records matching partitions "
             + "[data_bucket=0, data_bucket=1]: [/path/to/data-b.parquet]",
         () ->
-            table
-                .newReplacePartitions()
-                .validateFromSnapshot(baseId)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .addFile(FILE_A)
-                .addFile(FILE_B)
-                .commit());
+            commit(
+                table,
+                table
+                    .newReplacePartitions()
+                    .validateFromSnapshot(baseId)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes()
+                    .addFile(FILE_A)
+                    .addFile(FILE_B),
+                branch));
   }
 
   @Test
   public void testAppendReplaceNoConflict() {
-    table.newFastAppend().appendFile(FILE_A).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A), branch);
 
     TableMetadata base = readMetadata();
-    long id1 = base.currentSnapshot().snapshotId();
+    long id1 = latestSnapshot(base, branch).snapshotId();
 
     // Concurrent Append and ReplacePartition should not conflict if concerning different partitions
-    table.newFastAppend().appendFile(FILE_B).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_B), branch);
 
-    long id2 = readMetadata().currentSnapshot().snapshotId();
+    long id2 = latestSnapshot(readMetadata(), branch).snapshotId();
 
-    table
-        .newReplacePartitions()
-        .validateFromSnapshot(id1)
-        .validateNoConflictingData()
-        .validateNoConflictingDeletes()
-        .addFile(FILE_A)
-        .commit();
+    commit(
+        table,
+        table
+            .newReplacePartitions()
+            .validateFromSnapshot(id1)
+            .validateNoConflictingData()
+            .validateNoConflictingDeletes()
+            .addFile(FILE_A),
+        branch);
 
-    long id3 = readMetadata().currentSnapshot().snapshotId();
+    long id3 = latestSnapshot(readMetadata(), branch).snapshotId();
     Assert.assertEquals(
         "Table should have 3 manifests",
         3,
-        table.currentSnapshot().allManifests(table.io()).size());
+        latestSnapshot(table, branch).allManifests(table.io()).size());
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(id3),
         files(FILE_A),
         statuses(Status.ADDED));
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(1),
+        latestSnapshot(table, branch).allManifests(table.io()).get(1),
         ids(id2),
         files(FILE_B),
         statuses(Status.ADDED));
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(2),
+        latestSnapshot(table, branch).allManifests(table.io()).get(2),
         ids(id3),
         files(FILE_A),
         statuses(Status.DELETED));
@@ -485,13 +521,13 @@ public class TestReplacePartitions extends TableTestBase {
     Table unpartitioned =
         TestTables.create(
             tableDir, "unpartitioned", SCHEMA, PartitionSpec.unpartitioned(), formatVersion);
-    unpartitioned.newAppend().appendFile(FILE_UNPARTITIONED_A).commit();
+    commit(table, unpartitioned.newAppend().appendFile(FILE_UNPARTITIONED_A), branch);
 
     TableMetadata replaceMetadata = TestTables.readMetadata("unpartitioned");
-    long replaceBaseId = replaceMetadata.currentSnapshot().snapshotId();
+    long replaceBaseId = latestSnapshot(replaceMetadata, branch).snapshotId();
 
     // Concurrent Append and ReplacePartitions should fail with ValidationException
-    unpartitioned.newAppend().appendFile(FILE_UNPARTITIONED_A).commit();
+    commit(table, unpartitioned.newAppend().appendFile(FILE_UNPARTITIONED_A), branch);
 
     AssertHelpers.assertThrows(
         "Should reject commit with file matching partitions replaced",
@@ -499,25 +535,28 @@ public class TestReplacePartitions extends TableTestBase {
         "Found conflicting files that can contain records matching true: "
             + "[/path/to/data-unpartitioned-a.parquet]",
         () ->
-            unpartitioned
-                .newReplacePartitions()
-                .validateFromSnapshot(replaceBaseId)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .addFile(FILE_UNPARTITIONED_A)
-                .commit());
+            commit(
+                table,
+                unpartitioned
+                    .newReplacePartitions()
+                    .validateFromSnapshot(replaceBaseId)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes()
+                    .addFile(FILE_UNPARTITIONED_A),
+                branch));
   }
 
   @Test
   public void testDeleteReplaceConflict() {
     Assume.assumeTrue(formatVersion == 2);
-    table.newFastAppend().appendFile(FILE_A).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
     // Concurrent Delete and ReplacePartition should fail with ValidationException
-    table.newRowDelta().addDeletes(FILE_A_DELETES).validateFromSnapshot(baseId).commit();
+    commit(
+        table, table.newRowDelta().addDeletes(FILE_A_DELETES).validateFromSnapshot(baseId), branch);
 
     AssertHelpers.assertThrows(
         "Should reject commit with file matching partitions replaced",
@@ -525,13 +564,15 @@ public class TestReplacePartitions extends TableTestBase {
         "Found new conflicting delete files that can apply to records matching "
             + "[data_bucket=0]: [/path/to/data-a-deletes.parquet]",
         () ->
-            table
-                .newReplacePartitions()
-                .validateFromSnapshot(baseId)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .addFile(FILE_A)
-                .commit());
+            commit(
+                table,
+                table
+                    .newReplacePartitions()
+                    .validateFromSnapshot(baseId)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes()
+                    .addFile(FILE_A),
+                branch));
   }
 
   @Test
@@ -541,13 +582,13 @@ public class TestReplacePartitions extends TableTestBase {
     Table unpartitioned =
         TestTables.create(
             tableDir, "unpartitioned", SCHEMA, PartitionSpec.unpartitioned(), formatVersion);
-    unpartitioned.newAppend().appendFile(FILE_A).commit();
+    commit(table, unpartitioned.newAppend().appendFile(FILE_A), branch);
 
     TableMetadata replaceMetadata = TestTables.readMetadata("unpartitioned");
-    long replaceBaseId = replaceMetadata.currentSnapshot().snapshotId();
+    long replaceBaseId = latestSnapshot(replaceMetadata, branch).snapshotId();
 
     // Concurrent Delete and ReplacePartitions should fail with ValidationException
-    unpartitioned.newRowDelta().addDeletes(FILE_UNPARTITIONED_A_DELETES).commit();
+    commit(table, unpartitioned.newRowDelta().addDeletes(FILE_UNPARTITIONED_A_DELETES), branch);
 
     AssertHelpers.assertThrows(
         "Should reject commit with file matching partitions replaced",
@@ -555,55 +596,65 @@ public class TestReplacePartitions extends TableTestBase {
         "Found new conflicting delete files that can apply to records matching true: "
             + "[/path/to/data-unpartitioned-a-deletes.parquet]",
         () ->
-            unpartitioned
-                .newReplacePartitions()
-                .validateFromSnapshot(replaceBaseId)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .addFile(FILE_UNPARTITIONED_A)
-                .commit());
+            commit(
+                table,
+                unpartitioned
+                    .newReplacePartitions()
+                    .validateFromSnapshot(replaceBaseId)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes()
+                    .addFile(FILE_UNPARTITIONED_A),
+                branch));
   }
 
   @Test
   public void testDeleteReplaceNoConflict() {
     Assume.assumeTrue(formatVersion == 2);
-    table.newFastAppend().appendFile(FILE_A).commit();
-    long id1 = readMetadata().currentSnapshot().snapshotId();
+    commit(table, table.newFastAppend().appendFile(FILE_A), branch);
+    long id1 = latestSnapshot(readMetadata(), branch).snapshotId();
 
     // Concurrent Delta and ReplacePartition should not conflict if concerning different partitions
-    table
-        .newRowDelta()
-        .addDeletes(FILE_A_DELETES)
-        .validateFromSnapshot(id1)
-        .validateNoConflictingDataFiles()
-        .validateNoConflictingDeleteFiles()
-        .validateFromSnapshot(id1)
-        .commit();
-    long id2 = readMetadata().currentSnapshot().snapshotId();
+    commit(
+        table,
+        table
+            .newRowDelta()
+            .addDeletes(FILE_A_DELETES)
+            .validateFromSnapshot(id1)
+            .validateNoConflictingDataFiles()
+            .validateNoConflictingDeleteFiles()
+            .validateFromSnapshot(id1),
+        branch);
 
-    table
-        .newReplacePartitions()
-        .validateNoConflictingData()
-        .validateNoConflictingDeletes()
-        .validateFromSnapshot(id1)
-        .addFile(FILE_B)
-        .commit();
-    long id3 = readMetadata().currentSnapshot().snapshotId();
+    long id2 = latestSnapshot(readMetadata(), branch).snapshotId();
+
+    commit(
+        table,
+        table
+            .newReplacePartitions()
+            .validateNoConflictingData()
+            .validateNoConflictingDeletes()
+            .validateFromSnapshot(id1)
+            .addFile(FILE_B),
+        branch);
+
+    long id3 = latestSnapshot(readMetadata(), branch).snapshotId();
 
     Assert.assertEquals(
-        "Table should have 3 manifest", 3, table.currentSnapshot().allManifests(table.io()).size());
+        "Table should have 3 manifest",
+        3,
+        latestSnapshot(table, branch).allManifests(table.io()).size());
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(id3),
         files(FILE_B),
         statuses(Status.ADDED));
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(1),
+        latestSnapshot(table, branch).allManifests(table.io()).get(1),
         ids(id1),
         files(FILE_A),
         statuses(Status.ADDED));
     validateDeleteManifest(
-        table.currentSnapshot().allManifests(table.io()).get(2),
+        latestSnapshot(table, branch).allManifests(table.io()).get(2),
         dataSeqs(2L),
         fileSeqs(2L),
         ids(id2),
@@ -614,13 +665,13 @@ public class TestReplacePartitions extends TableTestBase {
   @Test
   public void testOverwriteReplaceConflict() {
     Assume.assumeTrue(formatVersion == 2);
-    table.newFastAppend().appendFile(FILE_A).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
     // Concurrent Overwrite and ReplacePartition should fail with ValidationException
-    table.newOverwrite().deleteFile(FILE_A).commit();
+    commit(table, table.newOverwrite().deleteFile(FILE_A), branch);
 
     AssertHelpers.assertThrows(
         "Should reject commit with file matching partitions replaced",
@@ -628,46 +679,52 @@ public class TestReplacePartitions extends TableTestBase {
         "Found conflicting deleted files that can apply to records matching "
             + "[data_bucket=0]: [/path/to/data-a.parquet]",
         () ->
-            table
-                .newReplacePartitions()
-                .validateFromSnapshot(baseId)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .addFile(FILE_A)
-                .commit());
+            commit(
+                table,
+                table
+                    .newReplacePartitions()
+                    .validateFromSnapshot(baseId)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes()
+                    .addFile(FILE_A),
+                branch));
   }
 
   @Test
   public void testOverwriteReplaceNoConflict() {
     Assume.assumeTrue(formatVersion == 2);
-    table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
+    commit(table, table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
 
     TableMetadata base = readMetadata();
-    long baseId = base.currentSnapshot().snapshotId();
+    long baseId = latestSnapshot(base, branch).snapshotId();
 
     // Concurrent Overwrite and ReplacePartition should not fail with if concerning different
     // partitions
-    table.newOverwrite().deleteFile(FILE_A).commit();
+    commit(table, table.newOverwrite().deleteFile(FILE_A), branch);
 
-    table
-        .newReplacePartitions()
-        .validateNoConflictingData()
-        .validateNoConflictingDeletes()
-        .validateFromSnapshot(baseId)
-        .addFile(FILE_B)
-        .commit();
+    commit(
+        table,
+        table
+            .newReplacePartitions()
+            .validateNoConflictingData()
+            .validateNoConflictingDeletes()
+            .validateFromSnapshot(baseId)
+            .addFile(FILE_B),
+        branch);
 
-    long finalId = readMetadata().currentSnapshot().snapshotId();
+    long finalId = latestSnapshot(readMetadata(), branch).snapshotId();
 
     Assert.assertEquals(
-        "Table should have 2 manifest", 2, table.currentSnapshot().allManifests(table.io()).size());
+        "Table should have 2 manifest",
+        2,
+        latestSnapshot(table, branch).allManifests(table.io()).size());
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(finalId),
         files(FILE_B),
         statuses(Status.ADDED));
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(1),
+        latestSnapshot(table, branch).allManifests(table.io()).get(1),
         ids(finalId),
         files(FILE_B),
         statuses(Status.DELETED));
@@ -681,13 +738,13 @@ public class TestReplacePartitions extends TableTestBase {
         TestTables.create(
             tableDir, "unpartitioned", SCHEMA, PartitionSpec.unpartitioned(), formatVersion);
 
-    unpartitioned.newAppend().appendFile(FILE_UNPARTITIONED_A).commit();
+    commit(table, unpartitioned.newAppend().appendFile(FILE_UNPARTITIONED_A), branch);
 
     TableMetadata replaceMetadata = TestTables.readMetadata("unpartitioned");
-    long replaceBaseId = replaceMetadata.currentSnapshot().snapshotId();
+    long replaceBaseId = latestSnapshot(replaceMetadata, branch).snapshotId();
 
     // Concurrent Overwrite and ReplacePartitions should fail with ValidationException
-    unpartitioned.newOverwrite().deleteFile(FILE_UNPARTITIONED_A).commit();
+    commit(table, unpartitioned.newOverwrite().deleteFile(FILE_UNPARTITIONED_A), branch);
 
     AssertHelpers.assertThrows(
         "Should reject commit with file matching partitions replaced",
@@ -695,45 +752,51 @@ public class TestReplacePartitions extends TableTestBase {
         "Found conflicting deleted files that can contain records matching true: "
             + "[/path/to/data-unpartitioned-a.parquet]",
         () ->
-            unpartitioned
-                .newReplacePartitions()
-                .validateFromSnapshot(replaceBaseId)
-                .validateNoConflictingData()
-                .validateNoConflictingDeletes()
-                .addFile(FILE_UNPARTITIONED_A)
-                .commit());
+            commit(
+                table,
+                unpartitioned
+                    .newReplacePartitions()
+                    .validateFromSnapshot(replaceBaseId)
+                    .validateNoConflictingData()
+                    .validateNoConflictingDeletes()
+                    .addFile(FILE_UNPARTITIONED_A),
+                branch));
   }
 
   @Test
   public void testValidateOnlyDeletes() {
-    table.newAppend().appendFile(FILE_A).commit();
-    long baseId = readMetadata().currentSnapshot().snapshotId();
+    commit(table, table.newAppend().appendFile(FILE_A), branch);
+    long baseId = latestSnapshot(readMetadata(), branch).snapshotId();
 
     // Snapshot Isolation mode: appends do not conflict with replace
-    table.newAppend().appendFile(FILE_B).commit();
+    commit(table, table.newAppend().appendFile(FILE_B), branch);
 
-    table
-        .newReplacePartitions()
-        .validateFromSnapshot(baseId)
-        .validateNoConflictingDeletes()
-        .addFile(FILE_B)
-        .commit();
-    long finalId = readMetadata().currentSnapshot().snapshotId();
+    commit(
+        table,
+        table
+            .newReplacePartitions()
+            .validateFromSnapshot(baseId)
+            .validateNoConflictingDeletes()
+            .addFile(FILE_B),
+        branch);
+    long finalId = latestSnapshot(readMetadata(), branch).snapshotId();
 
     Assert.assertEquals(
-        "Table should have 3 manifest", 3, table.currentSnapshot().allManifests(table.io()).size());
+        "Table should have 3 manifest",
+        3,
+        latestSnapshot(table, branch).allManifests(table.io()).size());
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(0),
+        latestSnapshot(table, branch).allManifests(table.io()).get(0),
         ids(finalId),
         files(FILE_B),
         statuses(Status.ADDED));
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(1),
+        latestSnapshot(table, branch).allManifests(table.io()).get(1),
         ids(finalId),
         files(FILE_B),
         statuses(Status.DELETED));
     validateManifestEntries(
-        table.currentSnapshot().allManifests(table.io()).get(2),
+        latestSnapshot(table, branch).allManifests(table.io()).get(2),
         ids(baseId),
         files(FILE_A),
         statuses(Status.ADDED));
@@ -743,13 +806,4 @@ public class TestReplacePartitions extends TableTestBase {
   public void testEmptyPartitionPathWithUnpartitionedTable() {
     DataFiles.builder(PartitionSpec.unpartitioned()).withPartitionPath("");
   }
-
-  @Test
-  public void testReplacePartitionsOnBranchUnsupported() {
-    AssertHelpers.assertThrows(
-        "Should reject committing rewrite manifests to branch",
-        UnsupportedOperationException.class,
-        "Cannot commit to branch someBranch: org.apache.iceberg.BaseReplacePartitions does not support branch commits",
-        () -> table.newReplacePartitions().addFile(FILE_UNPARTITIONED_A).toBranch("someBranch"));
-  }
 }
