@@ -632,4 +632,82 @@ public class TestSnapshotManager extends TableTestBase {
     long currentSnapshotId = table.currentSnapshot().snapshotId();
     table.manageSnapshots().rollbackTo(currentSnapshotId).commit();
   }
+
+  @Test
+  public void testSnapshotManagerThroughTransaction() {
+    table.newAppend().appendFile(FILE_A).commit();
+    Snapshot snapshotAfterFirstAppend = readMetadata().currentSnapshot();
+    validateSnapshot(null, snapshotAfterFirstAppend, FILE_A);
+
+    table.newAppend().appendFile(FILE_B).commit();
+    validateSnapshot(snapshotAfterFirstAppend, readMetadata().currentSnapshot(), FILE_B);
+    Assert.assertEquals("Table should be on version 2 after appending twice", 2, (int) version());
+
+    TableMetadata base = readMetadata();
+    Transaction txn = table.newTransaction();
+
+    Assert.assertSame(
+        "Base metadata should not change when transaction is created", base, readMetadata());
+    Assert.assertEquals(
+        "Table should be on version 2 after creating transaction", 2, (int) version());
+
+    ManageSnapshots manageSnapshots = txn.manageSnapshots();
+    Assert.assertNotNull(manageSnapshots);
+
+    Assert.assertSame(
+        "Base metadata should not change when manageSnapshots is created", base, readMetadata());
+    Assert.assertEquals(
+        "Table should be on version 2 after creating manageSnapshots", 2, (int) version());
+
+    manageSnapshots.rollbackTo(snapshotAfterFirstAppend.snapshotId()).commit();
+
+    Assert.assertSame(
+        "Base metadata should not change when invoking rollbackTo", base, readMetadata());
+    Assert.assertEquals(
+        "Table should be on version 2 after invoking rollbackTo", 2, (int) version());
+
+    txn.commitTransaction();
+
+    Assert.assertEquals(snapshotAfterFirstAppend, readMetadata().currentSnapshot());
+    validateSnapshot(null, snapshotAfterFirstAppend, FILE_A);
+    Assert.assertEquals(
+        "Table should be on version 3 after invoking rollbackTo", 3, (int) version());
+  }
+
+  @Test
+  public void testSnapshotManagerThroughTransactionMultiOperation() {
+    table.newAppend().appendFile(FILE_A).commit();
+    Snapshot snapshotAfterFirstAppend = readMetadata().currentSnapshot();
+    validateSnapshot(null, snapshotAfterFirstAppend, FILE_A);
+
+    table.newAppend().appendFile(FILE_B).commit();
+    validateSnapshot(snapshotAfterFirstAppend, readMetadata().currentSnapshot(), FILE_B);
+    Assert.assertEquals("Table should be on version 2 after appending twice", 2, (int) version());
+
+    TableMetadata base = readMetadata();
+    Transaction txn = table.newTransaction();
+
+    txn.manageSnapshots().rollbackTo(snapshotAfterFirstAppend.snapshotId()).commit();
+    txn.updateProperties().set("some_prop", "some_prop_value").commit();
+    Assert.assertSame(
+        "Base metadata should not change when transaction is not committed", base, readMetadata());
+    Assert.assertEquals(
+        "Table should remain on version 2 when transaction is not committed", 2, (int) version());
+
+    txn.commitTransaction();
+
+    Assert.assertEquals(snapshotAfterFirstAppend, readMetadata().currentSnapshot());
+    Assert.assertEquals(
+        "Table should be on version 3 after invoking rollbackTo", 3, (int) version());
+  }
+
+  @Test
+  public void testSnapshotManagerInvalidParameters() throws Exception {
+    Assert.assertThrows(
+        "Incorrect input transaction: null",
+        IllegalArgumentException.class,
+        () -> {
+          new SnapshotManager(null);
+        });
+  }
 }
