@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg;
 
 import java.io.File;
@@ -31,6 +30,7 @@ import org.apache.iceberg.io.OutputFile;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.Types;
+import org.assertj.core.api.Assertions;
 import org.junit.Assert;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -40,7 +40,7 @@ import org.junit.runners.Parameterized;
 public class TestTransaction extends TableTestBase {
   @Parameterized.Parameters(name = "formatVersion = {0}")
   public static Object[] parameters() {
-    return new Object[] { 1, 2 };
+    return new Object[] {1, 2};
   }
 
   public TestTransaction(int formatVersion) {
@@ -56,8 +56,8 @@ public class TestTransaction extends TableTestBase {
     Transaction txn = table.newTransaction();
     txn.commitTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 0", 0, (int) version());
   }
 
@@ -69,17 +69,14 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
 
-    txn.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertSame("Base metadata should not change when an append is committed",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when an append is committed", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after append", 0, (int) version());
 
     txn.commitTransaction();
@@ -103,10 +100,7 @@ public class TestTransaction extends TableTestBase {
         "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
 
-    txn.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
     Assert.assertSame(
         "Base metadata should not change when commit is created", base, readMetadata());
@@ -114,9 +108,7 @@ public class TestTransaction extends TableTestBase {
 
     Snapshot appendSnapshot = txn.table().currentSnapshot();
 
-    txn.newDelete()
-        .deleteFile(FILE_A)
-        .commit();
+    txn.newDelete().deleteFile(FILE_A).commit();
 
     Snapshot deleteSnapshot = txn.table().currentSnapshot();
 
@@ -138,7 +130,8 @@ public class TestTransaction extends TableTestBase {
     validateManifestEntries(
         readMetadata().currentSnapshot().allManifests(table.io()).get(0),
         ids(deleteSnapshot.snapshotId(), appendSnapshot.snapshotId()),
-        files(FILE_A, FILE_B), statuses(Status.DELETED, Status.EXISTING));
+        files(FILE_A, FILE_B),
+        statuses(Status.DELETED, Status.EXISTING));
 
     Assert.assertEquals(
         "Table should have a snapshot for each operation", 3, readMetadata().snapshots().size());
@@ -148,7 +141,7 @@ public class TestTransaction extends TableTestBase {
         files(FILE_A, FILE_B),
         statuses(Status.ADDED, Status.ADDED));
 
-    org.assertj.core.api.Assertions.assertThat(table.history()).containsAll(initialHistory);
+    Assertions.assertThat(table.history()).containsAll(initialHistory);
   }
 
   @Test
@@ -159,47 +152,50 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
 
-    txn.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
 
     Snapshot appendSnapshot = txn.table().currentSnapshot();
 
-    txn.table().newDelete()
-        .deleteFile(FILE_A)
-        .commit();
+    txn.table().newDelete().deleteFile(FILE_A).commit();
 
     Snapshot deleteSnapshot = txn.table().currentSnapshot();
 
-    Assert.assertSame("Base metadata should not change when an append is committed",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when an append is committed", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after append", 0, (int) version());
 
     txn.commitTransaction();
 
     Assert.assertEquals("Table should be on version 1 after commit", 1, (int) version());
-    Assert.assertEquals("Table should have one manifest after commit",
-        1, readMetadata().currentSnapshot().allManifests(table.io()).size());
-    Assert.assertEquals("Table snapshot should be the delete snapshot",
-        deleteSnapshot, readMetadata().currentSnapshot());
-    validateManifestEntries(readMetadata().currentSnapshot().allManifests(table.io()).get(0),
+    Assert.assertEquals(
+        "Table should have one manifest after commit",
+        1,
+        readMetadata().currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Table snapshot should be the delete snapshot",
+        deleteSnapshot,
+        readMetadata().currentSnapshot());
+    validateManifestEntries(
+        readMetadata().currentSnapshot().allManifests(table.io()).get(0),
         ids(deleteSnapshot.snapshotId(), appendSnapshot.snapshotId()),
-        files(FILE_A, FILE_B), statuses(Status.DELETED, Status.EXISTING));
+        files(FILE_A, FILE_B),
+        statuses(Status.DELETED, Status.EXISTING));
 
-    Assert.assertEquals("Table should have a snapshot for each operation",
-        2, readMetadata().snapshots().size());
-    validateManifestEntries(readMetadata().snapshots().get(0).allManifests(table.io()).get(0),
+    Assert.assertEquals(
+        "Table should have a snapshot for each operation", 2, readMetadata().snapshots().size());
+    validateManifestEntries(
+        readMetadata().snapshots().get(0).allManifests(table.io()).get(0),
         ids(appendSnapshot.snapshotId(), appendSnapshot.snapshotId()),
-        files(FILE_A, FILE_B), statuses(Status.ADDED, Status.ADDED));
+        files(FILE_A, FILE_B),
+        statuses(Status.ADDED, Status.ADDED));
   }
 
   @Test
@@ -210,17 +206,18 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B); // not committed
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
 
-    AssertHelpers.assertThrows("Should reject commit when last operation has not committed",
+    AssertHelpers.assertThrows(
+        "Should reject commit when last operation has not committed",
         IllegalStateException.class,
         "Cannot create new DeleteFiles: last operation has not committed",
         txn::newDelete);
@@ -234,17 +231,18 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B); // not committed
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
 
-    AssertHelpers.assertThrows("Should reject commit when last operation has not committed",
+    AssertHelpers.assertThrows(
+        "Should reject commit when last operation has not committed",
         IllegalStateException.class,
         "Cannot commit transaction: last operation has not committed",
         txn::commitTransaction);
@@ -253,9 +251,7 @@ public class TestTransaction extends TableTestBase {
   @Test
   public void testTransactionConflict() {
     // set retries to 0 to catch the failure
-    table.updateProperties()
-        .set(TableProperties.COMMIT_NUM_RETRIES, "0")
-        .commit();
+    table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "0").commit();
 
     Assert.assertEquals("Table should be on version 1", 1, (int) version());
 
@@ -263,32 +259,30 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
 
-    txn.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
 
     // cause the transaction commit to fail
     table.ops().failCommits(1);
 
-    AssertHelpers.assertThrows("Transaction commit should fail",
-        CommitFailedException.class, "Injected failure", txn::commitTransaction);
+    AssertHelpers.assertThrows(
+        "Transaction commit should fail",
+        CommitFailedException.class,
+        "Injected failure",
+        txn::commitTransaction);
   }
 
   @Test
   public void testTransactionRetry() {
     // use only one retry
-    table.updateProperties()
-        .set(TableProperties.COMMIT_NUM_RETRIES, "1")
-        .commit();
+    table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "1").commit();
 
     Assert.assertEquals("Table should be on version 1", 1, (int) version());
 
@@ -296,19 +290,17 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
 
-    txn.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Set<ManifestFile> appendManifests = Sets.newHashSet(txn.table().currentSnapshot().allManifests(table.io()));
+    Set<ManifestFile> appendManifests =
+        Sets.newHashSet(txn.table().currentSnapshot().allManifests(table.io()));
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
 
     // cause the transaction commit to fail
@@ -318,16 +310,16 @@ public class TestTransaction extends TableTestBase {
 
     Assert.assertEquals("Table should be on version 2 after commit", 2, (int) version());
 
-    Assert.assertEquals("Should reuse manifests from initial append commit",
-        appendManifests, Sets.newHashSet(table.currentSnapshot().allManifests(table.io())));
+    Assert.assertEquals(
+        "Should reuse manifests from initial append commit",
+        appendManifests,
+        Sets.newHashSet(table.currentSnapshot().allManifests(table.io())));
   }
 
   @Test
   public void testTransactionRetryMergeAppend() {
     // use only one retry
-    table.updateProperties()
-        .set(TableProperties.COMMIT_NUM_RETRIES, "1")
-        .commit();
+    table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "1").commit();
 
     Assert.assertEquals("Table should be on version 1", 1, (int) version());
 
@@ -335,30 +327,26 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
 
-    txn.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Set<ManifestFile> appendManifests = Sets.newHashSet(txn.table().currentSnapshot().allManifests(table.io()));
+    Set<ManifestFile> appendManifests =
+        Sets.newHashSet(txn.table().currentSnapshot().allManifests(table.io()));
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
 
     // cause the transaction commit to fail
-    table.newAppend()
-        .appendFile(FILE_C)
-        .appendFile(FILE_D)
-        .commit();
+    table.newAppend().appendFile(FILE_C).appendFile(FILE_D).commit();
 
     Assert.assertEquals("Table should be on version 2 after real append", 2, (int) version());
 
-    Set<ManifestFile> conflictAppendManifests = Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
+    Set<ManifestFile> conflictAppendManifests =
+        Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
 
     txn.commitTransaction();
 
@@ -368,14 +356,17 @@ public class TestTransaction extends TableTestBase {
     expectedManifests.addAll(appendManifests);
     expectedManifests.addAll(conflictAppendManifests);
 
-    Assert.assertEquals("Should reuse manifests from initial append commit and conflicting append",
-        expectedManifests, Sets.newHashSet(table.currentSnapshot().allManifests(table.io())));
+    Assert.assertEquals(
+        "Should reuse manifests from initial append commit and conflicting append",
+        expectedManifests,
+        Sets.newHashSet(table.currentSnapshot().allManifests(table.io())));
   }
 
   @Test
   public void testMultipleUpdateTransactionRetryMergeCleanup() {
     // use only one retry and aggressively merge manifests
-    table.updateProperties()
+    table
+        .updateProperties()
         .set(TableProperties.COMMIT_NUM_RETRIES, "1")
         .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
         .commit();
@@ -386,36 +377,31 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
 
-    txn.updateProperties()
-        .set("test-property", "test-value")
-        .commit();
+    txn.updateProperties().set("test-property", "test-value").commit();
 
-    txn.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertEquals("Append should create one manifest",
-        1, txn.table().currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Append should create one manifest",
+        1,
+        txn.table().currentSnapshot().allManifests(table.io()).size());
     ManifestFile appendManifest = txn.table().currentSnapshot().allManifests(table.io()).get(0);
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
 
     // cause the transaction commit to fail
-    table.newAppend()
-        .appendFile(FILE_C)
-        .appendFile(FILE_D)
-        .commit();
+    table.newAppend().appendFile(FILE_C).appendFile(FILE_D).commit();
 
     Assert.assertEquals("Table should be on version 2 after real append", 2, (int) version());
 
-    Set<ManifestFile> conflictAppendManifests = Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
+    Set<ManifestFile> conflictAppendManifests =
+        Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
 
     txn.commitTransaction();
 
@@ -425,49 +411,52 @@ public class TestTransaction extends TableTestBase {
     previousManifests.add(appendManifest);
     previousManifests.addAll(conflictAppendManifests);
 
-    Assert.assertEquals("Should merge both commit manifests into a single manifest",
-        1, table.currentSnapshot().allManifests(table.io()).size());
-    Assert.assertFalse("Should merge both commit manifests into a new manifest",
+    Assert.assertEquals(
+        "Should merge both commit manifests into a single manifest",
+        1,
+        table.currentSnapshot().allManifests(table.io()).size());
+    Assert.assertFalse(
+        "Should merge both commit manifests into a new manifest",
         previousManifests.contains(table.currentSnapshot().allManifests(table.io()).get(0)));
 
-    Assert.assertFalse("Append manifest should be deleted", new File(appendManifest.path()).exists());
+    Assert.assertFalse(
+        "Append manifest should be deleted", new File(appendManifest.path()).exists());
   }
 
   @Test
   public void testTransactionRetrySchemaUpdate() {
     // use only one retry
-    table.updateProperties()
-        .set(TableProperties.COMMIT_NUM_RETRIES, "1")
-        .commit();
+    table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "1").commit();
 
     // start a transaction
     Transaction txn = table.newTransaction();
     // add column "new-column"
-    txn.updateSchema()
-        .addColumn("new-column", Types.IntegerType.get())
-        .commit();
+    txn.updateSchema().addColumn("new-column", Types.IntegerType.get()).commit();
     int schemaId = txn.table().schema().schemaId();
 
-    // directly update the table for adding "another-column" (which causes in-progress txn commit fail)
-    table.updateSchema()
-        .addColumn("another-column", Types.IntegerType.get())
-        .commit();
+    // directly update the table for adding "another-column" (which causes in-progress txn commit
+    // fail)
+    table.updateSchema().addColumn("another-column", Types.IntegerType.get()).commit();
     int conflictingSchemaId = table.schema().schemaId();
 
-    Assert.assertEquals("Both schema IDs should be the same in order to cause a conflict",
+    Assert.assertEquals(
+        "Both schema IDs should be the same in order to cause a conflict",
         conflictingSchemaId,
         schemaId);
 
     // commit the transaction for adding "new-column"
-    AssertHelpers.assertThrows("Should fail due to conflicting transaction even after retry",
-        CommitFailedException.class, "Table metadata refresh is required",
+    AssertHelpers.assertThrows(
+        "Should fail due to conflicting transaction even after retry",
+        CommitFailedException.class,
+        "Table metadata refresh is required",
         txn::commitTransaction);
   }
 
   @Test
   public void testTransactionRetryMergeCleanup() {
     // use only one retry and aggressively merge manifests
-    table.updateProperties()
+    table
+        .updateProperties()
         .set(TableProperties.COMMIT_NUM_RETRIES, "1")
         .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
         .commit();
@@ -478,32 +467,29 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
 
-    txn.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertEquals("Append should create one manifest",
-        1, txn.table().currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Append should create one manifest",
+        1,
+        txn.table().currentSnapshot().allManifests(table.io()).size());
     ManifestFile appendManifest = txn.table().currentSnapshot().allManifests(table.io()).get(0);
 
-    Assert.assertSame("Base metadata should not change when commit is created",
-        base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
 
     // cause the transaction commit to fail
-    table.newAppend()
-        .appendFile(FILE_C)
-        .appendFile(FILE_D)
-        .commit();
+    table.newAppend().appendFile(FILE_C).appendFile(FILE_D).commit();
 
     Assert.assertEquals("Table should be on version 2 after real append", 2, (int) version());
 
-    Set<ManifestFile> conflictAppendManifests = Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
+    Set<ManifestFile> conflictAppendManifests =
+        Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
 
     txn.commitTransaction();
 
@@ -513,38 +499,43 @@ public class TestTransaction extends TableTestBase {
     previousManifests.add(appendManifest);
     previousManifests.addAll(conflictAppendManifests);
 
-    Assert.assertEquals("Should merge both commit manifests into a single manifest",
-        1, table.currentSnapshot().allManifests(table.io()).size());
-    Assert.assertFalse("Should merge both commit manifests into a new manifest",
+    Assert.assertEquals(
+        "Should merge both commit manifests into a single manifest",
+        1,
+        table.currentSnapshot().allManifests(table.io()).size());
+    Assert.assertFalse(
+        "Should merge both commit manifests into a new manifest",
         previousManifests.contains(table.currentSnapshot().allManifests(table.io()).get(0)));
 
-    Assert.assertFalse("Append manifest should be deleted", new File(appendManifest.path()).exists());
+    Assert.assertFalse(
+        "Append manifest should be deleted", new File(appendManifest.path()).exists());
   }
 
   @Test
   public void testTransactionRetryAndAppendManifests() throws Exception {
     // use only one retry and aggressively merge manifests
-    table.updateProperties()
+    table
+        .updateProperties()
         .set(TableProperties.COMMIT_NUM_RETRIES, "1")
         .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
         .commit();
 
     Assert.assertEquals("Table should be on version 1", 1, (int) version());
 
-    table.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    table.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
     Assert.assertEquals("Table should be on version 2 after append", 2, (int) version());
-    Assert.assertEquals("Append should create one manifest",
-        1, table.currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Append should create one manifest",
+        1,
+        table.currentSnapshot().allManifests(table.io()).size());
     ManifestFile v1manifest = table.currentSnapshot().allManifests(table.io()).get(0);
 
     TableMetadata base = readMetadata();
 
     // create a manifest append
-    OutputFile manifestLocation = Files.localOutput("/tmp/" + UUID.randomUUID().toString() + ".avro");
+    OutputFile manifestLocation =
+        Files.localOutput("/tmp/" + UUID.randomUUID().toString() + ".avro");
     ManifestWriter<DataFile> writer = ManifestFiles.write(table.spec(), manifestLocation);
     try {
       writer.add(FILE_D);
@@ -554,30 +545,35 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    txn.newAppend()
-        .appendManifest(writer.toManifestFile())
-        .commit();
+    txn.newAppend().appendManifest(writer.toManifestFile()).commit();
 
-    Assert.assertSame("Base metadata should not change when commit is created", base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 2 after txn create", 2, (int) version());
 
-    Assert.assertEquals("Append should have one merged manifest",
-        1, txn.table().currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Append should have one merged manifest",
+        1,
+        txn.table().currentSnapshot().allManifests(table.io()).size());
     ManifestFile mergedManifest = txn.table().currentSnapshot().allManifests(table.io()).get(0);
 
     // find the initial copy of the appended manifest
-    String copiedAppendManifest = Iterables.getOnlyElement(Iterables.filter(
-        Iterables.transform(listManifestFiles(), File::getPath),
-        path -> !v1manifest.path().contains(path) && !mergedManifest.path().contains(path)));
+    String copiedAppendManifest =
+        Iterables.getOnlyElement(
+            Iterables.filter(
+                Iterables.transform(listManifestFiles(), File::getPath),
+                path ->
+                    !v1manifest.path().contains(path) && !mergedManifest.path().contains(path)));
 
-    Assert.assertTrue("Transaction should hijack the delete of the original copied manifest",
+    Assert.assertTrue(
+        "Transaction should hijack the delete of the original copied manifest",
         ((BaseTransaction) txn).deletedFiles().contains(copiedAppendManifest));
-    Assert.assertTrue("Copied append manifest should not be deleted yet", new File(copiedAppendManifest).exists());
+    Assert.assertTrue(
+        "Copied append manifest should not be deleted yet",
+        new File(copiedAppendManifest).exists());
 
     // cause the transaction commit to fail and retry
-    table.newAppend()
-        .appendFile(FILE_C)
-        .commit();
+    table.newAppend().appendFile(FILE_C).commit();
 
     Assert.assertEquals("Table should be on version 3 after real append", 3, (int) version());
 
@@ -585,21 +581,28 @@ public class TestTransaction extends TableTestBase {
 
     Assert.assertEquals("Table should be on version 4 after commit", 4, (int) version());
 
-    Assert.assertTrue("Transaction should hijack the delete of the original copied manifest",
+    Assert.assertTrue(
+        "Transaction should hijack the delete of the original copied manifest",
         ((BaseTransaction) txn).deletedFiles().contains(copiedAppendManifest));
-    Assert.assertFalse("Append manifest should be deleted", new File(copiedAppendManifest).exists());
-    Assert.assertTrue("Transaction should hijack the delete of the first merged manifest",
+    Assert.assertFalse(
+        "Append manifest should be deleted", new File(copiedAppendManifest).exists());
+    Assert.assertTrue(
+        "Transaction should hijack the delete of the first merged manifest",
         ((BaseTransaction) txn).deletedFiles().contains(mergedManifest.path()));
-    Assert.assertFalse("Append manifest should be deleted", new File(mergedManifest.path()).exists());
+    Assert.assertFalse(
+        "Append manifest should be deleted", new File(mergedManifest.path()).exists());
 
-    Assert.assertEquals("Should merge all commit manifests into a single manifest",
-        1, table.currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Should merge all commit manifests into a single manifest",
+        1,
+        table.currentSnapshot().allManifests(table.io()).size());
   }
 
   @Test
   public void testTransactionRetryAndAppendManifestsWithSnapshotIdInheritance() throws Exception {
     // use only one retry and aggressively merge manifests
-    table.updateProperties()
+    table
+        .updateProperties()
         .set(TableProperties.COMMIT_NUM_RETRIES, "1")
         .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
         .set(TableProperties.SNAPSHOT_ID_INHERITANCE_ENABLED, "true")
@@ -607,35 +610,33 @@ public class TestTransaction extends TableTestBase {
 
     Assert.assertEquals("Table should be on version 1", 1, (int) version());
 
-    table.newAppend()
-        .appendFile(FILE_A)
-        .appendFile(FILE_B)
-        .commit();
+    table.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
     Assert.assertEquals("Table should be on version 2 after append", 2, (int) version());
-    Assert.assertEquals("Append should create one manifest",
-        1, table.currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Append should create one manifest",
+        1,
+        table.currentSnapshot().allManifests(table.io()).size());
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
     ManifestFile appendManifest = writeManifestWithName("input.m0", FILE_D);
-    txn.newAppend()
-        .appendManifest(appendManifest)
-        .commit();
+    txn.newAppend().appendManifest(appendManifest).commit();
 
-    Assert.assertSame("Base metadata should not change when commit is created", base, readMetadata());
+    Assert.assertSame(
+        "Base metadata should not change when commit is created", base, readMetadata());
     Assert.assertEquals("Table should be on version 2 after txn create", 2, (int) version());
 
-    Assert.assertEquals("Append should have one merged manifest",
-        1, txn.table().currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Append should have one merged manifest",
+        1,
+        txn.table().currentSnapshot().allManifests(table.io()).size());
     ManifestFile mergedManifest = txn.table().currentSnapshot().allManifests(table.io()).get(0);
 
     // cause the transaction commit to fail and retry
-    table.newAppend()
-        .appendFile(FILE_C)
-        .commit();
+    table.newAppend().appendFile(FILE_C).commit();
 
     Assert.assertEquals("Table should be on version 3 after real append", 3, (int) version());
 
@@ -643,44 +644,48 @@ public class TestTransaction extends TableTestBase {
 
     Assert.assertEquals("Table should be on version 4 after commit", 4, (int) version());
 
-    Assert.assertTrue("Transaction should hijack the delete of the original append manifest",
+    Assert.assertTrue(
+        "Transaction should hijack the delete of the original append manifest",
         ((BaseTransaction) txn).deletedFiles().contains(appendManifest.path()));
-    Assert.assertFalse("Append manifest should be deleted", new File(appendManifest.path()).exists());
+    Assert.assertFalse(
+        "Append manifest should be deleted", new File(appendManifest.path()).exists());
 
-    Assert.assertTrue("Transaction should hijack the delete of the first merged manifest",
+    Assert.assertTrue(
+        "Transaction should hijack the delete of the first merged manifest",
         ((BaseTransaction) txn).deletedFiles().contains(mergedManifest.path()));
-    Assert.assertFalse("Merged append manifest should be deleted", new File(mergedManifest.path()).exists());
+    Assert.assertFalse(
+        "Merged append manifest should be deleted", new File(mergedManifest.path()).exists());
 
-    Assert.assertEquals("Should merge all commit manifests into a single manifest",
-        1, table.currentSnapshot().allManifests(table.io()).size());
+    Assert.assertEquals(
+        "Should merge all commit manifests into a single manifest",
+        1,
+        table.currentSnapshot().allManifests(table.io()).size());
   }
 
   @Test
   public void testTransactionNoCustomDeleteFunc() {
-    AssertHelpers.assertThrows("Should fail setting a custom delete function with a transaction",
-        IllegalArgumentException.class, "Cannot set delete callback more than once",
-        () -> table.newTransaction()
-            .newAppend()
-            .appendFile(FILE_A)
-            .appendFile(FILE_B)
-            .deleteWith(file -> { }));
+    AssertHelpers.assertThrows(
+        "Should fail setting a custom delete function with a transaction",
+        IllegalArgumentException.class,
+        "Cannot set delete callback more than once",
+        () ->
+            table
+                .newTransaction()
+                .newAppend()
+                .appendFile(FILE_A)
+                .appendFile(FILE_B)
+                .deleteWith(file -> {}));
   }
 
   @Test
   public void testTransactionFastAppends() {
-    table.updateProperties()
-        .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
-        .commit();
+    table.updateProperties().set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0").commit();
 
     Transaction txn = table.newTransaction();
 
-    txn.newFastAppend()
-        .appendFile(FILE_A)
-        .commit();
+    txn.newFastAppend().appendFile(FILE_A).commit();
 
-    txn.newFastAppend()
-        .appendFile(FILE_B)
-        .commit();
+    txn.newFastAppend().appendFile(FILE_B).commit();
 
     txn.commitTransaction();
 
@@ -692,28 +697,26 @@ public class TestTransaction extends TableTestBase {
   public void testTransactionRewriteManifestsAppendedDirectly() throws IOException {
     Table table = load();
 
-    table.updateProperties()
+    table
+        .updateProperties()
         .set(TableProperties.SNAPSHOT_ID_INHERITANCE_ENABLED, "true")
         .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
         .commit();
 
-    table.newFastAppend()
-        .appendFile(FILE_A)
-        .commit();
+    table.newFastAppend().appendFile(FILE_A).commit();
     long firstSnapshotId = table.currentSnapshot().snapshotId();
 
-    table.newFastAppend()
-        .appendFile(FILE_B)
-        .commit();
+    table.newFastAppend().appendFile(FILE_B).commit();
     long secondSnapshotId = table.currentSnapshot().snapshotId();
 
     List<ManifestFile> manifests = table.currentSnapshot().allManifests(table.io());
     Assert.assertEquals("Should have 2 manifests after 2 appends", 2, manifests.size());
 
-    ManifestFile newManifest = writeManifest(
-        "manifest-file-1.avro",
-        manifestEntry(ManifestEntry.Status.EXISTING, firstSnapshotId, FILE_A),
-        manifestEntry(ManifestEntry.Status.EXISTING, secondSnapshotId, FILE_B));
+    ManifestFile newManifest =
+        writeManifest(
+            "manifest-file-1.avro",
+            manifestEntry(ManifestEntry.Status.EXISTING, firstSnapshotId, FILE_A),
+            manifestEntry(ManifestEntry.Status.EXISTING, secondSnapshotId, FILE_B));
 
     Transaction txn = table.newTransaction();
     txn.rewriteManifests()
@@ -721,30 +724,31 @@ public class TestTransaction extends TableTestBase {
         .deleteManifest(manifests.get(1))
         .addManifest(newManifest)
         .commit();
-    txn.newAppend()
-        .appendFile(FILE_C)
-        .commit();
+    txn.newAppend().appendFile(FILE_C).commit();
     txn.commitTransaction();
 
     long finalSnapshotId = table.currentSnapshot().snapshotId();
     long finalSnapshotTimestamp = System.currentTimeMillis();
 
-    Assert.assertTrue("Append manifest should not be deleted", new File(newManifest.path()).exists());
+    Assert.assertTrue(
+        "Append manifest should not be deleted", new File(newManifest.path()).exists());
 
     List<ManifestFile> finalManifests = table.currentSnapshot().allManifests(table.io());
     Assert.assertEquals("Should have 1 final manifest", 1, finalManifests.size());
 
-    validateManifestEntries(finalManifests.get(0),
+    validateManifestEntries(
+        finalManifests.get(0),
         ids(finalSnapshotId, firstSnapshotId, secondSnapshotId),
         files(FILE_C, FILE_A, FILE_B),
-        statuses(ManifestEntry.Status.ADDED, ManifestEntry.Status.EXISTING, ManifestEntry.Status.EXISTING));
+        statuses(
+            ManifestEntry.Status.ADDED,
+            ManifestEntry.Status.EXISTING,
+            ManifestEntry.Status.EXISTING));
 
-    table.expireSnapshots()
-        .expireOlderThan(finalSnapshotTimestamp + 1)
-        .retainLast(1)
-        .commit();
+    table.expireSnapshots().expireOlderThan(finalSnapshotTimestamp + 1).retainLast(1).commit();
 
-    Assert.assertFalse("Append manifest should be deleted on expiry", new File(newManifest.path()).exists());
+    Assert.assertFalse(
+        "Append manifest should be deleted on expiry", new File(newManifest.path()).exists());
   }
 
   @Test
@@ -752,13 +756,12 @@ public class TestTransaction extends TableTestBase {
     Table table = TestTables.tableWithCommitSucceedButStateUnknown(tableDir, "test");
 
     Transaction transaction = table.newTransaction();
-    transaction.newAppend()
-        .appendFile(FILE_A)
-        .commit();
+    transaction.newAppend().appendFile(FILE_A).commit();
 
     AssertHelpers.assertThrows(
         "Transaction commit should fail with CommitStateUnknownException",
-        CommitStateUnknownException.class, "datacenter on fire",
+        CommitStateUnknownException.class,
+        "datacenter on fire",
         () -> transaction.commitTransaction());
 
     // Make sure metadata files still exist
