@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.avro;
 
 import java.io.IOException;
@@ -34,19 +33,16 @@ public class TestGenericAvro extends AvroDataTest {
     List<Record> expected = RandomAvroData.generate(schema, 100, 0L);
 
     OutputFile outputFile = new InMemoryOutputFile();
-    try (FileAppender<Record> writer = Avro.write(outputFile)
-        .schema(schema)
-        .named("test")
-        .build()) {
+    try (FileAppender<Record> writer =
+        Avro.write(outputFile).schema(schema).named("test").build()) {
       for (Record rec : expected) {
         writer.add(rec);
       }
     }
 
     List<Record> rows;
-    try (AvroIterable<Record> reader = Avro.read(outputFile.toInputFile())
-        .project(schema)
-        .build()) {
+    try (AvroIterable<Record> reader =
+        Avro.read(outputFile.toInputFile()).project(schema).build()) {
       rows = Lists.newArrayList(reader);
     }
 
