@@ -16,9 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.io;
 
+import static org.apache.iceberg.types.Types.NestedField.optional;
+import static org.apache.iceberg.types.Types.NestedField.required;
+
 import java.io.File;
 import java.io.IOException;
 import java.nio.ByteBuffer;
@@ -51,9 +53,6 @@ import org.junit.rules.TemporaryFolder;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 
-import static org.apache.iceberg.types.Types.NestedField.optional;
-import static org.apache.iceberg.types.Types.NestedField.required;
-
 @RunWith(Parameterized.class)
 public abstract class TestWriterMetrics<T> {
 
@@ -62,18 +61,15 @@ public abstract class TestWriterMetrics<T> {
   protected static final Types.NestedField ID_FIELD = required(1, "id", Types.IntegerType.get());
   protected static final Types.NestedField DATA_FIELD = optional(2, "data", Types.StringType.get());
 
-  protected static final Types.StructType NESTED_FIELDS = Types.StructType.of(
-      required(4, "booleanField", Types.BooleanType.get()),
-      optional(5, "longValue", Types.LongType.get()));
+  protected static final Types.StructType NESTED_FIELDS =
+      Types.StructType.of(
+          required(4, "booleanField", Types.BooleanType.get()),
+          optional(5, "longValue", Types.LongType.get()));
 
   protected static final Types.NestedField STRUCT_FIELD = optional(3, "structField", NESTED_FIELDS);
 
   // create a schema with all supported fields
-  protected static final Schema SCHEMA = new Schema(
-      ID_FIELD,
-      DATA_FIELD,
-      STRUCT_FIELD
-  );
+  protected static final Schema SCHEMA = new Schema(ID_FIELD, DATA_FIELD, STRUCT_FIELD);
 
   protected static final SortOrder sortOrder =
       SortOrder.builderFor(SCHEMA).asc("id").asc("structField.longValue").build();
@@ -81,8 +77,7 @@ public abstract class TestWriterMetrics<T> {
   protected static final Map<String, String> properties =
       ImmutableMap.of(TableProperties.DEFAULT_WRITE_METRICS_MODE, "none");
 
-  @Rule
-  public TemporaryFolder temp = new TemporaryFolder();
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
   protected FileFormat fileFormat;
   protected TestTables.TestTable table = null;
@@ -90,10 +85,7 @@ public abstract class TestWriterMetrics<T> {
 
   @Parameterized.Parameters(name = "FileFormat = {0}")
   public static Object[][] parameters() {
-    return new Object[][] {
-        {FileFormat.ORC},
-        {FileFormat.PARQUET}
-    };
+    return new Object[][] {{FileFormat.ORC}, {FileFormat.PARQUET}};
   }
 
   public TestWriterMetrics(FileFormat fileFormat) {
@@ -111,13 +103,9 @@ public abstract class TestWriterMetrics<T> {
     File tableDir = temp.newFolder();
     tableDir.delete(); // created by table create
 
-    this.table = TestTables.create(
-        tableDir,
-        "test",
-        SCHEMA,
-        PartitionSpec.unpartitioned(),
-        sortOrder,
-        FORMAT_V2);
+    this.table =
+        TestTables.create(
+            tableDir, "test", SCHEMA, PartitionSpec.unpartitioned(), sortOrder, FORMAT_V2);
     table.updateProperties().set(TableProperties.DEFAULT_WRITE_METRICS_MODE, "none").commit();
 
     this.fileFactory = OutputFileFactory.builderFor(table, 1, 1).format(fileFormat).build();
@@ -131,36 +119,39 @@ public abstract class TestWriterMetrics<T> {
   @Test
   public void verifySortedColMetric() throws Exception {
     T row = toRow(3, "3", true, 3L);
-    DataWriter dataWriter = newWriterFactory(table).newDataWriter(
-        fileFactory.newOutputFile(),
-        PartitionSpec.unpartitioned(),
-        null
-    );
+    DataWriter dataWriter =
+        newWriterFactory(table)
+            .newDataWriter(fileFactory.newOutputFile(), PartitionSpec.unpartitioned(), null);
     dataWriter.write(row);
     dataWriter.close();
     DataFile dataFile = dataWriter.toDataFile();
 
     // Only two sorted fields (id, structField.longValue) will have metrics
     Map<Integer, ByteBuffer> lowerBounds = dataFile.lowerBounds();
-    Assert.assertEquals(3, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), lowerBounds.get(1)));
+    Assert.assertEquals(
+        3, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), lowerBounds.get(1)));
     Assert.assertFalse(lowerBounds.containsKey(2));
     Assert.assertFalse(lowerBounds.containsKey(3));
     Assert.assertFalse(lowerBounds.containsKey(4));
-    Assert.assertEquals(3L, (long) Conversions.fromByteBuffer(Types.LongType.get(), lowerBounds.get(5)));
+    Assert.assertEquals(
+        3L, (long) Conversions.fromByteBuffer(Types.LongType.get(), lowerBounds.get(5)));
 
     Map<Integer, ByteBuffer> upperBounds = dataFile.upperBounds();
-    Assert.assertEquals(3, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), upperBounds.get(1)));
+    Assert.assertEquals(
+        3, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), upperBounds.get(1)));
     Assert.assertFalse(upperBounds.containsKey(2));
     Assert.assertFalse(upperBounds.containsKey(3));
     Assert.assertFalse(upperBounds.containsKey(4));
-    Assert.assertEquals(3L, (long) Conversions.fromByteBuffer(Types.LongType.get(), upperBounds.get(5)));
+    Assert.assertEquals(
+        3L, (long) Conversions.fromByteBuffer(Types.LongType.get(), upperBounds.get(5)));
   }
 
   @Test
   public void testPositionDeleteMetrics() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table);
     EncryptedOutputFile outputFile = fileFactory.newOutputFile();
-    PositionDeleteWriter<T> deleteWriter = writerFactory.newPositionDeleteWriter(outputFile, table.spec(), null);
+    PositionDeleteWriter<T> deleteWriter =
+        writerFactory.newPositionDeleteWriter(outputFile, table.spec(), null);
 
     try {
       T deletedRow = toRow(3, "3", true, 3L);
@@ -176,33 +167,40 @@ public abstract class TestWriterMetrics<T> {
     int pathFieldId = MetadataColumns.DELETE_FILE_PATH.fieldId();
     int posFieldId = MetadataColumns.DELETE_FILE_POS.fieldId();
 
-    // should have metrics for _file and _pos as well as two sorted fields (id, structField.longValue)
+    // should have metrics for _file and _pos as well as two sorted fields (id,
+    // structField.longValue)
 
     Map<Integer, ByteBuffer> lowerBounds = deleteFile.lowerBounds();
 
     Assert.assertEquals(
         CharBuffer.wrap("File A"),
         Conversions.fromByteBuffer(Types.StringType.get(), lowerBounds.get(pathFieldId)));
-    Assert.assertEquals(1L, (long) Conversions.fromByteBuffer(Types.LongType.get(), lowerBounds.get(posFieldId)));
+    Assert.assertEquals(
+        1L, (long) Conversions.fromByteBuffer(Types.LongType.get(), lowerBounds.get(posFieldId)));
 
-    Assert.assertEquals(3, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), lowerBounds.get(1)));
+    Assert.assertEquals(
+        3, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), lowerBounds.get(1)));
     Assert.assertFalse(lowerBounds.containsKey(2));
     Assert.assertFalse(lowerBounds.containsKey(3));
     Assert.assertFalse(lowerBounds.containsKey(4));
-    Assert.assertEquals(3L, (long) Conversions.fromByteBuffer(Types.LongType.get(), lowerBounds.get(5)));
+    Assert.assertEquals(
+        3L, (long) Conversions.fromByteBuffer(Types.LongType.get(), lowerBounds.get(5)));
 
     Map<Integer, ByteBuffer> upperBounds = deleteFile.upperBounds();
 
     Assert.assertEquals(
         CharBuffer.wrap("File A"),
         Conversions.fromByteBuffer(Types.StringType.get(), upperBounds.get(pathFieldId)));
-    Assert.assertEquals(1L, (long) Conversions.fromByteBuffer(Types.LongType.get(), upperBounds.get(posFieldId)));
+    Assert.assertEquals(
+        1L, (long) Conversions.fromByteBuffer(Types.LongType.get(), upperBounds.get(posFieldId)));
 
-    Assert.assertEquals(3, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), upperBounds.get(1)));
+    Assert.assertEquals(
+        3, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), upperBounds.get(1)));
     Assert.assertFalse(upperBounds.containsKey(2));
     Assert.assertFalse(upperBounds.containsKey(3));
     Assert.assertFalse(upperBounds.containsKey(4));
-    Assert.assertEquals(3L, (long) Conversions.fromByteBuffer(Types.LongType.get(), upperBounds.get(5)));
+    Assert.assertEquals(
+        3L, (long) Conversions.fromByteBuffer(Types.LongType.get(), upperBounds.get(5)));
   }
 
   @Test
@@ -210,39 +208,40 @@ public abstract class TestWriterMetrics<T> {
     File tableDir = temp.newFolder();
     tableDir.delete(); // created by table create
 
-    int numColumns = 33;
+    int numColumns = TableProperties.METRICS_MAX_INFERRED_COLUMN_DEFAULTS_DEFAULT + 1;
     List<Types.NestedField> fields = Lists.newArrayListWithCapacity(numColumns);
     for (int i = 0; i < numColumns; i++) {
       fields.add(required(i, "col" + i, Types.IntegerType.get()));
     }
     Schema maxColSchema = new Schema(fields);
 
-    Table maxColumnTable = TestTables.create(
-        tableDir,
-        "max_col_table",
-        maxColSchema,
-        PartitionSpec.unpartitioned(),
-        SortOrder.unsorted(),
-        FORMAT_V2);
-    OutputFileFactory maxColFactory = OutputFileFactory.builderFor(maxColumnTable, 1, 1)
-        .format(fileFormat).build();
+    Table maxColumnTable =
+        TestTables.create(
+            tableDir,
+            "max_col_table",
+            maxColSchema,
+            PartitionSpec.unpartitioned(),
+            SortOrder.unsorted(),
+            FORMAT_V2);
+    OutputFileFactory maxColFactory =
+        OutputFileFactory.builderFor(maxColumnTable, 1, 1).format(fileFormat).build();
 
     T row = toGenericRow(1, numColumns);
-    DataWriter dataWriter = newWriterFactory(maxColumnTable).newDataWriter(
-        maxColFactory.newOutputFile(),
-        PartitionSpec.unpartitioned(),
-        null
-    );
-    dataWriter.add(row);
+    DataWriter<T> dataWriter =
+        newWriterFactory(maxColumnTable)
+            .newDataWriter(maxColFactory.newOutputFile(), PartitionSpec.unpartitioned(), null);
+    dataWriter.write(row);
     dataWriter.close();
     DataFile dataFile = dataWriter.toDataFile();
 
     // start at 1 because IDs were reassigned in the table
     int id = 1;
-    for (; id <= 32; id += 1) {
+    for (; id <= TableProperties.METRICS_MAX_INFERRED_COLUMN_DEFAULTS_DEFAULT; id += 1) {
       Assert.assertNotNull("Should have lower bound metrics", dataFile.lowerBounds().get(id));
       Assert.assertNotNull("Should have upper bound metrics", dataFile.upperBounds().get(id));
-      Assert.assertNull("Should not have nan value metrics (not floating point)", dataFile.nanValueCounts().get(id));
+      Assert.assertNull(
+          "Should not have nan value metrics (not floating point)",
+          dataFile.nanValueCounts().get(id));
       Assert.assertNotNull("Should have null value metrics", dataFile.nullValueCounts().get(id));
       Assert.assertNotNull("Should have value metrics", dataFile.valueCounts().get(id));
     }
@@ -252,7 +251,8 @@ public abstract class TestWriterMetrics<T> {
       Assert.assertNull("Should not have any lower bound metrics", dataFile.lowerBounds().get(id));
       Assert.assertNull("Should not have any upper bound metrics", dataFile.upperBounds().get(id));
       Assert.assertNull("Should not have any nan value metrics", dataFile.nanValueCounts().get(id));
-      Assert.assertNull("Should not have any null value metrics", dataFile.nullValueCounts().get(id));
+      Assert.assertNull(
+          "Should not have any null value metrics", dataFile.nullValueCounts().get(id));
       Assert.assertNull("Should not have any value metrics", dataFile.valueCounts().get(id));
     }
   }
@@ -262,32 +262,35 @@ public abstract class TestWriterMetrics<T> {
     File tableDir = temp.newFolder();
     tableDir.delete(); // created by table create
 
-    int numColumns = 33;
+    int numColumns = TableProperties.METRICS_MAX_INFERRED_COLUMN_DEFAULTS_DEFAULT + 1;
     List<Types.NestedField> fields = Lists.newArrayListWithCapacity(numColumns);
     for (int i = 0; i < numColumns; i++) {
       fields.add(required(i, "col" + i, Types.IntegerType.get()));
     }
     Schema maxColSchema = new Schema(fields);
 
-    Table maxColumnTable = TestTables.create(
-        tableDir,
-        "max_col_table",
-        maxColSchema,
-        PartitionSpec.unpartitioned(),
-        SortOrder.unsorted(),
-        FORMAT_V2);
-    maxColumnTable.updateProperties().set(TableProperties.DEFAULT_WRITE_METRICS_MODE,
-        TableProperties.DEFAULT_WRITE_METRICS_MODE_DEFAULT).commit();
-    OutputFileFactory maxColFactory = OutputFileFactory.builderFor(maxColumnTable, 1, 1)
-        .format(fileFormat).build();
+    Table maxColumnTable =
+        TestTables.create(
+            tableDir,
+            "max_col_table",
+            maxColSchema,
+            PartitionSpec.unpartitioned(),
+            SortOrder.unsorted(),
+            FORMAT_V2);
+    maxColumnTable
+        .updateProperties()
+        .set(
+            TableProperties.DEFAULT_WRITE_METRICS_MODE,
+            TableProperties.DEFAULT_WRITE_METRICS_MODE_DEFAULT)
+        .commit();
+    OutputFileFactory maxColFactory =
+        OutputFileFactory.builderFor(maxColumnTable, 1, 1).format(fileFormat).build();
 
     T row = toGenericRow(1, numColumns);
-    DataWriter dataWriter = newWriterFactory(maxColumnTable).newDataWriter(
-        maxColFactory.newOutputFile(),
-        PartitionSpec.unpartitioned(),
-        null
-    );
-    dataWriter.add(row);
+    DataWriter<T> dataWriter =
+        newWriterFactory(maxColumnTable)
+            .newDataWriter(maxColFactory.newOutputFile(), PartitionSpec.unpartitioned(), null);
+    dataWriter.write(row);
     dataWriter.close();
     DataFile dataFile = dataWriter.toDataFile();
 
@@ -295,8 +298,10 @@ public abstract class TestWriterMetrics<T> {
     Map<Integer, ByteBuffer> upperBounds = dataFile.upperBounds();
     Map<Integer, ByteBuffer> lowerBounds = dataFile.upperBounds();
     for (int i = 0; i < numColumns; i++) {
-      Assert.assertEquals(1, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), upperBounds.get(1)));
-      Assert.assertEquals(1, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), lowerBounds.get(1)));
+      Assert.assertEquals(
+          1, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), upperBounds.get(1)));
+      Assert.assertEquals(
+          1, (int) Conversions.fromByteBuffer(Types.IntegerType.get(), lowerBounds.get(1)));
     }
   }
 }
