@@ -30,6 +30,7 @@ import org.apache.iceberg.hive.HiveCatalog;
 import org.apache.iceberg.relocated.com.google.common.base.MoreObjects;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
+import org.apache.iceberg.rest.RESTCatalog;
 
 /** Serializable loader to load an Iceberg {@link Catalog}. */
 public interface CatalogLoader extends Serializable {
@@ -53,6 +54,10 @@ public interface CatalogLoader extends Serializable {
     return new HiveCatalogLoader(name, hadoopConf, properties);
   }
 
+  static CatalogLoader rest(String name, Configuration hadoopConf, Map<String, String> properties) {
+    return new RESTCatalogLoader(name, hadoopConf, properties);
+  }
+
   static CatalogLoader custom(
       String name, Map<String, String> properties, Configuration hadoopConf, String impl) {
     return new CustomCatalogLoader(name, properties, hadoopConf, impl);
@@ -125,6 +130,33 @@ public interface CatalogLoader extends Serializable {
     }
   }
 
+  class RESTCatalogLoader implements CatalogLoader {
+    private final String catalogName;
+    private final SerializableConfiguration hadoopConf;
+    private final Map<String, String> properties;
+
+    private RESTCatalogLoader(
+        String catalogName, Configuration conf, Map<String, String> properties) {
+      this.catalogName = catalogName;
+      this.hadoopConf = new SerializableConfiguration(conf);
+      this.properties = Maps.newHashMap(properties);
+    }
+
+    @Override
+    public Catalog loadCatalog() {
+      return CatalogUtil.loadCatalog(
+          RESTCatalog.class.getName(), catalogName, properties, hadoopConf.get());
+    }
+
+    @Override
+    public String toString() {
+      return MoreObjects.toStringHelper(this)
+          .add("catalogName", catalogName)
+          .add("properties", properties)
+          .toString();
+    }
+  }
+
   class CustomCatalogLoader implements CatalogLoader {
 
     private final SerializableConfiguration hadoopConf;
