@@ -170,7 +170,7 @@ public class TestContinuousSplitPlannerImplStartStrategy {
     AssertHelpers.assertThrows(
         "Should detect invalid starting snapshot timestamp",
         IllegalArgumentException.class,
-        "Cannot find a snapshot older than 1970-01-01T00:00:00.001+00:00",
+        "Cannot find a snapshot after: ",
         () ->
             ContinuousSplitPlannerImpl.startSnapshot(
                 tableResource.table(), scanContextInvalidSnapshotTimestamp));
