@@ -16,9 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.hive;
 
+import static org.apache.iceberg.PartitionSpec.builderFor;
+import static org.apache.iceberg.TableMetadataParser.getFileExtension;
+import static org.apache.iceberg.types.Types.NestedField.optional;
+import static org.apache.iceberg.types.Types.NestedField.required;
+
 import java.io.File;
 import java.nio.file.Paths;
 import java.util.Arrays;
@@ -33,23 +37,20 @@ import org.apache.iceberg.types.Types;
 import org.junit.After;
 import org.junit.Before;
 
-import static org.apache.iceberg.PartitionSpec.builderFor;
-import static org.apache.iceberg.TableMetadataParser.getFileExtension;
-import static org.apache.iceberg.types.Types.NestedField.optional;
-import static org.apache.iceberg.types.Types.NestedField.required;
-
-
 public class HiveTableBaseTest extends HiveMetastoreTest {
 
-  static final String TABLE_NAME =  "tbl";
+  static final String TABLE_NAME = "tbl";
   static final TableIdentifier TABLE_IDENTIFIER = TableIdentifier.of(DB_NAME, TABLE_NAME);
 
-  static final Schema schema = new Schema(Types.StructType.of(
-      required(1, "id", Types.LongType.get())).fields());
+  static final Schema schema =
+      new Schema(Types.StructType.of(required(1, "id", Types.LongType.get())).fields());
 
-  static final Schema altered = new Schema(Types.StructType.of(
-      required(1, "id", Types.LongType.get()),
-      optional(2, "data", Types.LongType.get())).fields());
+  static final Schema altered =
+      new Schema(
+          Types.StructType.of(
+                  required(1, "id", Types.LongType.get()),
+                  optional(2, "data", Types.LongType.get()))
+              .fields());
 
   private static final PartitionSpec partitionSpec = builderFor(schema).identity("id").build();
 
@@ -57,7 +58,8 @@ public class HiveTableBaseTest extends HiveMetastoreTest {
 
   @Before
   public void createTestTable() {
-    this.tableLocation = new Path(catalog.createTable(TABLE_IDENTIFIER, schema, partitionSpec).location());
+    this.tableLocation =
+        new Path(catalog.createTable(TABLE_IDENTIFIER, schema, partitionSpec).location());
   }
 
   @After
@@ -66,6 +68,7 @@ public class HiveTableBaseTest extends HiveMetastoreTest {
     tableLocation.getFileSystem(hiveConf).delete(tableLocation, true);
     catalog.dropTable(TABLE_IDENTIFIER, false /* metadata only, location was already deleted */);
   }
+
   private static String getTableBasePath(String tableName) {
     String databasePath = metastore.getDatabasePath(DB_NAME);
     return Paths.get(databasePath, tableName).toAbsolutePath().toString();
@@ -98,10 +101,8 @@ public class HiveTableBaseTest extends HiveMetastoreTest {
   }
 
   private static List<String> filterByExtension(String tableName, String extension) {
-    return metadataFiles(tableName)
-        .stream()
+    return metadataFiles(tableName).stream()
         .filter(f -> f.endsWith(extension))
         .collect(Collectors.toList());
   }
-
 }
