@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.mr.hive;
 
 import java.util.List;
@@ -50,16 +49,20 @@ import org.slf4j.LoggerFactory;
 
 public class HiveIcebergMetaHook implements HiveMetaHook {
   private static final Logger LOG = LoggerFactory.getLogger(HiveIcebergMetaHook.class);
-  private static final Set<String> PARAMETERS_TO_REMOVE = ImmutableSet
-      .of(InputFormatConfig.TABLE_SCHEMA, Catalogs.LOCATION, Catalogs.NAME);
-  private static final Set<String> PROPERTIES_TO_REMOVE = ImmutableSet
-      // We don't want to push down the metadata location props to Iceberg from HMS,
-      // since the snapshot pointer in HMS would always be one step ahead
-      .of(BaseMetastoreTableOperations.METADATA_LOCATION_PROP,
-      BaseMetastoreTableOperations.PREVIOUS_METADATA_LOCATION_PROP,
-      // Initially we'd like to cache the partition spec in HMS, but not push it down later to Iceberg during alter
-      // table commands since by then the HMS info can be stale + Iceberg does not store its partition spec in the props
-      InputFormatConfig.PARTITION_SPEC);
+  private static final Set<String> PARAMETERS_TO_REMOVE =
+      ImmutableSet.of(InputFormatConfig.TABLE_SCHEMA, Catalogs.LOCATION, Catalogs.NAME);
+  private static final Set<String> PROPERTIES_TO_REMOVE =
+      ImmutableSet
+          // We don't want to push down the metadata location props to Iceberg from HMS,
+          // since the snapshot pointer in HMS would always be one step ahead
+          .of(
+          BaseMetastoreTableOperations.METADATA_LOCATION_PROP,
+          BaseMetastoreTableOperations.PREVIOUS_METADATA_LOCATION_PROP,
+          // Initially we'd like to cache the partition spec in HMS, but not push it down later to
+          // Iceberg during alter
+          // table commands since by then the HMS info can be stale + Iceberg does not store its
+          // partition spec in the props
+          InputFormatConfig.PARTITION_SPEC);
 
   private final Configuration conf;
   private Table icebergTable = null;
@@ -77,8 +80,11 @@ public class HiveIcebergMetaHook implements HiveMetaHook {
     this.catalogProperties = getCatalogProperties(hmsTable);
 
     // Set the table type even for non HiveCatalog based tables
-    hmsTable.getParameters().put(BaseMetastoreTableOperations.TABLE_TYPE_PROP,
-        BaseMetastoreTableOperations.ICEBERG_TABLE_TYPE_VALUE.toUpperCase());
+    hmsTable
+        .getParameters()
+        .put(
+            BaseMetastoreTableOperations.TABLE_TYPE_PROP,
+            BaseMetastoreTableOperations.ICEBERG_TABLE_TYPE_VALUE.toUpperCase());
 
     if (!Catalogs.hiveCatalog(conf, catalogProperties)) {
       // For non-HiveCatalog tables too, we should set the input and output format
@@ -90,9 +96,11 @@ public class HiveIcebergMetaHook implements HiveMetaHook {
       try {
         this.icebergTable = Catalogs.loadTable(conf, catalogProperties);
 
-        Preconditions.checkArgument(catalogProperties.getProperty(InputFormatConfig.TABLE_SCHEMA) == null,
+        Preconditions.checkArgument(
+            catalogProperties.getProperty(InputFormatConfig.TABLE_SCHEMA) == null,
             "Iceberg table already created - can not use provided schema");
-        Preconditions.checkArgument(catalogProperties.getProperty(InputFormatConfig.PARTITION_SPEC) == null,
+        Preconditions.checkArgument(
+            catalogProperties.getProperty(InputFormatConfig.PARTITION_SPEC) == null,
             "Iceberg table already created - can not use provided partition specification");
 
         LOG.info("Iceberg table already exists {}", icebergTable);
@@ -104,13 +112,15 @@ public class HiveIcebergMetaHook implements HiveMetaHook {
     }
 
     // If the table does not exist collect data for table creation
-    // - InputFormatConfig.TABLE_SCHEMA, InputFormatConfig.PARTITION_SPEC takes precedence so the user can override the
+    // - InputFormatConfig.TABLE_SCHEMA, InputFormatConfig.PARTITION_SPEC takes precedence so the
+    // user can override the
     // Iceberg schema and specification generated by the code
 
     Schema schema = schema(catalogProperties, hmsTable);
     PartitionSpec spec = spec(schema, catalogProperties, hmsTable);
 
-    // If there are partition keys specified remove them from the HMS table and add them to the column list
+    // If there are partition keys specified remove them from the HMS table and add them to the
+    // column list
     if (hmsTable.isSetPartitionKeys()) {
       hmsTable.getSd().getCols().addAll(hmsTable.getPartitionKeys());
       hmsTable.setPartitionKeysIsSet(false);
@@ -124,7 +134,8 @@ public class HiveIcebergMetaHook implements HiveMetaHook {
 
     // If the table is not managed by Hive catalog then the location should be set
     if (!Catalogs.hiveCatalog(conf, catalogProperties)) {
-      Preconditions.checkArgument(hmsTable.getSd() != null && hmsTable.getSd().getLocation() != null,
+      Preconditions.checkArgument(
+          hmsTable.getSd() != null && hmsTable.getSd().getLocation() != null,
           "Table location not set");
     }
 
@@ -151,21 +162,29 @@ public class HiveIcebergMetaHook implements HiveMetaHook {
   @Override
   public void preDropTable(org.apache.hadoop.hive.metastore.api.Table hmsTable) {
     this.catalogProperties = getCatalogProperties(hmsTable);
-    this.deleteIcebergTable = hmsTable.getParameters() != null &&
-        "TRUE".equalsIgnoreCase(hmsTable.getParameters().get(InputFormatConfig.EXTERNAL_TABLE_PURGE));
+    this.deleteIcebergTable =
+        hmsTable.getParameters() != null
+            && "TRUE"
+                .equalsIgnoreCase(
+                    hmsTable.getParameters().get(InputFormatConfig.EXTERNAL_TABLE_PURGE));
 
     if (deleteIcebergTable && Catalogs.hiveCatalog(conf, catalogProperties)) {
       // Store the metadata and the io for deleting the actual table data
       try {
-        String metadataLocation = hmsTable.getParameters().get(BaseMetastoreTableOperations.METADATA_LOCATION_PROP);
+        String metadataLocation =
+            hmsTable.getParameters().get(BaseMetastoreTableOperations.METADATA_LOCATION_PROP);
         this.deleteIo = Catalogs.loadTable(conf, catalogProperties).io();
         this.deleteMetadata = TableMetadataParser.read(deleteIo, metadataLocation);
       } catch (Exception e) {
-        LOG.error("preDropTable: Error during loading Iceberg table or parsing its metadata for HMS table: {}.{}. " +
-            "In some cases, this might lead to undeleted metadata files under the table directory: {}. " +
-            "Please double check and, if needed, manually delete any dangling files/folders, if any. " +
-            "In spite of this error, the HMS table drop operation should proceed as normal.",
-            hmsTable.getDbName(), hmsTable.getTableName(), hmsTable.getSd().getLocation(), e);
+        LOG.error(
+            "preDropTable: Error during loading Iceberg table or parsing its metadata for HMS table: {}.{}. "
+                + "In some cases, this might lead to undeleted metadata files under the table directory: {}. "
+                + "Please double check and, if needed, manually delete any dangling files/folders, if any. "
+                + "In spite of this error, the HMS table drop operation should proceed as normal.",
+            hmsTable.getDbName(),
+            hmsTable.getTableName(),
+            hmsTable.getSd().getLocation(),
+            e);
       }
     }
   }
@@ -176,54 +195,75 @@ public class HiveIcebergMetaHook implements HiveMetaHook {
   }
 
   @Override
-  public void commitDropTable(org.apache.hadoop.hive.metastore.api.Table hmsTable, boolean deleteData) {
+  public void commitDropTable(
+      org.apache.hadoop.hive.metastore.api.Table hmsTable, boolean deleteData) {
     if (deleteData && deleteIcebergTable) {
       try {
         if (!Catalogs.hiveCatalog(conf, catalogProperties)) {
-          LOG.info("Dropping with purge all the data for table {}.{}", hmsTable.getDbName(), hmsTable.getTableName());
+          LOG.info(
+              "Dropping with purge all the data for table {}.{}",
+              hmsTable.getDbName(),
+              hmsTable.getTableName());
           Catalogs.dropTable(conf, catalogProperties);
         } else {
-          // do nothing if metadata folder has been deleted already (Hive 4 behaviour for purge=TRUE)
+          // do nothing if metadata folder has been deleted already (Hive 4 behaviour for
+          // purge=TRUE)
           if (deleteMetadata != null && deleteIo.newInputFile(deleteMetadata.location()).exists()) {
             CatalogUtil.dropTableData(deleteIo, deleteMetadata);
           }
         }
       } catch (Exception e) {
-        // we want to successfully complete the Hive DROP TABLE command despite catalog-related exceptions here
-        // e.g. we wish to successfully delete a Hive table even if the underlying Hadoop table has already been deleted
-        LOG.warn("Exception during commitDropTable operation for table {}.{}.",
-            hmsTable.getDbName(), hmsTable.getTableName(), e);
+        // we want to successfully complete the Hive DROP TABLE command despite catalog-related
+        // exceptions here
+        // e.g. we wish to successfully delete a Hive table even if the underlying Hadoop table has
+        // already been deleted
+        LOG.warn(
+            "Exception during commitDropTable operation for table {}.{}.",
+            hmsTable.getDbName(),
+            hmsTable.getTableName(),
+            e);
       }
     }
   }
 
   /**
    * Calculates the properties we would like to send to the catalog.
+   *
    * <ul>
-   * <li>The base of the properties is the properties stored at the Hive Metastore for the given table
-   * <li>We add the {@link Catalogs#LOCATION} as the table location
-   * <li>We add the {@link Catalogs#NAME} as TableIdentifier defined by the database name and table name
-   * <li>We remove some parameters that we don't want to push down to the Iceberg table props
+   *   <li>The base of the properties is the properties stored at the Hive Metastore for the given
+   *       table
+   *   <li>We add the {@link Catalogs#LOCATION} as the table location
+   *   <li>We add the {@link Catalogs#NAME} as TableIdentifier defined by the database name and
+   *       table name
+   *   <li>We remove some parameters that we don't want to push down to the Iceberg table props
    * </ul>
+   *
    * @param hmsTable Table for which we are calculating the properties
    * @return The properties we can provide for Iceberg functions, like {@link Catalogs}
    */
-  private static Properties getCatalogProperties(org.apache.hadoop.hive.metastore.api.Table hmsTable) {
+  private static Properties getCatalogProperties(
+      org.apache.hadoop.hive.metastore.api.Table hmsTable) {
     Properties properties = new Properties();
 
-    hmsTable.getParameters().forEach((key, value) -> {
-      // translate key names between HMS and Iceberg where needed
-      String icebergKey = HiveTableOperations.translateToIcebergProp(key);
-      properties.put(icebergKey, value);
-    });
+    hmsTable
+        .getParameters()
+        .forEach(
+            (key, value) -> {
+              // translate key names between HMS and Iceberg where needed
+              String icebergKey = HiveTableOperations.translateToIcebergProp(key);
+              properties.put(icebergKey, value);
+            });
 
-    if (properties.get(Catalogs.LOCATION) == null &&
-        hmsTable.getSd() != null && hmsTable.getSd().getLocation() != null) {
+    if (properties.get(Catalogs.LOCATION) == null
+        && hmsTable.getSd() != null
+        && hmsTable.getSd().getLocation() != null) {
       properties.put(Catalogs.LOCATION, hmsTable.getSd().getLocation());
     }
 
     if (properties.get(Catalogs.NAME) == null) {
-      properties.put(Catalogs.NAME, TableIdentifier.of(hmsTable.getDbName(), hmsTable.getTableName()).toString());
+      properties.put(
+          Catalogs.NAME,
+          TableIdentifier.of(hmsTable.getDbName(), hmsTable.getTableName()).toString());
     }
 
     // Remove HMS table parameters we don't want to propagate to Iceberg
@@ -232,7 +272,8 @@ public class HiveIcebergMetaHook implements HiveMetaHook {
     return properties;
   }
 
-  private Schema schema(Properties properties, org.apache.hadoop.hive.metastore.api.Table hmsTable) {
+  private Schema schema(
+      Properties properties, org.apache.hadoop.hive.metastore.api.Table hmsTable) {
     boolean autoConversion = conf.getBoolean(InputFormatConfig.SCHEMA_AUTO_CONVERSION, false);
 
     if (properties.getProperty(InputFormatConfig.TABLE_SCHEMA) != null) {
@@ -247,16 +288,20 @@ public class HiveIcebergMetaHook implements HiveMetaHook {
     }
   }
 
-  private static PartitionSpec spec(Schema schema, Properties properties,
-      org.apache.hadoop.hive.metastore.api.Table hmsTable) {
+  private static PartitionSpec spec(
+      Schema schema, Properties properties, org.apache.hadoop.hive.metastore.api.Table hmsTable) {
 
     if (hmsTable.getParameters().get(InputFormatConfig.PARTITION_SPEC) != null) {
-      Preconditions.checkArgument(!hmsTable.isSetPartitionKeys() || hmsTable.getPartitionKeys().isEmpty(),
-          "Provide only one of the following: Hive partition specification, or the " +
-              InputFormatConfig.PARTITION_SPEC + " property");
-      return PartitionSpecParser.fromJson(schema, hmsTable.getParameters().get(InputFormatConfig.PARTITION_SPEC));
+      Preconditions.checkArgument(
+          !hmsTable.isSetPartitionKeys() || hmsTable.getPartitionKeys().isEmpty(),
+          "Provide only one of the following: Hive partition specification, or the "
+              + InputFormatConfig.PARTITION_SPEC
+              + " property");
+      return PartitionSpecParser.fromJson(
+          schema, hmsTable.getParameters().get(InputFormatConfig.PARTITION_SPEC));
     } else if (hmsTable.isSetPartitionKeys() && !hmsTable.getPartitionKeys().isEmpty()) {
-      // If the table is partitioned then generate the identity partition definitions for the Iceberg table
+      // If the table is partitioned then generate the identity partition definitions for the
+      // Iceberg table
       return HiveSchemaUtil.spec(schema, hmsTable.getPartitionKeys());
     } else {
       return PartitionSpec.unpartitioned();
