@@ -16,10 +16,8 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.mr.hive;
 
-import java.util.Locale;
 import java.util.Properties;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
@@ -45,18 +43,24 @@ import org.apache.iceberg.mr.Catalogs;
 import org.apache.iceberg.mr.mapred.Container;
 import org.apache.iceberg.util.PropertyUtil;
 
-public class HiveIcebergOutputFormat<T> implements OutputFormat<NullWritable, Container<Record>>,
-    HiveOutputFormat<NullWritable, Container<Record>> {
+public class HiveIcebergOutputFormat<T>
+    implements OutputFormat<NullWritable, Container<Record>>,
+        HiveOutputFormat<NullWritable, Container<Record>> {
 
   @Override
-  public FileSinkOperator.RecordWriter getHiveRecordWriter(JobConf jc, Path finalOutPath, Class valueClass,
-      boolean isCompressed, Properties tableAndSerDeProperties, Progressable progress) {
+  public FileSinkOperator.RecordWriter getHiveRecordWriter(
+      JobConf jc,
+      Path finalOutPath,
+      Class valueClass,
+      boolean isCompressed,
+      Properties tableAndSerDeProperties,
+      Progressable progress) {
     return writer(jc);
   }
 
   @Override
-  public org.apache.hadoop.mapred.RecordWriter<NullWritable, Container<Record>> getRecordWriter(FileSystem ignored,
-      JobConf job, String name, Progressable progress) {
+  public org.apache.hadoop.mapred.RecordWriter<NullWritable, Container<Record>> getRecordWriter(
+      FileSystem ignored, JobConf job, String name, Progressable progress) {
     return writer(job);
   }
 
@@ -68,24 +72,42 @@ public class HiveIcebergOutputFormat<T> implements OutputFormat<NullWritable, Co
   private static HiveIcebergRecordWriter writer(JobConf jc) {
     TaskAttemptID taskAttemptID = TezUtil.taskAttemptWrapper(jc);
     // It gets the config from the FileSinkOperator which has its own config for every target table
-    Table table = HiveIcebergStorageHandler.table(jc, jc.get(hive_metastoreConstants.META_TABLE_NAME));
+    Table table =
+        HiveIcebergStorageHandler.table(jc, jc.get(hive_metastoreConstants.META_TABLE_NAME));
     Schema schema = HiveIcebergStorageHandler.schema(jc);
     PartitionSpec spec = table.spec();
-    FileFormat fileFormat = FileFormat.valueOf(PropertyUtil.propertyAsString(table.properties(),
-        TableProperties.DEFAULT_FILE_FORMAT, TableProperties.DEFAULT_FILE_FORMAT_DEFAULT).toUpperCase(Locale.ENGLISH));
-    long targetFileSize = PropertyUtil.propertyAsLong(table.properties(), TableProperties.WRITE_TARGET_FILE_SIZE_BYTES,
+    FileFormat fileFormat =
+        FileFormat.fromString(
+            PropertyUtil.propertyAsString(
+                table.properties(),
+                TableProperties.DEFAULT_FILE_FORMAT,
+                TableProperties.DEFAULT_FILE_FORMAT_DEFAULT));
+    long targetFileSize =
+        PropertyUtil.propertyAsLong(
+            table.properties(),
+            TableProperties.WRITE_TARGET_FILE_SIZE_BYTES,
             TableProperties.WRITE_TARGET_FILE_SIZE_BYTES_DEFAULT);
     FileIO io = table.io();
     int partitionId = taskAttemptID.getTaskID().getId();
     int taskId = taskAttemptID.getId();
-    String operationId = jc.get(HiveConf.ConfVars.HIVEQUERYID.varname) + "-" + taskAttemptID.getJobID();
-    OutputFileFactory outputFileFactory = OutputFileFactory.builderFor(table, partitionId, taskId)
-        .format(fileFormat)
-        .operationId(operationId)
-        .build();
+    String operationId =
+        jc.get(HiveConf.ConfVars.HIVEQUERYID.varname) + "-" + taskAttemptID.getJobID();
+    OutputFileFactory outputFileFactory =
+        OutputFileFactory.builderFor(table, partitionId, taskId)
+            .format(fileFormat)
+            .operationId(operationId)
+            .build();
     String tableName = jc.get(Catalogs.NAME);
 
-    return new HiveIcebergRecordWriter(schema, spec, fileFormat,
-        new GenericAppenderFactory(schema, spec), outputFileFactory, io, targetFileSize, taskAttemptID, tableName);
+    return new HiveIcebergRecordWriter(
+        schema,
+        spec,
+        fileFormat,
+        new GenericAppenderFactory(schema, spec),
+        outputFileFactory,
+        io,
+        targetFileSize,
+        taskAttemptID,
+        tableName);
   }
 }
