@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.mr;
 
+import static org.apache.iceberg.types.Types.NestedField.required;
+
 import java.io.File;
 import java.io.IOException;
 import java.io.UncheckedIOException;
 import java.util.List;
-import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 import java.util.function.Function;
@@ -69,29 +69,28 @@ import org.junit.rules.TemporaryFolder;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 
-import static org.apache.iceberg.types.Types.NestedField.required;
-
 @RunWith(Parameterized.class)
 public class TestIcebergInputFormats {
 
-  public static final List<TestInputFormat.Factory<Record>> TESTED_INPUT_FORMATS = ImmutableList.of(
+  public static final List<TestInputFormat.Factory<Record>> TESTED_INPUT_FORMATS =
+      ImmutableList.of(
           TestInputFormat.newFactory("IcebergInputFormat", TestIcebergInputFormat::create),
-          TestInputFormat.newFactory("MapredIcebergInputFormat", TestMapredIcebergInputFormat::create));
+          TestInputFormat.newFactory(
+              "MapredIcebergInputFormat", TestMapredIcebergInputFormat::create));
 
-  private static final List<String> TESTED_FILE_FORMATS = ImmutableList.of("avro", "orc", "parquet");
+  private static final List<String> TESTED_FILE_FORMATS =
+      ImmutableList.of("avro", "orc", "parquet");
 
-  private static final Schema SCHEMA = new Schema(
+  private static final Schema SCHEMA =
+      new Schema(
           required(1, "data", Types.StringType.get()),
           required(2, "id", Types.LongType.get()),
           required(3, "date", Types.StringType.get()));
 
-  private static final PartitionSpec SPEC = PartitionSpec.builderFor(SCHEMA)
-          .identity("date")
-          .bucket("id", 1)
-          .build();
+  private static final PartitionSpec SPEC =
+      PartitionSpec.builderFor(SCHEMA).identity("date").bucket("id", 1).build();
 
-  @Rule
-  public TemporaryFolder temp = new TemporaryFolder();
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
   // before variables
   private Configuration conf;
@@ -105,7 +104,7 @@ public class TestIcebergInputFormats {
   @Before
   public void before() throws IOException {
     conf = new Configuration();
-    conf.set(InputFormatConfig.CATALOG, Catalogs.LOCATION);
+    conf.set(CatalogUtil.ICEBERG_CATALOG_TYPE, Catalogs.LOCATION);
     HadoopTables tables = new HadoopTables(conf);
 
     File location = temp.newFolder(testInputFormat.name(), fileFormat.name());
@@ -130,9 +129,10 @@ public class TestIcebergInputFormats {
     return parameters;
   }
 
-  public TestIcebergInputFormats(TestInputFormat.Factory<Record> testInputFormat, String fileFormat) {
+  public TestIcebergInputFormats(
+      TestInputFormat.Factory<Record> testInputFormat, String fileFormat) {
     this.testInputFormat = testInputFormat;
-    this.fileFormat = FileFormat.valueOf(fileFormat.toUpperCase(Locale.ENGLISH));
+    this.fileFormat = FileFormat.fromString(fileFormat);
   }
 
   @Test
@@ -163,7 +163,8 @@ public class TestIcebergInputFormats {
     expectedRecords.get(1).set(2, "2020-03-20");
 
     DataFile dataFile1 = helper.writeFile(Row.of("2020-03-20", 0), expectedRecords);
-    DataFile dataFile2 = helper.writeFile(Row.of("2020-03-21", 0), helper.generateRandomRecords(2, 0L));
+    DataFile dataFile2 =
+        helper.writeFile(Row.of("2020-03-21", 0), helper.generateRandomRecords(2, 0L));
     helper.appendToTable(dataFile1, dataFile2);
 
     builder.filter(Expressions.equal("date", "2020-03-20"));
@@ -184,12 +185,12 @@ public class TestIcebergInputFormats {
     expectedRecords.add(writeRecords.get(0));
 
     DataFile dataFile1 = helper.writeFile(Row.of("2020-03-20", 0), writeRecords);
-    DataFile dataFile2 = helper.writeFile(Row.of("2020-03-21", 0), helper.generateRandomRecords(2, 0L));
+    DataFile dataFile2 =
+        helper.writeFile(Row.of("2020-03-21", 0), helper.generateRandomRecords(2, 0L));
     helper.appendToTable(dataFile1, dataFile2);
 
-    builder.filter(Expressions.and(
-            Expressions.equal("date", "2020-03-20"),
-            Expressions.equal("id", 123)));
+    builder.filter(
+        Expressions.and(Expressions.equal("date", "2020-03-20"), Expressions.equal("id", 123)));
     testInputFormat.create(builder.conf()).validate(expectedRecords);
 
     // skip residual filtering
@@ -207,21 +208,23 @@ public class TestIcebergInputFormats {
 
     helper.appendToTable(Row.of("2020-03-20", 0), expectedRecords);
 
-    builder.useHiveRows()
-           .filter(Expressions.and(
-                   Expressions.equal("date", "2020-03-20"),
-                   Expressions.equal("id", 0)));
+    builder
+        .useHiveRows()
+        .filter(
+            Expressions.and(Expressions.equal("date", "2020-03-20"), Expressions.equal("id", 0)));
 
     AssertHelpers.assertThrows(
         "Residuals are not evaluated today for Iceberg Generics In memory model of HIVE",
-        UnsupportedOperationException.class, "Filter expression ref(name=\"id\") == 0 is not completely satisfied.",
+        UnsupportedOperationException.class,
+        "Filter expression ref(name=\"id\") == 0 is not completely satisfied.",
         () -> testInputFormat.create(builder.conf()));
 
     builder.usePigTuples();
 
     AssertHelpers.assertThrows(
         "Residuals are not evaluated today for Iceberg Generics In memory model of PIG",
-        UnsupportedOperationException.class, "Filter expression ref(name=\"id\") == 0 is not completely satisfied.",
+        UnsupportedOperationException.class,
+        "Filter expression ref(name=\"id\") == 0 is not completely satisfied.",
         () -> testInputFormat.create(builder.conf()));
   }
 
@@ -240,15 +243,15 @@ public class TestIcebergInputFormats {
     Assert.assertEquals(projection.asStruct(), outputRecords.get(0).struct());
   }
 
-  private static final Schema LOG_SCHEMA = new Schema(
+  private static final Schema LOG_SCHEMA =
+      new Schema(
           Types.NestedField.optional(1, "id", Types.IntegerType.get()),
           Types.NestedField.optional(2, "date", Types.StringType.get()),
           Types.NestedField.optional(3, "level", Types.StringType.get()),
-          Types.NestedField.optional(4, "message", Types.StringType.get())
-  );
+          Types.NestedField.optional(4, "message", Types.StringType.get()));
 
   private static final PartitionSpec IDENTITY_PARTITION_SPEC =
-          PartitionSpec.builderFor(LOG_SCHEMA).identity("date").identity("level").build();
+      PartitionSpec.builderFor(LOG_SCHEMA).identity("date").identity("level").build();
 
   @Test
   public void testIdentityPartitionProjections() throws Exception {
@@ -260,7 +263,8 @@ public class TestIcebergInputFormats {
     for (Record record : inputRecords) {
       record.set(1, "2020-03-2" + idx);
       record.set(2, idx.toString());
-      append.appendFile(helper.writeFile(Row.of("2020-03-2" + idx, idx.toString()), ImmutableList.of(record)));
+      append.appendFile(
+          helper.writeFile(Row.of("2020-03-2" + idx, idx.toString()), ImmutableList.of(record)));
       idx += 1;
     }
     append.commit();
@@ -298,7 +302,8 @@ public class TestIcebergInputFormats {
     return TypeUtil.select(LOG_SCHEMA, projectedIds);
   }
 
-  private void validateIdentityPartitionProjections(Schema projectedSchema, List<Record> inputRecords) {
+  private void validateIdentityPartitionProjections(
+      Schema projectedSchema, List<Record> inputRecords) {
     builder.project(projectedSchema);
     List<Record> actualRecords = testInputFormat.create(builder.conf()).getRecords();
 
@@ -307,11 +312,14 @@ public class TestIcebergInputFormats {
     for (int pos = 0; pos < inputRecords.size(); pos++) {
       Record inputRecord = inputRecords.get(pos);
       Record actualRecord = actualRecords.get(pos);
-      Assert.assertEquals("Projected schema should match", projectedSchema.asStruct(), actualRecord.struct());
+      Assert.assertEquals(
+          "Projected schema should match", projectedSchema.asStruct(), actualRecord.struct());
 
       for (String name : fieldNames) {
         Assert.assertEquals(
-                "Projected field " + name + " should match", inputRecord.getField(name), actualRecord.getField(name));
+            "Projected field " + name + " should match",
+            inputRecord.getField(name),
+            actualRecord.getField(name));
       }
     }
   }
@@ -337,13 +345,13 @@ public class TestIcebergInputFormats {
     helper.appendToTable(null, expectedRecords);
 
     for (InputSplit split : testInputFormat.create(builder.conf()).getSplits()) {
-      Assert.assertArrayEquals(new String[]{"*"}, split.getLocations());
+      Assert.assertArrayEquals(new String[] {"*"}, split.getLocations());
     }
 
     builder.preferLocality();
 
     for (InputSplit split : testInputFormat.create(builder.conf()).getSplits()) {
-      Assert.assertArrayEquals(new String[]{"localhost"}, split.getLocations());
+      Assert.assertArrayEquals(new String[] {"localhost"}, split.getLocations());
     }
   }
 
@@ -352,10 +360,14 @@ public class TestIcebergInputFormats {
     String warehouseLocation = temp.newFolder("hadoop_catalog").getAbsolutePath();
     conf.set("warehouse.location", warehouseLocation);
     conf.set(InputFormatConfig.CATALOG_NAME, Catalogs.ICEBERG_DEFAULT_CATALOG_NAME);
-    conf.set(InputFormatConfig.catalogPropertyConfigKey(Catalogs.ICEBERG_DEFAULT_CATALOG_NAME,
-        CatalogUtil.ICEBERG_CATALOG_TYPE), CatalogUtil.ICEBERG_CATALOG_TYPE_HADOOP);
-    conf.set(InputFormatConfig.catalogPropertyConfigKey(Catalogs.ICEBERG_DEFAULT_CATALOG_NAME,
-        CatalogProperties.WAREHOUSE_LOCATION), warehouseLocation);
+    conf.set(
+        InputFormatConfig.catalogPropertyConfigKey(
+            Catalogs.ICEBERG_DEFAULT_CATALOG_NAME, CatalogUtil.ICEBERG_CATALOG_TYPE),
+        CatalogUtil.ICEBERG_CATALOG_TYPE_HADOOP);
+    conf.set(
+        InputFormatConfig.catalogPropertyConfigKey(
+            Catalogs.ICEBERG_DEFAULT_CATALOG_NAME, CatalogProperties.WAREHOUSE_LOCATION),
+        warehouseLocation);
 
     Catalog catalog = new HadoopCatalog(conf, conf.get("warehouse.location"));
     TableIdentifier identifier = TableIdentifier.of("db", "t");
@@ -371,7 +383,8 @@ public class TestIcebergInputFormats {
     testInputFormat.create(builder.conf()).validate(expectedRecords);
   }
 
-  // TODO - Capture template type T in toString method: https://github.com/apache/iceberg/issues/1542
+  // TODO - Capture template type T in toString method:
+  // https://github.com/apache/iceberg/issues/1542
   public abstract static class TestInputFormat<T> {
 
     private final List<IcebergSplit> splits;
@@ -396,10 +409,12 @@ public class TestIcebergInputFormats {
 
     public interface Factory<T> {
       String name();
+
       TestInputFormat<T> create(Configuration conf);
     }
 
-    public static <T> Factory<T> newFactory(String name, Function<Configuration, TestInputFormat<T>> function) {
+    public static <T> Factory<T> newFactory(
+        String name, Function<Configuration, TestInputFormat<T>> function) {
       return new Factory<T>() {
         @Override
         public String name() {
@@ -437,8 +452,8 @@ public class TestIcebergInputFormats {
 
         for (org.apache.hadoop.mapred.InputSplit split : splits) {
           iceSplits.add((IcebergSplit) split);
-          org.apache.hadoop.mapred.RecordReader<Void, Container<T>>
-                  reader = inputFormat.getRecordReader(split, job, Reporter.NULL);
+          org.apache.hadoop.mapred.RecordReader<Void, Container<T>> reader =
+              inputFormat.getRecordReader(split, job, Reporter.NULL);
 
           try {
             Container<T> container = reader.createValue();
