@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.parquet;
 
 import java.io.File;
@@ -34,6 +33,7 @@ import org.apache.iceberg.data.Record;
 import org.apache.iceberg.data.parquet.GenericParquetReaders;
 import org.apache.iceberg.data.parquet.GenericParquetWriter;
 import org.apache.iceberg.deletes.EqualityDeleteWriter;
+import org.apache.iceberg.deletes.PositionDelete;
 import org.apache.iceberg.deletes.PositionDeleteWriter;
 import org.apache.iceberg.io.CloseableIterable;
 import org.apache.iceberg.io.OutputFile;
@@ -49,14 +49,14 @@ import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 
 public class TestParquetDeleteWriters {
-  private static final Schema SCHEMA = new Schema(
-      NestedField.required(1, "id", Types.LongType.get()),
-      NestedField.optional(2, "data", Types.StringType.get()));
+  private static final Schema SCHEMA =
+      new Schema(
+          NestedField.required(1, "id", Types.LongType.get()),
+          NestedField.optional(2, "data", Types.StringType.get()));
 
   private List<Record> records;
 
-  @Rule
-  public TemporaryFolder temp = new TemporaryFolder();
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
   @Before
   public void createDeleteRecords() {
@@ -77,30 +77,33 @@ public class TestParquetDeleteWriters {
     File deleteFile = temp.newFile();
 
     OutputFile out = Files.localOutput(deleteFile);
-    EqualityDeleteWriter<Record> deleteWriter = Parquet.writeDeletes(out)
-        .createWriterFunc(GenericParquetWriter::buildWriter)
-        .overwrite()
-        .rowSchema(SCHEMA)
-        .withSpec(PartitionSpec.unpartitioned())
-        .equalityFieldIds(1)
-        .buildEqualityWriter();
+    EqualityDeleteWriter<Record> deleteWriter =
+        Parquet.writeDeletes(out)
+            .createWriterFunc(GenericParquetWriter::buildWriter)
+            .overwrite()
+            .rowSchema(SCHEMA)
+            .withSpec(PartitionSpec.unpartitioned())
+            .equalityFieldIds(1)
+            .buildEqualityWriter();
 
     try (EqualityDeleteWriter<Record> writer = deleteWriter) {
-      writer.deleteAll(records);
+      writer.write(records);
     }
 
     DeleteFile metadata = deleteWriter.toDeleteFile();
     Assert.assertEquals("Format should be Parquet", FileFormat.PARQUET, metadata.format());
-    Assert.assertEquals("Should be equality deletes", FileContent.EQUALITY_DELETES, metadata.content());
+    Assert.assertEquals(
+        "Should be equality deletes", FileContent.EQUALITY_DELETES, metadata.content());
     Assert.assertEquals("Record count should be correct", records.size(), metadata.recordCount());
     Assert.assertEquals("Partition should be empty", 0, metadata.partition().size());
     Assert.assertNull("Key metadata should be null", metadata.keyMetadata());
 
     List<Record> deletedRecords;
-    try (CloseableIterable<Record> reader = Parquet.read(out.toInputFile())
-        .project(SCHEMA)
-        .createReaderFunc(fileSchema -> GenericParquetReaders.buildReader(SCHEMA, fileSchema))
-        .build()) {
+    try (CloseableIterable<Record> reader =
+        Parquet.read(out.toInputFile())
+            .project(SCHEMA)
+            .createReaderFunc(fileSchema -> GenericParquetReaders.buildReader(SCHEMA, fileSchema))
+            .build()) {
       deletedRecords = Lists.newArrayList(reader);
     }
 
@@ -111,99 +114,112 @@ public class TestParquetDeleteWriters {
   public void testPositionDeleteWriter() throws IOException {
     File deleteFile = temp.newFile();
 
-    Schema deleteSchema = new Schema(
-        MetadataColumns.DELETE_FILE_PATH,
-        MetadataColumns.DELETE_FILE_POS,
-        NestedField.optional(MetadataColumns.DELETE_FILE_ROW_FIELD_ID, "row", SCHEMA.asStruct()));
+    Schema deleteSchema =
+        new Schema(
+            MetadataColumns.DELETE_FILE_PATH,
+            MetadataColumns.DELETE_FILE_POS,
+            NestedField.optional(
+                MetadataColumns.DELETE_FILE_ROW_FIELD_ID, "row", SCHEMA.asStruct()));
 
     String deletePath = "s3://bucket/path/file.parquet";
     GenericRecord posDelete = GenericRecord.create(deleteSchema);
     List<Record> expectedDeleteRecords = Lists.newArrayList();
 
     OutputFile out = Files.localOutput(deleteFile);
-    PositionDeleteWriter<Record> deleteWriter = Parquet.writeDeletes(out)
-        .createWriterFunc(GenericParquetWriter::buildWriter)
-        .overwrite()
-        .rowSchema(SCHEMA)
-        .withSpec(PartitionSpec.unpartitioned())
-        .buildPositionWriter();
+    PositionDeleteWriter<Record> deleteWriter =
+        Parquet.writeDeletes(out)
+            .createWriterFunc(GenericParquetWriter::buildWriter)
+            .overwrite()
+            .rowSchema(SCHEMA)
+            .withSpec(PartitionSpec.unpartitioned())
+            .buildPositionWriter();
 
+    PositionDelete<Record> positionDelete = PositionDelete.create();
     try (PositionDeleteWriter<Record> writer = deleteWriter) {
       for (int i = 0; i < records.size(); i += 1) {
         int pos = i * 3 + 2;
-        writer.delete(deletePath, pos, records.get(i));
-        expectedDeleteRecords.add(posDelete.copy(ImmutableMap.of(
-            "file_path", deletePath,
-            "pos", (long) pos,
-            "row", records.get(i))));
+        writer.write(positionDelete.set(deletePath, pos, records.get(i)));
+        expectedDeleteRecords.add(
+            posDelete.copy(
+                ImmutableMap.of(
+                    "file_path", deletePath, "pos", (long) pos, "row", records.get(i))));
       }
     }
 
     DeleteFile metadata = deleteWriter.toDeleteFile();
     Assert.assertEquals("Format should be Parquet", FileFormat.PARQUET, metadata.format());
-    Assert.assertEquals("Should be position deletes", FileContent.POSITION_DELETES, metadata.content());
+    Assert.assertEquals(
+        "Should be position deletes", FileContent.POSITION_DELETES, metadata.content());
     Assert.assertEquals("Record count should be correct", records.size(), metadata.recordCount());
     Assert.assertEquals("Partition should be empty", 0, metadata.partition().size());
     Assert.assertNull("Key metadata should be null", metadata.keyMetadata());
 
     List<Record> deletedRecords;
-    try (CloseableIterable<Record> reader = Parquet.read(out.toInputFile())
-        .project(deleteSchema)
-        .createReaderFunc(fileSchema -> GenericParquetReaders.buildReader(deleteSchema, fileSchema))
-        .build()) {
+    try (CloseableIterable<Record> reader =
+        Parquet.read(out.toInputFile())
+            .project(deleteSchema)
+            .createReaderFunc(
+                fileSchema -> GenericParquetReaders.buildReader(deleteSchema, fileSchema))
+            .build()) {
       deletedRecords = Lists.newArrayList(reader);
     }
 
-    Assert.assertEquals("Deleted records should match expected", expectedDeleteRecords, deletedRecords);
+    Assert.assertEquals(
+        "Deleted records should match expected", expectedDeleteRecords, deletedRecords);
   }
 
   @Test
   public void testPositionDeleteWriterWithEmptyRow() throws IOException {
     File deleteFile = temp.newFile();
 
-    Schema deleteSchema = new Schema(
-        MetadataColumns.DELETE_FILE_PATH,
-        MetadataColumns.DELETE_FILE_POS);
+    Schema deleteSchema =
+        new Schema(MetadataColumns.DELETE_FILE_PATH, MetadataColumns.DELETE_FILE_POS);
 
     String deletePath = "s3://bucket/path/file.parquet";
     GenericRecord posDelete = GenericRecord.create(deleteSchema);
     List<Record> expectedDeleteRecords = Lists.newArrayList();
 
     OutputFile out = Files.localOutput(deleteFile);
-    PositionDeleteWriter<Void> deleteWriter = Parquet.writeDeletes(out)
-        .createWriterFunc(GenericParquetWriter::buildWriter)
-        .overwrite()
-        .withSpec(PartitionSpec.unpartitioned())
-        .transformPaths(path -> {
-          throw new RuntimeException("Should not be called for performance reasons");
-        })
-        .buildPositionWriter();
+    PositionDeleteWriter<Void> deleteWriter =
+        Parquet.writeDeletes(out)
+            .createWriterFunc(GenericParquetWriter::buildWriter)
+            .overwrite()
+            .withSpec(PartitionSpec.unpartitioned())
+            .transformPaths(
+                path -> {
+                  throw new RuntimeException("Should not be called for performance reasons");
+                })
+            .buildPositionWriter();
 
+    PositionDelete<Void> positionDelete = PositionDelete.create();
     try (PositionDeleteWriter<Void> writer = deleteWriter) {
       for (int i = 0; i < records.size(); i += 1) {
         int pos = i * 3 + 2;
-        writer.delete(deletePath, pos, null);
-        expectedDeleteRecords.add(posDelete.copy(ImmutableMap.of(
-            "file_path", deletePath,
-            "pos", (long) pos)));
+        writer.write(positionDelete.set(deletePath, pos, null));
+        expectedDeleteRecords.add(
+            posDelete.copy(ImmutableMap.of("file_path", deletePath, "pos", (long) pos)));
       }
     }
 
     DeleteFile metadata = deleteWriter.toDeleteFile();
     Assert.assertEquals("Format should be Parquet", FileFormat.PARQUET, metadata.format());
-    Assert.assertEquals("Should be position deletes", FileContent.POSITION_DELETES, metadata.content());
+    Assert.assertEquals(
+        "Should be position deletes", FileContent.POSITION_DELETES, metadata.content());
     Assert.assertEquals("Record count should be correct", records.size(), metadata.recordCount());
     Assert.assertEquals("Partition should be empty", 0, metadata.partition().size());
     Assert.assertNull("Key metadata should be null", metadata.keyMetadata());
 
     List<Record> deletedRecords;
-    try (CloseableIterable<Record> reader = Parquet.read(out.toInputFile())
-        .project(deleteSchema)
-        .createReaderFunc(fileSchema -> GenericParquetReaders.buildReader(deleteSchema, fileSchema))
-        .build()) {
+    try (CloseableIterable<Record> reader =
+        Parquet.read(out.toInputFile())
+            .project(deleteSchema)
+            .createReaderFunc(
+                fileSchema -> GenericParquetReaders.buildReader(deleteSchema, fileSchema))
+            .build()) {
       deletedRecords = Lists.newArrayList(reader);
     }
 
-    Assert.assertEquals("Deleted records should match expected", expectedDeleteRecords, deletedRecords);
+    Assert.assertEquals(
+        "Deleted records should match expected", expectedDeleteRecords, deletedRecords);
   }
 }
