@@ -16,9 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark.source.orc;
 
+import static org.apache.iceberg.TableProperties.DEFAULT_FILE_FORMAT;
+import static org.apache.iceberg.TableProperties.SPLIT_OPEN_FILE_COST;
+import static org.apache.spark.sql.functions.current_date;
+import static org.apache.spark.sql.functions.date_add;
+import static org.apache.spark.sql.functions.expr;
+
 import java.io.IOException;
 import java.util.Map;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
@@ -31,19 +36,12 @@ import org.openjdk.jmh.annotations.Setup;
 import org.openjdk.jmh.annotations.TearDown;
 import org.openjdk.jmh.annotations.Threads;
 
-import static org.apache.iceberg.TableProperties.DEFAULT_FILE_FORMAT;
-import static org.apache.iceberg.TableProperties.SPLIT_OPEN_FILE_COST;
-import static org.apache.spark.sql.functions.current_date;
-import static org.apache.spark.sql.functions.date_add;
-import static org.apache.spark.sql.functions.expr;
-
 /**
- * A benchmark that evaluates the performance of reading ORC data with a flat schema
- * using Iceberg and the built-in file source in Spark.
+ * A benchmark that evaluates the performance of reading ORC data with a flat schema using Iceberg
+ * and the built-in file source in Spark.
  *
- * To run this benchmark for spark-3.1:
- * <code>
- *   ./gradlew -DsparkVersions=3.1 :iceberg-spark:iceberg-spark-3.1_2.12:jmh
+ * <p>To run this benchmark for spark-2.4: <code>
+ *   ./gradlew -DsparkVersions=2.4 :iceberg-spark:iceberg-spark-2.4:jmh
  *       -PjmhIncludeRegex=IcebergSourceFlatORCDataReadBenchmark
  *       -PjmhOutputPath=benchmark/iceberg-source-flat-orc-data-read-benchmark-result.txt
  * </code>
@@ -70,11 +68,13 @@ public class IcebergSourceFlatORCDataReadBenchmark extends IcebergSourceFlatORCD
   public void readIcebergNonVectorized() {
     Map<String, String> tableProperties = Maps.newHashMap();
     tableProperties.put(SPLIT_OPEN_FILE_COST, Integer.toString(128 * 1024 * 1024));
-    withTableProperties(tableProperties, () -> {
-      String tableLocation = table().location();
-      Dataset<Row> df = spark().read().format("iceberg").load(tableLocation);
-      materialize(df);
-    });
+    withTableProperties(
+        tableProperties,
+        () -> {
+          String tableLocation = table().location();
+          Dataset<Row> df = spark().read().format("iceberg").load(tableLocation);
+          materialize(df);
+        });
   }
 
   @Benchmark
@@ -82,12 +82,18 @@ public class IcebergSourceFlatORCDataReadBenchmark extends IcebergSourceFlatORCD
   public void readIcebergVectorized() {
     Map<String, String> tableProperties = Maps.newHashMap();
     tableProperties.put(SPLIT_OPEN_FILE_COST, Integer.toString(128 * 1024 * 1024));
-    withTableProperties(tableProperties, () -> {
-      String tableLocation = table().location();
-      Dataset<Row> df = spark().read().option(SparkReadOptions.VECTORIZATION_ENABLED, "true")
-          .format("iceberg").load(tableLocation);
-      materialize(df);
-    });
+    withTableProperties(
+        tableProperties,
+        () -> {
+          String tableLocation = table().location();
+          Dataset<Row> df =
+              spark()
+                  .read()
+                  .option(SparkReadOptions.VECTORIZATION_ENABLED, "true")
+                  .format("iceberg")
+                  .load(tableLocation);
+          materialize(df);
+        });
   }
 
   @Benchmark
@@ -96,10 +102,12 @@ public class IcebergSourceFlatORCDataReadBenchmark extends IcebergSourceFlatORCD
     Map<String, String> conf = Maps.newHashMap();
     conf.put(SQLConf.ORC_VECTORIZED_READER_ENABLED().key(), "true");
     conf.put(SQLConf.FILES_OPEN_COST_IN_BYTES().key(), Integer.toString(128 * 1024 * 1024));
-    withSQLConf(conf, () -> {
-      Dataset<Row> df = spark().read().orc(dataLocation());
-      materialize(df);
-    });
+    withSQLConf(
+        conf,
+        () -> {
+          Dataset<Row> df = spark().read().orc(dataLocation());
+          materialize(df);
+        });
   }
 
   @Benchmark
@@ -108,10 +116,12 @@ public class IcebergSourceFlatORCDataReadBenchmark extends IcebergSourceFlatORCD
     Map<String, String> conf = Maps.newHashMap();
     conf.put(SQLConf.ORC_VECTORIZED_READER_ENABLED().key(), "false");
     conf.put(SQLConf.FILES_OPEN_COST_IN_BYTES().key(), Integer.toString(128 * 1024 * 1024));
-    withSQLConf(conf, () -> {
-      Dataset<Row> df = spark().read().orc(dataLocation());
-      materialize(df);
-    });
+    withSQLConf(
+        conf,
+        () -> {
+          Dataset<Row> df = spark().read().orc(dataLocation());
+          materialize(df);
+        });
   }
 
   @Benchmark
@@ -119,11 +129,13 @@ public class IcebergSourceFlatORCDataReadBenchmark extends IcebergSourceFlatORCD
   public void readWithProjectionIcebergNonVectorized() {
     Map<String, String> tableProperties = Maps.newHashMap();
     tableProperties.put(SPLIT_OPEN_FILE_COST, Integer.toString(128 * 1024 * 1024));
-    withTableProperties(tableProperties, () -> {
-      String tableLocation = table().location();
-      Dataset<Row> df = spark().read().format("iceberg").load(tableLocation).select("longCol");
-      materialize(df);
-    });
+    withTableProperties(
+        tableProperties,
+        () -> {
+          String tableLocation = table().location();
+          Dataset<Row> df = spark().read().format("iceberg").load(tableLocation).select("longCol");
+          materialize(df);
+        });
   }
 
   @Benchmark
@@ -131,25 +143,33 @@ public class IcebergSourceFlatORCDataReadBenchmark extends IcebergSourceFlatORCD
   public void readWithProjectionIcebergVectorized() {
     Map<String, String> tableProperties = Maps.newHashMap();
     tableProperties.put(SPLIT_OPEN_FILE_COST, Integer.toString(128 * 1024 * 1024));
-    withTableProperties(tableProperties, () -> {
-      String tableLocation = table().location();
-      Dataset<Row> df = spark().read().option(SparkReadOptions.VECTORIZATION_ENABLED, "true")
-          .format("iceberg").load(tableLocation).select("longCol");
-      materialize(df);
-    });
+    withTableProperties(
+        tableProperties,
+        () -> {
+          String tableLocation = table().location();
+          Dataset<Row> df =
+              spark()
+                  .read()
+                  .option(SparkReadOptions.VECTORIZATION_ENABLED, "true")
+                  .format("iceberg")
+                  .load(tableLocation)
+                  .select("longCol");
+          materialize(df);
+        });
   }
 
-
   @Benchmark
   @Threads(1)
   public void readWithProjectionFileSourceVectorized() {
     Map<String, String> conf = Maps.newHashMap();
     conf.put(SQLConf.ORC_VECTORIZED_READER_ENABLED().key(), "true");
     conf.put(SQLConf.FILES_OPEN_COST_IN_BYTES().key(), Integer.toString(128 * 1024 * 1024));
-    withSQLConf(conf, () -> {
-      Dataset<Row> df = spark().read().orc(dataLocation()).select("longCol");
-      materialize(df);
-    });
+    withSQLConf(
+        conf,
+        () -> {
+          Dataset<Row> df = spark().read().orc(dataLocation()).select("longCol");
+          materialize(df);
+        });
   }
 
   @Benchmark
@@ -158,27 +178,33 @@ public class IcebergSourceFlatORCDataReadBenchmark extends IcebergSourceFlatORCD
     Map<String, String> conf = Maps.newHashMap();
     conf.put(SQLConf.ORC_VECTORIZED_READER_ENABLED().key(), "false");
     conf.put(SQLConf.FILES_OPEN_COST_IN_BYTES().key(), Integer.toString(128 * 1024 * 1024));
-    withSQLConf(conf, () -> {
-      Dataset<Row> df = spark().read().orc(dataLocation()).select("longCol");
-      materialize(df);
-    });
+    withSQLConf(
+        conf,
+        () -> {
+          Dataset<Row> df = spark().read().orc(dataLocation()).select("longCol");
+          materialize(df);
+        });
   }
 
   private void appendData() {
     Map<String, String> tableProperties = Maps.newHashMap();
     tableProperties.put(DEFAULT_FILE_FORMAT, "orc");
-    withTableProperties(tableProperties, () -> {
-      for (int fileNum = 1; fileNum <= NUM_FILES; fileNum++) {
-        Dataset<Row> df = spark().range(NUM_ROWS)
-            .withColumnRenamed("id", "longCol")
-            .withColumn("intCol", expr("CAST(longCol AS INT)"))
-            .withColumn("floatCol", expr("CAST(longCol AS FLOAT)"))
-            .withColumn("doubleCol", expr("CAST(longCol AS DOUBLE)"))
-            .withColumn("decimalCol", expr("CAST(longCol AS DECIMAL(20, 5))"))
-            .withColumn("dateCol", date_add(current_date(), fileNum))
-            .withColumn("stringCol", expr("CAST(dateCol AS STRING)"));
-        appendAsFile(df);
-      }
-    });
+    withTableProperties(
+        tableProperties,
+        () -> {
+          for (int fileNum = 1; fileNum <= NUM_FILES; fileNum++) {
+            Dataset<Row> df =
+                spark()
+                    .range(NUM_ROWS)
+                    .withColumnRenamed("id", "longCol")
+                    .withColumn("intCol", expr("CAST(longCol AS INT)"))
+                    .withColumn("floatCol", expr("CAST(longCol AS FLOAT)"))
+                    .withColumn("doubleCol", expr("CAST(longCol AS DOUBLE)"))
+                    .withColumn("decimalCol", expr("CAST(longCol AS DECIMAL(20, 5))"))
+                    .withColumn("dateCol", date_add(current_date(), fileNum))
+                    .withColumn("stringCol", expr("CAST(dateCol AS STRING)"));
+            appendAsFile(df);
+          }
+        });
   }
 }
