@@ -19,7 +19,6 @@
 package org.apache.iceberg.spark.source.parquet.vectorized;
 
 import static org.apache.spark.sql.functions.col;
-import static org.apache.spark.sql.functions.date_add;
 import static org.apache.spark.sql.functions.lit;
 import static org.apache.spark.sql.functions.pmod;
 import static org.apache.spark.sql.functions.to_date;
@@ -35,6 +34,7 @@ import org.apache.spark.sql.Column;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SaveMode;
+import org.apache.spark.sql.catalyst.expressions.DateAdd;
 import org.apache.spark.sql.types.DataTypes;
 import org.openjdk.jmh.annotations.Setup;
 
@@ -42,8 +42,8 @@ import org.openjdk.jmh.annotations.Setup;
  * Benchmark to compare performance of reading Parquet dictionary encoded data with a flat schema
  * using vectorized Iceberg read path and the built-in file source in Spark.
  *
- * <p>To run this benchmark for spark-3.1: <code>
- *   ./gradlew -DsparkVersions=3.1 :iceberg-spark:iceberg-spark-3.1_2.12:jmh
+ * <p>To run this benchmark for spark-2.4: <code>
+ *   ./gradlew -DsparkVersions=2.4 :iceberg-spark:iceberg-spark-2.4:jmh
  *       -PjmhIncludeRegex=VectorizedReadDictionaryEncodedFlatParquetDataBenchmark
  *       -PjmhOutputPath=benchmark/results.txt
  * </code>
@@ -90,6 +90,10 @@ public class VectorizedReadDictionaryEncodedFlatParquetDataBenchmark
     return pmod(col("id"), lit(9));
   }
 
+  private static Column date_add(Column start, Column days) {
+    return new Column(new DateAdd(start.expr(), days.expr()));
+  }
+
   private Dataset<Row> idDF() {
     return spark().range(0, NUM_ROWS_PER_FILE * NUM_FILES, 1, NUM_FILES).toDF();
   }
