@@ -16,41 +16,8 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark;
 
-import java.sql.Date;
-import java.sql.Timestamp;
-import java.time.Instant;
-import java.time.LocalDate;
-import java.util.Map;
-import java.util.Objects;
-import java.util.stream.Collectors;
-import java.util.stream.Stream;
-import org.apache.iceberg.expressions.Expression;
-import org.apache.iceberg.expressions.Expression.Operation;
-import org.apache.iceberg.expressions.Expressions;
-import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
-import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
-import org.apache.iceberg.util.NaNUtil;
-import org.apache.spark.sql.catalyst.util.DateTimeUtils;
-import org.apache.spark.sql.sources.AlwaysFalse$;
-import org.apache.spark.sql.sources.AlwaysTrue$;
-import org.apache.spark.sql.sources.And;
-import org.apache.spark.sql.sources.EqualNullSafe;
-import org.apache.spark.sql.sources.EqualTo;
-import org.apache.spark.sql.sources.Filter;
-import org.apache.spark.sql.sources.GreaterThan;
-import org.apache.spark.sql.sources.GreaterThanOrEqual;
-import org.apache.spark.sql.sources.In;
-import org.apache.spark.sql.sources.IsNotNull;
-import org.apache.spark.sql.sources.IsNull;
-import org.apache.spark.sql.sources.LessThan;
-import org.apache.spark.sql.sources.LessThanOrEqual;
-import org.apache.spark.sql.sources.Not;
-import org.apache.spark.sql.sources.Or;
-import org.apache.spark.sql.sources.StringStartsWith;
-
 import static org.apache.iceberg.expressions.Expressions.and;
 import static org.apache.iceberg.expressions.Expressions.equal;
 import static org.apache.iceberg.expressions.Expressions.greaterThan;
@@ -65,50 +32,57 @@ import static org.apache.iceberg.expressions.Expressions.notNull;
 import static org.apache.iceberg.expressions.Expressions.or;
 import static org.apache.iceberg.expressions.Expressions.startsWith;
 
+import java.sql.Date;
+import java.sql.Timestamp;
+import java.util.Objects;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
+import org.apache.iceberg.expressions.Expression;
+import org.apache.iceberg.expressions.Expression.Operation;
+import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
+import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
+import org.apache.iceberg.util.NaNUtil;
+import org.apache.spark.sql.catalyst.util.DateTimeUtils;
+import org.apache.spark.sql.sources.And;
+import org.apache.spark.sql.sources.EqualNullSafe;
+import org.apache.spark.sql.sources.EqualTo;
+import org.apache.spark.sql.sources.Filter;
+import org.apache.spark.sql.sources.GreaterThan;
+import org.apache.spark.sql.sources.GreaterThanOrEqual;
+import org.apache.spark.sql.sources.In;
+import org.apache.spark.sql.sources.IsNotNull;
+import org.apache.spark.sql.sources.IsNull;
+import org.apache.spark.sql.sources.LessThan;
+import org.apache.spark.sql.sources.LessThanOrEqual;
+import org.apache.spark.sql.sources.Not;
+import org.apache.spark.sql.sources.Or;
+import org.apache.spark.sql.sources.StringStartsWith;
+
 public class SparkFilters {
-  private SparkFilters() {
-  }
+  private SparkFilters() {}
 
-  private static final Map<Class<? extends Filter>, Operation> FILTERS = ImmutableMap
-      .<Class<? extends Filter>, Operation>builder()
-      .put(AlwaysTrue$.class, Operation.TRUE)
-      .put(AlwaysFalse$.class, Operation.FALSE)
-      .put(EqualTo.class, Operation.EQ)
-      .put(EqualNullSafe.class, Operation.EQ)
-      .put(GreaterThan.class, Operation.GT)
-      .put(GreaterThanOrEqual.class, Operation.GT_EQ)
-      .put(LessThan.class, Operation.LT)
-      .put(LessThanOrEqual.class, Operation.LT_EQ)
-      .put(In.class, Operation.IN)
-      .put(IsNull.class, Operation.IS_NULL)
-      .put(IsNotNull.class, Operation.NOT_NULL)
-      .put(And.class, Operation.AND)
-      .put(Or.class, Operation.OR)
-      .put(Not.class, Operation.NOT)
-      .put(StringStartsWith.class, Operation.STARTS_WITH)
-      .build();
-
-  public static Expression convert(Filter[] filters) {
-    Expression expression = Expressions.alwaysTrue();
-    for (Filter filter : filters) {
-      Expression converted = convert(filter);
-      Preconditions.checkArgument(converted != null, "Cannot convert filter to Iceberg: %s", filter);
-      expression = Expressions.and(expression, converted);
-    }
-    return expression;
-  }
+  private static final ImmutableMap<Class<? extends Filter>, Operation> FILTERS =
+      ImmutableMap.<Class<? extends Filter>, Operation>builder()
+          .put(EqualTo.class, Operation.EQ)
+          .put(EqualNullSafe.class, Operation.EQ)
+          .put(GreaterThan.class, Operation.GT)
+          .put(GreaterThanOrEqual.class, Operation.GT_EQ)
+          .put(LessThan.class, Operation.LT)
+          .put(LessThanOrEqual.class, Operation.LT_EQ)
+          .put(In.class, Operation.IN)
+          .put(IsNull.class, Operation.IS_NULL)
+          .put(IsNotNull.class, Operation.NOT_NULL)
+          .put(And.class, Operation.AND)
+          .put(Or.class, Operation.OR)
+          .put(Not.class, Operation.NOT)
+          .put(StringStartsWith.class, Operation.STARTS_WITH)
+          .buildOrThrow();
 
   public static Expression convert(Filter filter) {
     // avoid using a chain of if instanceof statements by mapping to the expression enum.
     Operation op = FILTERS.get(filter.getClass());
     if (op != null) {
       switch (op) {
-        case TRUE:
-          return Expressions.alwaysTrue();
-
-        case FALSE:
-          return Expressions.alwaysFalse();
-
         case IS_NULL:
           IsNull isNullFilter = (IsNull) filter;
           return isNull(isNullFilter.attribute());
@@ -137,8 +111,8 @@ public class SparkFilters {
           if (filter instanceof EqualTo) {
             EqualTo eq = (EqualTo) filter;
             // comparison with null in normal equality is always null. this is probably a mistake.
-            Preconditions.checkNotNull(eq.value(),
-                "Expression is always false (eq is not null-safe): %s", filter);
+            Preconditions.checkNotNull(
+                eq.value(), "Expression is always false (eq is not null-safe): %s", filter);
             return handleEqual(eq.attribute(), eq.value());
           } else {
             EqualNullSafe eq = (EqualNullSafe) filter;
@@ -151,7 +125,8 @@ public class SparkFilters {
 
         case IN:
           In inFilter = (In) filter;
-          return in(inFilter.attribute(),
+          return in(
+              inFilter.attribute(),
               Stream.of(inFilter.values())
                   .filter(Objects::nonNull)
                   .map(SparkFilters::convertLiteral)
@@ -165,30 +140,33 @@ public class SparkFilters {
           }
           return null;
 
-        case AND: {
-          And andFilter = (And) filter;
-          Expression left = convert(andFilter.left());
-          Expression right = convert(andFilter.right());
-          if (left != null && right != null) {
-            return and(left, right);
+        case AND:
+          {
+            And andFilter = (And) filter;
+            Expression left = convert(andFilter.left());
+            Expression right = convert(andFilter.right());
+            if (left != null && right != null) {
+              return and(left, right);
+            }
+            return null;
           }
-          return null;
-        }
 
-        case OR: {
-          Or orFilter = (Or) filter;
-          Expression left = convert(orFilter.left());
-          Expression right = convert(orFilter.right());
-          if (left != null && right != null) {
-            return or(left, right);
+        case OR:
+          {
+            Or orFilter = (Or) filter;
+            Expression left = convert(orFilter.left());
+            Expression right = convert(orFilter.right());
+            if (left != null && right != null) {
+              return or(left, right);
+            }
+            return null;
           }
-          return null;
-        }
 
-        case STARTS_WITH: {
-          StringStartsWith stringStartsWith = (StringStartsWith) filter;
-          return startsWith(stringStartsWith.attribute(), stringStartsWith.value());
-        }
+        case STARTS_WITH:
+          {
+            StringStartsWith stringStartsWith = (StringStartsWith) filter;
+            return startsWith(stringStartsWith.attribute(), stringStartsWith.value());
+          }
       }
     }
 
@@ -200,10 +178,6 @@ public class SparkFilters {
       return DateTimeUtils.fromJavaTimestamp((Timestamp) value);
     } else if (value instanceof Date) {
       return DateTimeUtils.fromJavaDate((Date) value);
-    } else if (value instanceof Instant) {
-      return DateTimeUtils.instantToMicros((Instant) value);
-    } else if (value instanceof LocalDate) {
-      return DateTimeUtils.localDateToDays((LocalDate) value);
     }
     return value;
   }
