@@ -32,12 +32,6 @@ public class SparkReadOptions {
   // End snapshot ID used in incremental scans (inclusive)
   public static final String END_SNAPSHOT_ID = "end-snapshot-id";
 
-  // Start timestamp used in multi-snapshot scans (exclusive)
-  public static final String START_TIMESTAMP = "start-timestamp";
-
-  // End timestamp used in multi-snapshot scans (inclusive)
-  public static final String END_TIMESTAMP = "end-timestamp";
-
   // A timestamp in milliseconds; the snapshot used will be the snapshot current at this time.
   public static final String AS_OF_TIMESTAMP = "as-of-timestamp";
 
@@ -61,12 +55,6 @@ public class SparkReadOptions {
 
   // skip snapshots of type delete while reading stream out of iceberg table
   public static final String STREAMING_SKIP_DELETE_SNAPSHOTS = "streaming-skip-delete-snapshots";
-  public static final boolean STREAMING_SKIP_DELETE_SNAPSHOTS_DEFAULT = false;
-
-  // skip snapshots of type overwrite while reading stream out of iceberg table
-  public static final String STREAMING_SKIP_OVERWRITE_SNAPSHOTS =
-      "streaming-skip-overwrite-snapshots";
-  public static final boolean STREAMING_SKIP_OVERWRITE_SNAPSHOTS_DEFAULT = false;
 
   // Controls whether to allow reading timestamps without zone info
   public static final String HANDLE_TIMESTAMP_WITHOUT_TIMEZONE =
@@ -74,7 +62,4 @@ public class SparkReadOptions {
 
   // Controls whether to report locality information to Spark while allocating input partitions
   public static final String LOCALITY = "locality";
-
-  // Timestamp in milliseconds; start a stream from the snapshot that occurs after this timestamp
-  public static final String STREAM_FROM_TIMESTAMP = "stream-from-timestamp";
 }
