@@ -27,10 +27,10 @@ import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.UUID;
 import java.util.stream.Collectors;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
+import org.apache.hadoop.fs.PathFilter;
 import org.apache.iceberg.AppendFiles;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.FileFormat;
@@ -38,11 +38,11 @@ import org.apache.iceberg.ManifestFile;
 import org.apache.iceberg.ManifestFiles;
 import org.apache.iceberg.ManifestWriter;
 import org.apache.iceberg.MetadataTableType;
-import org.apache.iceberg.MetadataTableUtils;
 import org.apache.iceberg.MetricsConfig;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
+import org.apache.iceberg.common.DynMethods;
 import org.apache.iceberg.data.TableMigrationUtil;
 import org.apache.iceberg.hadoop.HadoopFileIO;
 import org.apache.iceberg.hadoop.SerializableConfiguration;
@@ -56,13 +56,10 @@ import org.apache.iceberg.relocated.com.google.common.base.MoreObjects;
 import org.apache.iceberg.relocated.com.google.common.base.Objects;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
-import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
-import org.apache.iceberg.spark.source.SparkTable;
 import org.apache.iceberg.util.PropertyUtil;
 import org.apache.iceberg.util.Tasks;
-import org.apache.iceberg.util.ThreadPools;
 import org.apache.spark.TaskContext;
 import org.apache.spark.api.java.JavaRDD;
 import org.apache.spark.api.java.JavaSparkContext;
@@ -71,6 +68,7 @@ import org.apache.spark.api.java.function.MapFunction;
 import org.apache.spark.api.java.function.MapPartitionsFunction;
 import org.apache.spark.sql.AnalysisException;
 import org.apache.spark.sql.Column;
+import org.apache.spark.sql.DataFrameReader;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
@@ -86,16 +84,15 @@ import org.apache.spark.sql.catalyst.expressions.Expression;
 import org.apache.spark.sql.catalyst.expressions.NamedExpression;
 import org.apache.spark.sql.catalyst.parser.ParseException;
 import org.apache.spark.sql.catalyst.plans.logical.LogicalPlan;
-import org.apache.spark.sql.execution.datasources.v2.DataSourceV2Relation;
-import org.apache.spark.sql.util.CaseInsensitiveStringMap;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import scala.Function2;
 import scala.Option;
+import scala.Predef;
 import scala.Some;
 import scala.Tuple2;
 import scala.collection.JavaConverters;
-import scala.collection.immutable.Map$;
-import scala.collection.immutable.Seq;
-import scala.collection.mutable.Builder;
+import scala.collection.Seq;
 import scala.runtime.AbstractPartialFunction;
 
 /**
@@ -104,7 +101,14 @@ import scala.runtime.AbstractPartialFunction;
  */
 public class SparkTableUtil {
 
-  private static final String DUPLICATE_FILE_MESSAGE =
+  private static final Logger LOG = LoggerFactory.getLogger(SparkTableUtil.class);
+
+  private static final Joiner.MapJoiner MAP_JOINER = Joiner.on(",").withKeyValueSeparator("=");
+
+  private static final PathFilter HIDDEN_PATH_FILTER =
+      p -> !p.getName().startsWith("_") && !p.getName().startsWith(".");
+
+  private static final String duplicateFileMessage =
       "Cannot complete import because data files "
           + "to be imported already exist within the target table: %s.  "
           + "This is disabled by default as Iceberg is not designed for mulitple references to the same file"
@@ -178,15 +182,16 @@ public class SparkTableUtil {
 
       Option<scala.collection.immutable.Map<String, String>> scalaPartitionFilter;
       if (partitionFilter != null && !partitionFilter.isEmpty()) {
-        Builder<Tuple2<String, String>, scala.collection.immutable.Map<String, String>> builder =
-            Map$.MODULE$.<String, String>newBuilder();
-        partitionFilter.forEach((key, value) -> builder.$plus$eq(Tuple2.apply(key, value)));
-        scalaPartitionFilter = Option.apply(builder.result());
+        scalaPartitionFilter =
+            Option.apply(
+                JavaConverters.mapAsScalaMapConverter(partitionFilter)
+                    .asScala()
+                    .toMap(Predef.conforms()));
       } else {
         scalaPartitionFilter = Option.empty();
       }
       Seq<CatalogTablePartition> partitions =
-          catalog.listPartitions(tableIdent, scalaPartitionFilter).toIndexedSeq();
+          catalog.listPartitions(tableIdent, scalaPartitionFilter);
       return JavaConverters.seqAsJavaListConverter(partitions).asJava().stream()
           .map(catalogPartition -> toSparkPartition(catalogPartition, catalogTable))
           .collect(Collectors.toList());
@@ -252,10 +257,10 @@ public class SparkTableUtil {
       Seq<Expression> predicates =
           JavaConverters.collectionAsScalaIterableConverter(ImmutableList.of(resolvedPredicateExpr))
               .asScala()
-              .toIndexedSeq();
+              .toSeq();
 
       Seq<CatalogTablePartition> partitions =
-          catalog.listPartitionsByFilter(tableIdent, predicates).toIndexedSeq();
+          catalog.listPartitionsByFilter(tableIdent, predicates);
 
       return JavaConverters.seqAsJavaListConverter(partitions).asJava().stream()
           .map(catalogPartition -> toSparkPartition(catalogPartition, catalogTable))
@@ -373,9 +378,7 @@ public class SparkTableUtil {
       FileIO io = new HadoopFileIO(conf.get());
       TaskContext ctx = TaskContext.get();
       String suffix =
-          String.format(
-              "stage-%d-task-%d-manifest-%s",
-              ctx.stageId(), ctx.taskAttemptId(), UUID.randomUUID());
+          String.format("stage-%d-task-%d-manifest", ctx.stageId(), ctx.taskAttemptId());
       Path location = new Path(basePath, suffix);
       String outputPath = FileFormat.AVRO.addExtension(location.toString());
       OutputFile outputFile = io.newOutputFile(outputPath);
@@ -542,7 +545,7 @@ public class SparkTableUtil {
         Preconditions.checkState(
             duplicates.isEmpty(),
             String.format(
-                DUPLICATE_FILE_MESSAGE, Joiner.on(",").join((String[]) duplicates.take(10))));
+                duplicateFileMessage, Joiner.on(",").join((String[]) duplicates.take(10))));
       }
 
       AppendFiles append = targetTable.newAppend();
@@ -602,9 +605,7 @@ public class SparkTableUtil {
 
     if (checkDuplicateFiles) {
       Dataset<Row> importedFiles =
-          filesToImport
-              .map((MapFunction<DataFile, String>) f -> f.path().toString(), Encoders.STRING())
-              .toDF("file_path");
+          filesToImport.map(f -> f.path().toString(), Encoders.STRING()).toDF("file_path");
       Dataset<Row> existingFiles = loadMetadataTable(spark, targetTable, MetadataTableType.ENTRIES);
       Column joinCond =
           existingFiles.col("data_file.file_path").equalTo(importedFiles.col("file_path"));
@@ -612,8 +613,7 @@ public class SparkTableUtil {
           importedFiles.join(existingFiles, joinCond).select("file_path").as(Encoders.STRING());
       Preconditions.checkState(
           duplicates.isEmpty(),
-          String.format(
-              DUPLICATE_FILE_MESSAGE, Joiner.on(",").join((String[]) duplicates.take(10))));
+          String.format(duplicateFileMessage, Joiner.on(",").join((String[]) duplicates.take(10))));
     }
 
     List<ManifestFile> manifests =
@@ -682,36 +682,59 @@ public class SparkTableUtil {
 
   private static void deleteManifests(FileIO io, List<ManifestFile> manifests) {
     Tasks.foreach(manifests)
-        .executeWith(ThreadPools.getWorkerPool())
         .noRetry()
         .suppressFailureWhenFinished()
         .run(item -> io.deleteFile(item.path()));
   }
 
-  /**
-   * Loads a metadata table.
-   *
-   * @deprecated since 0.14.0, will be removed in 0.15.0; use {@link
-   *     #loadMetadataTable(SparkSession, Table, MetadataTableType)}.
-   */
-  @Deprecated
+  // Attempt to use Spark3 Catalog resolution if available on the path
+  private static final DynMethods.UnboundMethod LOAD_METADATA_TABLE =
+      DynMethods.builder("loadMetadataTable")
+          .hiddenImpl(
+              "org.apache.iceberg.spark.Spark3Util",
+              SparkSession.class,
+              Table.class,
+              MetadataTableType.class)
+          .orNoop()
+          .build();
+
   public static Dataset<Row> loadCatalogMetadataTable(
       SparkSession spark, Table table, MetadataTableType type) {
-    return loadMetadataTable(spark, table, type);
+    Preconditions.checkArgument(
+        !LOAD_METADATA_TABLE.isNoop(), "Cannot find Spark3Util class but Spark3 is in use");
+    return LOAD_METADATA_TABLE.asStatic().invoke(spark, table, type);
   }
 
   public static Dataset<Row> loadMetadataTable(
       SparkSession spark, Table table, MetadataTableType type) {
-    return loadMetadataTable(spark, table, type, ImmutableMap.of());
-  }
+    if (spark.version().startsWith("3")) {
+      // construct the metadata table instance directly
+      Dataset<Row> catalogMetadataTable = loadCatalogMetadataTable(spark, table, type);
+      if (catalogMetadataTable != null) {
+        return catalogMetadataTable;
+      }
+    }
 
-  public static Dataset<Row> loadMetadataTable(
-      SparkSession spark, Table table, MetadataTableType type, Map<String, String> extraOptions) {
-    SparkTable metadataTable =
-        new SparkTable(MetadataTableUtils.createMetadataTableInstance(table, type), false);
-    CaseInsensitiveStringMap options = new CaseInsensitiveStringMap(extraOptions);
-    return Dataset.ofRows(
-        spark, DataSourceV2Relation.create(metadataTable, Some.empty(), Some.empty(), options));
+    String tableName = table.name();
+    String tableLocation = table.location();
+
+    DataFrameReader dataFrameReader = spark.read().format("iceberg");
+    if (tableName.contains("/")) {
+      // Hadoop Table or Metadata location passed, load without a catalog
+      return dataFrameReader.load(tableName + "#" + type);
+    }
+
+    // Catalog based resolution failed, our catalog may be a non-DatasourceV2 Catalog
+    if (tableName.startsWith("hadoop.")) {
+      // Try loading by location as Hadoop table without Catalog
+      return dataFrameReader.load(tableLocation + "#" + type);
+    } else if (tableName.startsWith("hive")) {
+      // Try loading by name as a Hive table without Catalog
+      return dataFrameReader.load(tableName.replaceFirst("hive\\.", "") + "." + type);
+    } else {
+      throw new IllegalArgumentException(
+          String.format("Cannot find the metadata table for %s of type %s", tableName, type));
+    }
   }
 
   /** Class representing a table partition. */
