@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark.source;
 
 import java.io.Closeable;
@@ -76,10 +75,16 @@ abstract class BaseDataReader<T> implements Closeable {
     this.tasks = task.files().iterator();
     Map<String, ByteBuffer> keyMetadata = Maps.newHashMap();
     task.files().stream()
-        .flatMap(fileScanTask -> Stream.concat(Stream.of(fileScanTask.file()), fileScanTask.deletes().stream()))
+        .flatMap(
+            fileScanTask ->
+                Stream.concat(Stream.of(fileScanTask.file()), fileScanTask.deletes().stream()))
         .forEach(file -> keyMetadata.put(file.path().toString(), file.keyMetadata()));
-    Stream<EncryptedInputFile> encrypted = keyMetadata.entrySet().stream()
-        .map(entry -> EncryptedFiles.encryptedInput(table.io().newInputFile(entry.getKey()), entry.getValue()));
+    Stream<EncryptedInputFile> encrypted =
+        keyMetadata.entrySet().stream()
+            .map(
+                entry ->
+                    EncryptedFiles.encryptedInput(
+                        table.io().newInputFile(entry.getKey()), entry.getValue()));
 
     // decrypt with the batch call to avoid multiple RPCs to a key server, if possible
     Iterable<InputFile> decryptedFiles = table.encryption().decrypt(encrypted::iterator);
@@ -91,10 +96,6 @@ abstract class BaseDataReader<T> implements Closeable {
     this.currentIterator = CloseableIterator.empty();
   }
 
-  protected Table table() {
-    return table;
-  }
-
   public boolean next() throws IOException {
     try {
       while (true) {
@@ -192,7 +193,8 @@ abstract class BaseDataReader<T> implements Closeable {
         for (int index = 0; index < fields.size(); index++) {
           NestedField field = fields.get(index);
           Type fieldType = field.type();
-          values[index] = convertConstant(fieldType, struct.get(index, fieldType.typeId().javaClass()));
+          values[index] =
+              convertConstant(fieldType, struct.get(index, fieldType.typeId().javaClass()));
         }
 
         return new GenericInternalRow(values);
