@@ -16,11 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark.source;
 
 import java.util.OptionalLong;
-import org.apache.spark.sql.connector.read.Statistics;
+import org.apache.spark.sql.sources.v2.reader.Statistics;
 
 class Stats implements Statistics {
   private final OptionalLong sizeInBytes;
