@@ -35,31 +35,16 @@ import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import java.util.UUID;
-import java.util.stream.Collectors;
-import java.util.stream.Stream;
-import java.util.stream.StreamSupport;
 import org.apache.arrow.vector.ValueVector;
 import org.apache.avro.generic.GenericData;
 import org.apache.avro.generic.GenericData.Record;
-import org.apache.iceberg.DataFile;
-import org.apache.iceberg.DeleteFile;
-import org.apache.iceberg.FileContent;
-import org.apache.iceberg.FileScanTask;
-import org.apache.iceberg.ManifestFile;
 import org.apache.iceberg.Schema;
-import org.apache.iceberg.Table;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
-import org.apache.iceberg.relocated.com.google.common.collect.Sets;
-import org.apache.iceberg.relocated.com.google.common.collect.Streams;
-import org.apache.iceberg.spark.SparkSchemaUtil;
 import org.apache.iceberg.spark.data.vectorized.IcebergArrowColumnVector;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
 import org.apache.orc.storage.serde2.io.DateWritable;
-import org.apache.spark.sql.Column;
-import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.InternalRow;
 import org.apache.spark.sql.catalyst.expressions.GenericRow;
@@ -85,11 +70,6 @@ public class TestHelpers {
 
   private TestHelpers() {}
 
-  public static void assertEqualsSafe(Types.StructType struct, List<Record> recs, List<Row> rows) {
-    Streams.forEachPair(
-        recs.stream(), rows.stream(), (rec, row) -> assertEqualsSafe(struct, rec, row));
-  }
-
   public static void assertEqualsSafe(Types.StructType struct, Record rec, Row row) {
     List<Types.NestedField> fields = struct.fields();
     for (int i = 0; i < fields.size(); i += 1) {
@@ -787,62 +767,4 @@ public class TestHelpers {
           actualValues.isNullAt(i) ? null : actualValues.get(i, valueType));
     }
   }
-
-  public static List<ManifestFile> dataManifests(Table table) {
-    return table.currentSnapshot().dataManifests(table.io());
-  }
-
-  public static List<ManifestFile> deleteManifests(Table table) {
-    return table.currentSnapshot().deleteManifests(table.io());
-  }
-
-  public static Set<DataFile> dataFiles(Table table) {
-    Set<DataFile> dataFiles = Sets.newHashSet();
-
-    for (FileScanTask task : table.newScan().planFiles()) {
-      dataFiles.add(task.file());
-    }
-
-    return dataFiles;
-  }
-
-  public static Set<DeleteFile> deleteFiles(Table table) {
-    Set<DeleteFile> deleteFiles = Sets.newHashSet();
-
-    for (FileScanTask task : table.newScan().planFiles()) {
-      deleteFiles.addAll(task.deletes());
-    }
-
-    return deleteFiles;
-  }
-
-  public static Set<String> reachableManifestPaths(Table table) {
-    return StreamSupport.stream(table.snapshots().spliterator(), false)
-        .flatMap(s -> s.allManifests(table.io()).stream())
-        .map(ManifestFile::path)
-        .collect(Collectors.toSet());
-  }
-
-  public static void asMetadataRecord(GenericData.Record file, FileContent content) {
-    file.put(0, content.id());
-    file.put(3, 0); // specId
-  }
-
-  public static void asMetadataRecord(GenericData.Record file) {
-    file.put(0, FileContent.DATA.id());
-    file.put(3, 0); // specId
-  }
-
-  public static Dataset<Row> selectNonDerived(Dataset<Row> metadataTable) {
-    StructField[] fields = metadataTable.schema().fields();
-    return metadataTable.select(
-        Stream.of(fields)
-            .filter(f -> !f.name().equals("readable_metrics")) // derived field
-            .map(f -> new Column(f.name()))
-            .toArray(Column[]::new));
-  }
-
-  public static Types.StructType nonDerivedSchema(Dataset<Row> metadataTable) {
-    return SparkSchemaUtil.convert(TestHelpers.selectNonDerived(metadataTable).schema()).asStruct();
-  }
 }
