@@ -16,13 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark.source;
 
-import org.apache.iceberg.catalog.TableIdentifier;
-import org.apache.spark.sql.SparkSession;
-import org.apache.spark.sql.connector.catalog.Identifier;
-import org.apache.spark.sql.util.CaseInsensitiveStringMap;
+import org.apache.hadoop.conf.Configuration;
+import org.apache.iceberg.Table;
+import org.apache.spark.sql.sources.v2.DataSourceOptions;
 
 public class TestIcebergSource extends IcebergSource {
   @Override
@@ -31,14 +29,7 @@ public class TestIcebergSource extends IcebergSource {
   }
 
   @Override
-  public Identifier extractIdentifier(CaseInsensitiveStringMap options) {
-    TableIdentifier ti = TableIdentifier.parse(options.get("iceberg.table.name"));
-    return Identifier.of(ti.namespace().levels(), ti.name());
+  protected Table findTable(DataSourceOptions options, Configuration conf) {
+    return TestTables.load(options.get("iceberg.table.name").get());
   }
-
-  @Override
-  public String extractCatalog(CaseInsensitiveStringMap options) {
-    return SparkSession.active().sessionState().catalogManager().currentCatalog().name();
-  }
-
 }
