@@ -27,7 +27,6 @@ import static org.mockito.Mockito.when;
 import java.io.File;
 import java.io.IOException;
 import java.util.List;
-import java.util.Map;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.iceberg.AppendFiles;
 import org.apache.iceberg.AssertHelpers;
@@ -42,7 +41,6 @@ import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.exceptions.CommitStateUnknownException;
 import org.apache.iceberg.hadoop.HadoopTables;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
-import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.SparkWriteOptions;
 import org.apache.iceberg.types.Types;
@@ -526,10 +524,7 @@ public class TestSparkDataWrite {
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.builderFor(SCHEMA).identity("data").build();
-    Map<String, String> properties =
-        ImmutableMap.of(
-            TableProperties.WRITE_DISTRIBUTION_MODE, TableProperties.WRITE_DISTRIBUTION_MODE_NONE);
-    Table table = tables.create(SCHEMA, spec, properties, location.toString());
+    Table table = tables.create(SCHEMA, spec, location.toString());
 
     List<SimpleRecord> expected = Lists.newArrayListWithCapacity(8000);
     for (int i = 0; i < 2000; i++) {
@@ -624,10 +619,9 @@ public class TestSparkDataWrite {
 
     Table spyTable = spy(table);
     when(spyTable.newAppend()).thenReturn(spyAppend);
-    SparkTable sparkTable = new SparkTable(spyTable, false);
 
     String manualTableName = "unknown_exception";
-    ManualSource.setTable(manualTableName, sparkTable);
+    ManualSource.setTable(manualTableName, spyTable);
 
     // Although an exception is thrown here, write and commit have succeeded
     AssertHelpers.assertThrowsWithCause(
