@@ -47,8 +47,7 @@ import org.junit.BeforeClass;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
-import scala.Option;
-import scala.collection.JavaConverters;
+import scala.collection.JavaConversions;
 
 public class TestStructuredStreaming {
 
@@ -284,7 +283,7 @@ public class TestStructuredStreaming {
       send(batch1, inputStream);
       Assertions.assertThatThrownBy(query::processAllAvailable)
           .isInstanceOf(StreamingQueryException.class)
-          .hasMessageContaining("does not support Update mode");
+          .hasMessageContaining("Output mode Update is not supported");
     } finally {
       for (StreamingQuery query : spark.streams().active()) {
         query.stop();
@@ -293,10 +292,10 @@ public class TestStructuredStreaming {
   }
 
   private <T> MemoryStream<T> newMemoryStream(int id, SQLContext sqlContext, Encoder<T> encoder) {
-    return new MemoryStream<>(id, sqlContext, Option.empty(), encoder);
+    return new MemoryStream<>(id, sqlContext, encoder);
   }
 
   private <T> void send(List<T> records, MemoryStream<T> stream) {
-    stream.addData(JavaConverters.asScalaBuffer(records));
+    stream.addData(JavaConversions.asScalaBuffer(records));
   }
 }
