@@ -27,12 +27,12 @@ import org.apache.spark.sql.connector.catalog.Identifier
 import org.apache.spark.sql.connector.catalog.TableCatalog
 
 case class CreateOrReplaceBranchExec(
-                              catalog: TableCatalog,
-                              ident: Identifier,
-                              branch: String,
-                              branchOptions: BranchOptions,
-                              replace: Boolean,
-                              ifNotExists: Boolean) extends LeafV2CommandExec {
+    catalog: TableCatalog,
+    ident: Identifier,
+    branch: String,
+    branchOptions: BranchOptions,
+    replace: Boolean,
+    ifNotExists: Boolean) extends V2CommandExec {
 
   import org.apache.spark.sql.connector.catalog.CatalogV2Implicits._
 
