@@ -67,6 +67,11 @@ class SparkConfParser {
       return self();
     }
 
+    public BooleanConfParser defaultValue(String value) {
+      this.defaultValue = Boolean.parseBoolean(value);
+      return self();
+    }
+
     public boolean parse() {
       Preconditions.checkArgument(defaultValue != null, "Default value cannot be null");
       return parse(Boolean::parseBoolean, defaultValue);
@@ -90,6 +95,10 @@ class SparkConfParser {
       Preconditions.checkArgument(defaultValue != null, "Default value cannot be null");
       return parse(Integer::parseInt, defaultValue);
     }
+
+    public Integer parseOptional() {
+      return parse(Integer::parseInt, null);
+    }
   }
 
   class LongConfParser extends ConfParser<LongConfParser, Long> {
@@ -132,6 +141,10 @@ class SparkConfParser {
       Preconditions.checkArgument(defaultValue != null, "Default value cannot be null");
       return parse(Function.identity(), defaultValue);
     }
+
+    public String parseOptional() {
+      return parse(Function.identity(), null);
+    }
   }
 
   abstract class ConfParser<ThisT, T> {
