@@ -125,7 +125,12 @@ public class SparkValueConverter {
           record.set(i, convert(fieldType.asStructType(), row.getStruct(i)));
           break;
         case LIST:
-          record.set(i, convert(fieldType.asListType(), row.getList(i)));
+          try {
+            record.set(i, convert(fieldType.asListType(), row.getList(i)));
+          } catch (NullPointerException npe) {
+            // Handle https://issues.apache.org/jira/browse/SPARK-37654
+            record.set(i, convert(fieldType.asListType(), null));
+          }
           break;
         case MAP:
           record.set(i, convert(fieldType.asMapType(), row.getJavaMap(i)));
