@@ -20,13 +20,24 @@ package org.apache.iceberg.spark.source;
 
 import static org.apache.iceberg.IsolationLevel.SERIALIZABLE;
 import static org.apache.iceberg.IsolationLevel.SNAPSHOT;
+import static org.apache.iceberg.TableProperties.COMMIT_MAX_RETRY_WAIT_MS;
+import static org.apache.iceberg.TableProperties.COMMIT_MAX_RETRY_WAIT_MS_DEFAULT;
+import static org.apache.iceberg.TableProperties.COMMIT_MIN_RETRY_WAIT_MS;
+import static org.apache.iceberg.TableProperties.COMMIT_MIN_RETRY_WAIT_MS_DEFAULT;
+import static org.apache.iceberg.TableProperties.COMMIT_NUM_RETRIES;
+import static org.apache.iceberg.TableProperties.COMMIT_NUM_RETRIES_DEFAULT;
+import static org.apache.iceberg.TableProperties.COMMIT_TOTAL_RETRY_TIME_MS;
+import static org.apache.iceberg.TableProperties.COMMIT_TOTAL_RETRY_TIME_MS_DEFAULT;
 
 import java.io.IOException;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.stream.Collectors;
 import org.apache.iceberg.AppendFiles;
+import org.apache.iceberg.ContentFile;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.FileScanTask;
@@ -52,11 +63,13 @@ import org.apache.iceberg.io.OutputFileFactory;
 import org.apache.iceberg.io.PartitioningWriter;
 import org.apache.iceberg.io.RollingDataWriter;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
-import org.apache.iceberg.relocated.com.google.common.collect.ImmutableSet;
-import org.apache.iceberg.relocated.com.google.common.collect.Lists;
+import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
+import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.spark.CommitMetadata;
 import org.apache.iceberg.spark.FileRewriteCoordinator;
 import org.apache.iceberg.spark.SparkWriteConf;
+import org.apache.iceberg.util.PropertyUtil;
+import org.apache.iceberg.util.Tasks;
 import org.apache.spark.TaskContext;
 import org.apache.spark.TaskContext$;
 import org.apache.spark.api.java.JavaSparkContext;
@@ -64,15 +77,11 @@ import org.apache.spark.broadcast.Broadcast;
 import org.apache.spark.executor.OutputMetrics;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.InternalRow;
-import org.apache.spark.sql.connector.distributions.Distribution;
-import org.apache.spark.sql.connector.expressions.SortOrder;
 import org.apache.spark.sql.connector.write.BatchWrite;
 import org.apache.spark.sql.connector.write.DataWriter;
 import org.apache.spark.sql.connector.write.DataWriterFactory;
 import org.apache.spark.sql.connector.write.LogicalWriteInfo;
 import org.apache.spark.sql.connector.write.PhysicalWriteInfo;
-import org.apache.spark.sql.connector.write.RequiresDistributionAndOrdering;
-import org.apache.spark.sql.connector.write.Write;
 import org.apache.spark.sql.connector.write.WriterCommitMessage;
 import org.apache.spark.sql.connector.write.streaming.StreamingDataWriterFactory;
 import org.apache.spark.sql.connector.write.streaming.StreamingWrite;
@@ -80,25 +89,21 @@ import org.apache.spark.sql.types.StructType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
+class SparkWrite {
   private static final Logger LOG = LoggerFactory.getLogger(SparkWrite.class);
 
   private final JavaSparkContext sparkContext;
-  private final SparkWriteConf writeConf;
   private final Table table;
   private final String queryId;
   private final FileFormat format;
   private final String applicationId;
   private final boolean wapEnabled;
   private final String wapId;
-  private final String branch;
   private final long targetFileSize;
   private final Schema writeSchema;
   private final StructType dsSchema;
   private final Map<String, String> extraSnapshotMetadata;
   private final boolean partitionedFanoutEnabled;
-  private final Distribution requiredDistribution;
-  private final SortOrder[] requiredOrdering;
 
   private boolean cleanupOnAbort = true;
 
@@ -109,35 +114,19 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       LogicalWriteInfo writeInfo,
       String applicationId,
       Schema writeSchema,
-      StructType dsSchema,
-      Distribution requiredDistribution,
-      SortOrder[] requiredOrdering) {
+      StructType dsSchema) {
     this.sparkContext = JavaSparkContext.fromSparkContext(spark.sparkContext());
     this.table = table;
-    this.writeConf = writeConf;
     this.queryId = writeInfo.queryId();
     this.format = writeConf.dataFileFormat();
     this.applicationId = applicationId;
     this.wapEnabled = writeConf.wapEnabled();
     this.wapId = writeConf.wapId();
-    this.branch = writeConf.branch();
     this.targetFileSize = writeConf.targetDataFileSize();
     this.writeSchema = writeSchema;
     this.dsSchema = dsSchema;
     this.extraSnapshotMetadata = writeConf.extraSnapshotMetadata();
     this.partitionedFanoutEnabled = writeConf.fanoutWriterEnabled();
-    this.requiredDistribution = requiredDistribution;
-    this.requiredOrdering = requiredOrdering;
-  }
-
-  @Override
-  public Distribution requiredDistribution() {
-    return requiredDistribution;
-  }
-
-  @Override
-  public SortOrder[] requiredOrdering() {
-    return requiredOrdering;
   }
 
   BatchWrite asBatchAppend() {
@@ -152,8 +141,8 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     return new OverwriteByFilter(overwriteExpr);
   }
 
-  BatchWrite asCopyOnWriteOperation(SparkCopyOnWriteScan scan, IsolationLevel isolationLevel) {
-    return new CopyOnWriteOperation(scan, isolationLevel);
+  BatchWrite asCopyOnWriteMergeWrite(SparkMergeScan scan, IsolationLevel isolationLevel) {
+    return new CopyOnWriteMergeWrite(scan, isolationLevel);
   }
 
   BatchWrite asRewrite(String fileSetID) {
@@ -174,13 +163,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     Broadcast<Table> tableBroadcast =
         sparkContext.broadcast(SerializableTableWithSize.copyOf(table));
     return new WriterFactory(
-        tableBroadcast,
-        queryId,
-        format,
-        targetFileSize,
-        writeSchema,
-        dsSchema,
-        partitionedFanoutEnabled);
+        tableBroadcast, format, targetFileSize, writeSchema, dsSchema, partitionedFanoutEnabled);
   }
 
   private void commitOperation(SnapshotUpdate<?> operation, String description) {
@@ -204,10 +187,6 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       operation.stageOnly();
     }
 
-    if (branch != null) {
-      operation.toBranch(branch);
-    }
-
     try {
       long start = System.currentTimeMillis();
       operation.commit(); // abort is automatically called if this fails
@@ -221,28 +200,39 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
 
   private void abort(WriterCommitMessage[] messages) {
     if (cleanupOnAbort) {
-      SparkCleanupUtil.deleteFiles("job abort", table.io(), files(messages));
+      Map<String, String> props = table.properties();
+      Tasks.foreach(files(messages))
+          .retry(PropertyUtil.propertyAsInt(props, COMMIT_NUM_RETRIES, COMMIT_NUM_RETRIES_DEFAULT))
+          .exponentialBackoff(
+              PropertyUtil.propertyAsInt(
+                  props, COMMIT_MIN_RETRY_WAIT_MS, COMMIT_MIN_RETRY_WAIT_MS_DEFAULT),
+              PropertyUtil.propertyAsInt(
+                  props, COMMIT_MAX_RETRY_WAIT_MS, COMMIT_MAX_RETRY_WAIT_MS_DEFAULT),
+              PropertyUtil.propertyAsInt(
+                  props, COMMIT_TOTAL_RETRY_TIME_MS, COMMIT_TOTAL_RETRY_TIME_MS_DEFAULT),
+              2.0 /* exponential */)
+          .throwFailureWhenFinished()
+          .run(
+              file -> {
+                table.io().deleteFile(file.path().toString());
+              });
     } else {
-      LOG.warn("Skipping cleanup of written files");
+      LOG.warn(
+          "Skipping cleaning up of data files because Iceberg was unable to determine the final commit state");
     }
   }
 
-  private List<DataFile> files(WriterCommitMessage[] messages) {
-    List<DataFile> files = Lists.newArrayList();
-
-    for (WriterCommitMessage message : messages) {
-      if (message != null) {
-        TaskCommit taskCommit = (TaskCommit) message;
-        files.addAll(Arrays.asList(taskCommit.files()));
-      }
+  private Iterable<DataFile> files(WriterCommitMessage[] messages) {
+    if (messages.length > 0) {
+      return Iterables.concat(
+          Iterables.transform(
+              Arrays.asList(messages),
+              message ->
+                  message != null
+                      ? ImmutableList.copyOf(((TaskCommit) message).files())
+                      : ImmutableList.of()));
     }
-
-    return files;
-  }
-
-  @Override
-  public String toString() {
-    return String.format("IcebergWrite(table=%s, format=%s)", table, format);
+    return ImmutableList.of();
   }
 
   private abstract class BaseBatchWrite implements BatchWrite {
@@ -280,28 +270,14 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
   private class DynamicOverwrite extends BaseBatchWrite {
     @Override
     public void commit(WriterCommitMessage[] messages) {
-      List<DataFile> files = files(messages);
+      Iterable<DataFile> files = files(messages);
 
-      if (files.isEmpty()) {
+      if (!files.iterator().hasNext()) {
         LOG.info("Dynamic overwrite is empty, skipping commit");
         return;
       }
 
       ReplacePartitions dynamicOverwrite = table.newReplacePartitions();
-      IsolationLevel isolationLevel = writeConf.isolationLevel();
-      Long validateFromSnapshotId = writeConf.validateFromSnapshotId();
-
-      if (isolationLevel != null && validateFromSnapshotId != null) {
-        dynamicOverwrite.validateFromSnapshot(validateFromSnapshotId);
-      }
-
-      if (isolationLevel == SERIALIZABLE) {
-        dynamicOverwrite.validateNoConflictingData();
-        dynamicOverwrite.validateNoConflictingDeletes();
-
-      } else if (isolationLevel == SNAPSHOT) {
-        dynamicOverwrite.validateNoConflictingDeletes();
-      }
 
       int numFiles = 0;
       for (DataFile file : files) {
@@ -333,42 +309,23 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
         overwriteFiles.addFile(file);
       }
 
-      IsolationLevel isolationLevel = writeConf.isolationLevel();
-      Long validateFromSnapshotId = writeConf.validateFromSnapshotId();
-
-      if (isolationLevel != null && validateFromSnapshotId != null) {
-        overwriteFiles.validateFromSnapshot(validateFromSnapshotId);
-      }
-
-      if (isolationLevel == SERIALIZABLE) {
-        overwriteFiles.validateNoConflictingDeletes();
-        overwriteFiles.validateNoConflictingData();
-
-      } else if (isolationLevel == SNAPSHOT) {
-        overwriteFiles.validateNoConflictingDeletes();
-      }
-
       String commitMsg =
           String.format("overwrite by filter %s with %d new data files", overwriteExpr, numFiles);
       commitOperation(overwriteFiles, commitMsg);
     }
   }
 
-  private class CopyOnWriteOperation extends BaseBatchWrite {
-    private final SparkCopyOnWriteScan scan;
+  private class CopyOnWriteMergeWrite extends BaseBatchWrite {
+    private final SparkMergeScan scan;
     private final IsolationLevel isolationLevel;
 
-    private CopyOnWriteOperation(SparkCopyOnWriteScan scan, IsolationLevel isolationLevel) {
+    private CopyOnWriteMergeWrite(SparkMergeScan scan, IsolationLevel isolationLevel) {
       this.scan = scan;
       this.isolationLevel = isolationLevel;
     }
 
     private List<DataFile> overwrittenFiles() {
-      if (scan == null) {
-        return ImmutableList.of();
-      } else {
-        return scan.tasks().stream().map(FileScanTask::file).collect(Collectors.toList());
-      }
+      return scan.files().stream().map(FileScanTask::file).collect(Collectors.toList());
     }
 
     private Expression conflictDetectionFilter() {
@@ -400,21 +357,12 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
         overwriteFiles.addFile(file);
       }
 
-      // the scan may be null if the optimizer replaces it with an empty relation (e.g. false cond)
-      // no validation is needed in this case as the command does not depend on the table state
-      if (scan != null) {
-        if (isolationLevel == SERIALIZABLE) {
-          commitWithSerializableIsolation(overwriteFiles, numOverwrittenFiles, numAddedFiles);
-        } else if (isolationLevel == SNAPSHOT) {
-          commitWithSnapshotIsolation(overwriteFiles, numOverwrittenFiles, numAddedFiles);
-        } else {
-          throw new IllegalArgumentException("Unsupported isolation level: " + isolationLevel);
-        }
-
+      if (isolationLevel == SERIALIZABLE) {
+        commitWithSerializableIsolation(overwriteFiles, numOverwrittenFiles, numAddedFiles);
+      } else if (isolationLevel == SNAPSHOT) {
+        commitWithSnapshotIsolation(overwriteFiles, numOverwrittenFiles, numAddedFiles);
       } else {
-        commitOperation(
-            overwriteFiles,
-            String.format("overwrite with %d new data files (no validation)", numAddedFiles));
+        throw new IllegalArgumentException("Unsupported isolation level: " + isolationLevel);
       }
     }
 
@@ -466,7 +414,13 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     @Override
     public void commit(WriterCommitMessage[] messages) {
       FileRewriteCoordinator coordinator = FileRewriteCoordinator.get();
-      coordinator.stageRewrite(table, fileSetID, ImmutableSet.copyOf(files(messages)));
+
+      Set<DataFile> newDataFiles = Sets.newHashSetWithExpectedSize(messages.length);
+      for (DataFile file : files(messages)) {
+        newDataFiles.add(file);
+      }
+
+      coordinator.stageRewrite(table, fileSetID, Collections.unmodifiableSet(newDataFiles));
     }
   }
 
@@ -608,11 +562,9 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     private final Schema writeSchema;
     private final StructType dsSchema;
     private final boolean partitionedFanoutEnabled;
-    private final String queryId;
 
     protected WriterFactory(
         Broadcast<Table> tableBroadcast,
-        String queryId,
         FileFormat format,
         long targetFileSize,
         Schema writeSchema,
@@ -624,7 +576,6 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       this.writeSchema = writeSchema;
       this.dsSchema = dsSchema;
       this.partitionedFanoutEnabled = partitionedFanoutEnabled;
-      this.queryId = queryId;
     }
 
     @Override
@@ -639,10 +590,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       FileIO io = table.io();
 
       OutputFileFactory fileFactory =
-          OutputFileFactory.builderFor(table, partitionId, taskId)
-              .format(format)
-              .operationId(queryId)
-              .build();
+          OutputFileFactory.builderFor(table, partitionId, taskId).format(format).build();
       SparkFileWriterFactory writerFactory =
           SparkFileWriterFactory.builderFor(table)
               .dataFileFormat(format)
@@ -667,6 +615,13 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     }
   }
 
+  private static <T extends ContentFile<T>> void deleteFiles(FileIO io, List<T> files) {
+    Tasks.foreach(files)
+        .throwFailureWhenFinished()
+        .noRetry()
+        .run(file -> io.deleteFile(file.path().toString()));
+  }
+
   private static class UnpartitionedDataWriter implements DataWriter<InternalRow> {
     private final FileWriter<InternalRow, DataWriteResult> delegate;
     private final FileIO io;
@@ -702,7 +657,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       close();
 
       DataWriteResult result = delegate.result();
-      SparkCleanupUtil.deleteTaskFiles(io, result.dataFiles());
+      deleteFiles(io, result.dataFiles());
     }
 
     @Override
@@ -759,7 +714,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       close();
 
       DataWriteResult result = delegate.result();
-      SparkCleanupUtil.deleteTaskFiles(io, result.dataFiles());
+      deleteFiles(io, result.dataFiles());
     }
 
     @Override
