@@ -16,9 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark.data.parquet.vectorized;
 
+import static org.apache.iceberg.TableProperties.PARQUET_ROW_GROUP_SIZE_BYTES_DEFAULT;
+
 import java.io.File;
 import java.io.IOException;
 import org.apache.avro.generic.GenericData;
@@ -35,42 +36,42 @@ import org.junit.Assert;
 import org.junit.Ignore;
 import org.junit.Test;
 
-import static org.apache.iceberg.TableProperties.PARQUET_ROW_GROUP_SIZE_BYTES_DEFAULT;
-
 public class TestParquetDictionaryEncodedVectorizedReads extends TestParquetVectorizedReads {
 
   @Override
-  Iterable<GenericData.Record> generateData(Schema schema, int numRecords, long seed, float nullPercentage,
-                                            Function<GenericData.Record, GenericData.Record> transform) {
-    Iterable data = RandomData.generateDictionaryEncodableData(schema, numRecords, seed, nullPercentage);
+  Iterable<GenericData.Record> generateData(
+      Schema schema,
+      int numRecords,
+      long seed,
+      float nullPercentage,
+      Function<GenericData.Record, GenericData.Record> transform) {
+    Iterable data =
+        RandomData.generateDictionaryEncodableData(schema, numRecords, seed, nullPercentage);
     return transform == IDENTITY ? data : Iterables.transform(data, transform);
   }
 
   @Test
   @Override
   @Ignore // Ignored since this code path is already tested in TestParquetVectorizedReads
-  public void testVectorizedReadsWithNewContainers() throws IOException {
-
-  }
+  public void testVectorizedReadsWithNewContainers() throws IOException {}
 
   @Test
   public void testMixedDictionaryNonDictionaryReads() throws IOException {
     Schema schema = new Schema(SUPPORTED_PRIMITIVES.fields());
     File dictionaryEncodedFile = temp.newFile();
     Assert.assertTrue("Delete should succeed", dictionaryEncodedFile.delete());
-    Iterable<GenericData.Record> dictionaryEncodableData = RandomData.generateDictionaryEncodableData(
-            schema,
-            10000,
-            0L,
-            RandomData.DEFAULT_NULL_PERCENTAGE);
-    try (FileAppender<GenericData.Record> writer = getParquetWriter(schema, dictionaryEncodedFile)) {
+    Iterable<GenericData.Record> dictionaryEncodableData =
+        RandomData.generateDictionaryEncodableData(
+            schema, 10000, 0L, RandomData.DEFAULT_NULL_PERCENTAGE);
+    try (FileAppender<GenericData.Record> writer =
+        getParquetWriter(schema, dictionaryEncodedFile)) {
       writer.addAll(dictionaryEncodableData);
     }
 
     File plainEncodingFile = temp.newFile();
     Assert.assertTrue("Delete should succeed", plainEncodingFile.delete());
-    Iterable<GenericData.Record> nonDictionaryData = RandomData.generate(schema, 10000, 0L,
-            RandomData.DEFAULT_NULL_PERCENTAGE);
+    Iterable<GenericData.Record> nonDictionaryData =
+        RandomData.generate(schema, 10000, 0L, RandomData.DEFAULT_NULL_PERCENTAGE);
     try (FileAppender<GenericData.Record> writer = getParquetWriter(schema, plainEncodingFile)) {
       writer.addAll(nonDictionaryData);
     }
@@ -78,15 +79,19 @@ public class TestParquetDictionaryEncodedVectorizedReads extends TestParquetVect
     int rowGroupSize = PARQUET_ROW_GROUP_SIZE_BYTES_DEFAULT;
     File mixedFile = temp.newFile();
     Assert.assertTrue("Delete should succeed", mixedFile.delete());
-    Parquet.concat(ImmutableList.of(dictionaryEncodedFile, plainEncodingFile, dictionaryEncodedFile),
-            mixedFile, rowGroupSize, schema, ImmutableMap.of());
+    Parquet.concat(
+        ImmutableList.of(dictionaryEncodedFile, plainEncodingFile, dictionaryEncodedFile),
+        mixedFile,
+        rowGroupSize,
+        schema,
+        ImmutableMap.of());
     assertRecordsMatch(
-            schema,
-            30000,
-            FluentIterable.concat(dictionaryEncodableData, nonDictionaryData, dictionaryEncodableData),
-            mixedFile,
-            false,
-            true,
-            BATCH_SIZE);
+        schema,
+        30000,
+        FluentIterable.concat(dictionaryEncodableData, nonDictionaryData, dictionaryEncodableData),
+        mixedFile,
+        false,
+        true,
+        BATCH_SIZE);
   }
 }
