@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark;
 
 import java.io.IOException;
@@ -41,7 +40,8 @@ public class SmokeTest extends SparkExtensionsTestBase {
   }
 
   // Run through our Doc's Getting Started Example
-  // TODO Update doc example so that it can actually be run, modifications were required for this test suite to run
+  // TODO Update doc example so that it can actually be run, modifications were required for this
+  // test suite to run
   @Test
   public void testGettingStarted() throws IOException {
     // Creating a table
@@ -49,45 +49,58 @@ public class SmokeTest extends SparkExtensionsTestBase {
 
     // Writing
     sql("INSERT INTO %s VALUES (1, 'a'), (2, 'b'), (3, 'c')", tableName);
-    Assert.assertEquals("Should have inserted 3 rows",
-        3L, scalarSql("SELECT COUNT(*) FROM %s", tableName));
+    Assert.assertEquals(
+        "Should have inserted 3 rows", 3L, scalarSql("SELECT COUNT(*) FROM %s", tableName));
 
     sql("DROP TABLE IF EXISTS source");
-    sql("CREATE TABLE source (id bigint, data string) USING parquet LOCATION '%s'", temp.newFolder());
+    sql(
+        "CREATE TABLE source (id bigint, data string) USING parquet LOCATION '%s'",
+        temp.newFolder());
     sql("INSERT INTO source VALUES (10, 'd'), (11, 'ee')");
 
     sql("INSERT INTO %s SELECT id, data FROM source WHERE length(data) = 1", tableName);
-    Assert.assertEquals("Table should now have 4 rows",
-        4L, scalarSql("SELECT COUNT(*) FROM %s", tableName));
+    Assert.assertEquals(
+        "Table should now have 4 rows", 4L, scalarSql("SELECT COUNT(*) FROM %s", tableName));
 
     sql("DROP TABLE IF EXISTS updates");
-    sql("CREATE TABLE updates (id bigint, data string) USING parquet LOCATION '%s'", temp.newFolder());
+    sql(
+        "CREATE TABLE updates (id bigint, data string) USING parquet LOCATION '%s'",
+        temp.newFolder());
     sql("INSERT INTO updates VALUES (1, 'x'), (2, 'x'), (4, 'z')");
 
-    sql("MERGE INTO %s t USING (SELECT * FROM updates) u ON t.id = u.id\n" +
-        "WHEN MATCHED THEN UPDATE SET t.data = u.data\n" +
-        "WHEN NOT MATCHED THEN INSERT *", tableName);
-    Assert.assertEquals("Table should now have 5 rows",
-        5L, scalarSql("SELECT COUNT(*) FROM %s", tableName));
-    Assert.assertEquals("Record 1 should now have data x",
-        "x", scalarSql("SELECT data FROM %s WHERE id = 1", tableName));
+    sql(
+        "MERGE INTO %s t USING (SELECT * FROM updates) u ON t.id = u.id\n"
+            + "WHEN MATCHED THEN UPDATE SET t.data = u.data\n"
+            + "WHEN NOT MATCHED THEN INSERT *",
+        tableName);
+    Assert.assertEquals(
+        "Table should now have 5 rows", 5L, scalarSql("SELECT COUNT(*) FROM %s", tableName));
+    Assert.assertEquals(
+        "Record 1 should now have data x",
+        "x",
+        scalarSql("SELECT data FROM %s WHERE id = 1", tableName));
 
     // Reading
-    Assert.assertEquals("There should be 2 records with data x",
-        2L, scalarSql(
-            "SELECT count(1) as count FROM %s WHERE data = 'x' GROUP BY data ", tableName));
+    Assert.assertEquals(
+        "There should be 2 records with data x",
+        2L,
+        scalarSql("SELECT count(1) as count FROM %s WHERE data = 'x' GROUP BY data ", tableName));
 
     // Not supported because of Spark limitation
     if (!catalogName.equals("spark_catalog")) {
-      Assert.assertEquals("There should be 3 snapshots",
-          3L, scalarSql("SELECT COUNT(*) FROM %s.snapshots", tableName));
+      Assert.assertEquals(
+          "There should be 3 snapshots",
+          3L,
+          scalarSql("SELECT COUNT(*) FROM %s.snapshots", tableName));
     }
   }
 
   // From Spark DDL Docs section
   @Test
   public void testAlterTable() throws NoSuchTableException {
-    sql("CREATE TABLE %s (category int, id bigint, data string, ts timestamp) USING iceberg", tableName);
+    sql(
+        "CREATE TABLE %s (category int, id bigint, data string, ts timestamp) USING iceberg",
+        tableName);
     Table table = getTable();
     // Add examples
     sql("ALTER TABLE %s ADD PARTITION FIELD bucket(16, id)", tableName);
@@ -106,7 +119,8 @@ public class SmokeTest extends SparkExtensionsTestBase {
     table = getTable();
     Assert.assertEquals("Table should have 4 partition fields", 4, table.spec().fields().size());
     // VoidTransform is package private so we can't reach it here, just checking name
-    Assert.assertTrue("All transforms should be void",
+    Assert.assertTrue(
+        "All transforms should be void",
         table.spec().fields().stream().allMatch(pf -> pf.transform().toString().equals("void")));
 
     // Sort order examples
@@ -123,28 +137,34 @@ public class SmokeTest extends SparkExtensionsTestBase {
     sql("DROP TABLE IF EXISTS %s", tableName("second"));
     sql("DROP TABLE IF EXISTS %s", tableName("third"));
 
-    sql("CREATE TABLE %s (\n" +
-        "    id bigint COMMENT 'unique id',\n" +
-        "    data string)\n" +
-        "USING iceberg", tableName("first"));
+    sql(
+        "CREATE TABLE %s (\n"
+            + "    id bigint COMMENT 'unique id',\n"
+            + "    data string)\n"
+            + "USING iceberg",
+        tableName("first"));
     getTable("first"); // Table should exist
 
-    sql("CREATE TABLE %s (\n" +
-        "    id bigint,\n" +
-        "    data string,\n" +
-        "    category string)\n" +
-        "USING iceberg\n" +
-        "PARTITIONED BY (category)", tableName("second"));
+    sql(
+        "CREATE TABLE %s (\n"
+            + "    id bigint,\n"
+            + "    data string,\n"
+            + "    category string)\n"
+            + "USING iceberg\n"
+            + "PARTITIONED BY (category)",
+        tableName("second"));
     Table second = getTable("second");
     Assert.assertEquals("Should be partitioned on 1 column", 1, second.spec().fields().size());
 
-    sql("CREATE TABLE %s (\n" +
-        "    id bigint,\n" +
-        "    data string,\n" +
-        "    category string,\n" +
-        "    ts timestamp)\n" +
-        "USING iceberg\n" +
-        "PARTITIONED BY (bucket(16, id), days(ts), category)", tableName("third"));
+    sql(
+        "CREATE TABLE %s (\n"
+            + "    id bigint,\n"
+            + "    data string,\n"
+            + "    category string,\n"
+            + "    ts timestamp)\n"
+            + "USING iceberg\n"
+            + "PARTITIONED BY (bucket(16, id), days(ts), category)",
+        tableName("third"));
     Table third = getTable("third");
     Assert.assertEquals("Should be partitioned on 3 columns", 3, third.spec().fields().size());
   }
@@ -156,5 +176,4 @@ public class SmokeTest extends SparkExtensionsTestBase {
   private Table getTable() {
     return validationCatalog.loadTable(tableIdent);
   }
-
 }
