@@ -287,4 +287,8 @@ public class SparkUtil {
 
     return filterExpressions;
   }
+
+  public static boolean caseSensitive(SparkSession spark) {
+    return Boolean.parseBoolean(spark.conf().get("spark.sql.caseSensitive"));
+  }
 }
