@@ -20,15 +20,17 @@ package org.apache.iceberg.spark;
 
 import static org.apache.hadoop.hive.conf.HiveConf.ConfVars.METASTOREURIS;
 
+import java.io.IOException;
+import java.io.UncheckedIOException;
+import java.net.URI;
+import java.nio.file.Files;
+import java.nio.file.Path;
+import java.nio.file.Paths;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
-import java.util.concurrent.Callable;
-import java.util.concurrent.TimeoutException;
-import java.util.stream.Collectors;
-import java.util.stream.IntStream;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.iceberg.CatalogUtil;
+import org.apache.iceberg.ContentFile;
 import org.apache.iceberg.catalog.Namespace;
 import org.apache.iceberg.exceptions.AlreadyExistsException;
 import org.apache.iceberg.hive.HiveCatalog;
@@ -37,19 +39,16 @@ import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
-import org.apache.iceberg.relocated.com.google.common.collect.Sets;
+import org.apache.spark.sql.Dataset;
+import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SparkSession;
-import org.apache.spark.sql.execution.ui.SQLExecutionUIData;
 import org.apache.spark.sql.internal.SQLConf;
 import org.junit.AfterClass;
 import org.junit.Assert;
 import org.junit.BeforeClass;
-import scala.collection.JavaConverters;
 
-public abstract class SparkTestBase {
-
-  protected static final Object ANY = new Object();
+public abstract class SparkTestBase extends SparkTestHelperBase {
 
   protected static TestHiveMetastore metastore = null;
   protected static HiveConf hiveConf = null;
@@ -112,32 +111,6 @@ public abstract class SparkTestBase {
     return rowsToJava(rows);
   }
 
-  protected List<Object[]> rowsToJava(List<Row> rows) {
-    return rows.stream().map(this::toJava).collect(Collectors.toList());
-  }
-
-  private Object[] toJava(Row row) {
-    return IntStream.range(0, row.size())
-        .mapToObj(
-            pos -> {
-              if (row.isNullAt(pos)) {
-                return null;
-              }
-
-              Object value = row.get(pos);
-              if (value instanceof Row) {
-                return toJava((Row) value);
-              } else if (value instanceof scala.collection.Seq) {
-                return row.getList(pos);
-              } else if (value instanceof scala.collection.Map) {
-                return row.getJavaMap(pos);
-              } else {
-                return value;
-              }
-            })
-        .toArray(Object[]::new);
-  }
-
   protected Object scalarSql(String query, Object... args) {
     List<Object[]> rows = sql(query, args);
     Assert.assertEquals("Scalar SQL should return one row", 1, rows.size());
@@ -150,39 +123,40 @@ public abstract class SparkTestBase {
     return values;
   }
 
-  protected void assertEquals(
-      String context, List<Object[]> expectedRows, List<Object[]> actualRows) {
-    Assert.assertEquals(
-        context + ": number of results should match", expectedRows.size(), actualRows.size());
-    for (int row = 0; row < expectedRows.size(); row += 1) {
-      Object[] expected = expectedRows.get(row);
-      Object[] actual = actualRows.get(row);
-      Assert.assertEquals("Number of columns should match", expected.length, actual.length);
-      for (int col = 0; col < actualRows.get(row).length; col += 1) {
-        String newContext = String.format("%s: row %d col %d", context, row + 1, col + 1);
-        assertEquals(newContext, expected, actual);
-      }
-    }
-  }
-
-  protected void assertEquals(String context, Object[] expectedRow, Object[] actualRow) {
-    Assert.assertEquals("Number of columns should match", expectedRow.length, actualRow.length);
-    for (int col = 0; col < actualRow.length; col += 1) {
-      Object expectedValue = expectedRow[col];
-      Object actualValue = actualRow[col];
-      if (expectedValue != null && expectedValue.getClass().isArray()) {
-        String newContext = String.format("%s (nested col %d)", context, col + 1);
-        assertEquals(newContext, (Object[]) expectedValue, (Object[]) actualValue);
-      } else if (expectedValue != ANY) {
-        Assert.assertEquals(context + " contents should match", expectedValue, actualValue);
-      }
-    }
-  }
-
   protected static String dbPath(String dbName) {
     return metastore.getDatabasePath(dbName);
   }
 
+  protected void withUnavailableFiles(Iterable<? extends ContentFile<?>> files, Action action) {
+    Iterable<String> fileLocations = Iterables.transform(files, file -> file.path().toString());
+    withUnavailableLocations(fileLocations, action);
+  }
+
+  private void move(String location, String newLocation) {
+    Path path = Paths.get(URI.create(location));
+    Path tempPath = Paths.get(URI.create(newLocation));
+
+    try {
+      Files.move(path, tempPath);
+    } catch (IOException e) {
+      throw new UncheckedIOException("Failed to move: " + location, e);
+    }
+  }
+
+  protected void withUnavailableLocations(Iterable<String> locations, Action action) {
+    for (String location : locations) {
+      move(location, location + "_temp");
+    }
+
+    try {
+      action.invoke();
+    } finally {
+      for (String location : locations) {
+        move(location + "_temp", location);
+      }
+    }
+  }
+
   protected void withSQLConf(Map<String, String> conf, Action action) {
     SQLConf sqlConf = SQLConf.get();
 
@@ -198,7 +172,7 @@ public abstract class SparkTestBase {
 
     conf.forEach(
         (confKey, confValue) -> {
-          if (SQLConf.staticConfKeys().contains(confKey)) {
+          if (SQLConf.isStaticConfigKey(confKey)) {
             throw new RuntimeException("Cannot modify the value of a static config: " + confKey);
           }
           sqlConf.setConfString(confKey, confValue);
@@ -218,43 +192,9 @@ public abstract class SparkTestBase {
     }
   }
 
-  private Map<Long, SQLExecutionUIData> currentExecutionUIDataMap() throws TimeoutException {
-    spark.sparkContext().listenerBus().waitUntilEmpty(10000);
-    return JavaConverters.seqAsJavaList(spark.sharedState().statusStore().executionsList()).stream()
-        .collect(Collectors.toMap(data -> data.executionId(), data -> data));
-  }
-
-  protected void checkMetrics(Callable sparkCallable, Map<String, String> expectedMetrics)
-      throws Exception {
-    Set<Long> originalExecutionIds = currentExecutionUIDataMap().keySet();
-    sparkCallable.call();
-    Map<Long, SQLExecutionUIData> currentExecutions = currentExecutionUIDataMap();
-    Set<Long> currentExecutionIds = currentExecutions.keySet();
-    currentExecutionIds.removeAll(originalExecutionIds);
-    Assert.assertEquals(currentExecutionIds.size(), 1);
-    SQLExecutionUIData currentExecution =
-        currentExecutions.get(currentExecutionIds.stream().findFirst().get());
-
-    Map<Long, String> metricsIds = Maps.newHashMap();
-    JavaConverters.seqAsJavaList(currentExecution.metrics()).stream()
-        .forEach(
-            metricsDeclaration -> {
-              if (expectedMetrics.containsKey(metricsDeclaration.name())) {
-                metricsIds.put(metricsDeclaration.accumulatorId(), metricsDeclaration.name());
-              }
-            });
-    Assert.assertEquals(
-        "Expected metric name not match",
-        expectedMetrics.keySet(),
-        Sets.newHashSet(metricsIds.values()));
-
-    Map<Object, String> currentMetrics =
-        JavaConverters.mapAsJavaMap(
-                spark.sharedState().statusStore().executionMetrics(currentExecution.executionId()))
-            .entrySet().stream()
-            .filter(x -> metricsIds.containsKey(x.getKey()))
-            .collect(Collectors.toMap(x -> metricsIds.get(x.getKey()), x -> x.getValue()));
-    Assert.assertEquals("Expected metric value not match", expectedMetrics, currentMetrics);
+  protected Dataset<Row> jsonToDF(String schema, String... records) {
+    Dataset<String> jsonDF = spark.createDataset(ImmutableList.copyOf(records), Encoders.STRING());
+    return spark.read().schema(schema).json(jsonDF);
   }
 
   @FunctionalInterface
