@@ -16,12 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark;
 
 import java.io.File;
 import java.io.IOException;
 import java.util.Map;
+import org.apache.hadoop.fs.FileSystem;
+import org.apache.hadoop.fs.Path;
 import org.apache.iceberg.catalog.Catalog;
 import org.apache.iceberg.catalog.Namespace;
 import org.apache.iceberg.catalog.SupportsNamespaces;
@@ -43,14 +44,15 @@ public abstract class SparkTestBaseWithCatalog extends SparkTestBase {
   }
 
   @AfterClass
-  public static void dropWarehouse() {
+  public static void dropWarehouse() throws IOException {
     if (warehouse != null && warehouse.exists()) {
-      warehouse.delete();
+      Path warehousePath = new Path(warehouse.getAbsolutePath());
+      FileSystem fs = warehousePath.getFileSystem(hiveConf);
+      Assert.assertTrue("Failed to delete " + warehousePath, fs.delete(warehousePath, true));
     }
   }
 
-  @Rule
-  public TemporaryFolder temp = new TemporaryFolder();
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
   protected final String catalogName;
   protected final Catalog validationCatalog;
@@ -66,21 +68,25 @@ public abstract class SparkTestBaseWithCatalog extends SparkTestBase {
     this(config.catalogName(), config.implementation(), config.properties());
   }
 
-  public SparkTestBaseWithCatalog(String catalogName, String implementation, Map<String, String> config) {
+  public SparkTestBaseWithCatalog(
+      String catalogName, String implementation, Map<String, String> config) {
     this.catalogName = catalogName;
-    this.validationCatalog = catalogName.equals("testhadoop") ?
-        new HadoopCatalog(spark.sessionState().newHadoopConf(), "file:" + warehouse) :
-        catalog;
+    this.validationCatalog =
+        catalogName.equals("testhadoop")
+            ? new HadoopCatalog(spark.sessionState().newHadoopConf(), "file:" + warehouse)
+            : catalog;
     this.validationNamespaceCatalog = (SupportsNamespaces) validationCatalog;
 
     spark.conf().set("spark.sql.catalog." + catalogName, implementation);
-    config.forEach((key, value) -> spark.conf().set("spark.sql.catalog." + catalogName + "." + key, value));
+    config.forEach(
+        (key, value) -> spark.conf().set("spark.sql.catalog." + catalogName + "." + key, value));
 
     if (config.get("type").equalsIgnoreCase("hadoop")) {
       spark.conf().set("spark.sql.catalog." + catalogName + ".warehouse", "file:" + warehouse);
     }
 
-    this.tableName = (catalogName.equals("spark_catalog") ? "" : catalogName + ".") + "default.table";
+    this.tableName =
+        (catalogName.equals("spark_catalog") ? "" : catalogName + ".") + "default.table";
 
     sql("CREATE NAMESPACE IF NOT EXISTS default");
   }
