@@ -1254,15 +1254,15 @@ public class TestExpireSnapshotsAction extends SparkTestBase {
 
   @Test
   public void testExpireFileDeletionMostExpired() {
-    textExpireAllCheckFilesDeleted(5, 2);
+    testExpireFilesAreDeleted(5, 2);
   }
 
   @Test
   public void testExpireFileDeletionMostRetained() {
-    textExpireAllCheckFilesDeleted(2, 5);
+    testExpireFilesAreDeleted(2, 5);
   }
 
-  public void textExpireAllCheckFilesDeleted(int dataFilesExpired, int dataFilesRetained) {
+  public void testExpireFilesAreDeleted(int dataFilesExpired, int dataFilesRetained) {
     // Add data files to be expired
     Set<String> dataFiles = Sets.newHashSet();
     for (int i = 0; i < dataFilesExpired; i++) {
