@@ -25,6 +25,7 @@ import java.io.File;
 import java.io.IOException;
 import java.util.List;
 import java.util.UUID;
+import java.util.concurrent.TimeoutException;
 import org.apache.avro.generic.GenericData;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.iceberg.AssertHelpers;
@@ -61,7 +62,8 @@ import org.junit.BeforeClass;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
-import scala.collection.JavaConversions;
+import scala.Option;
+import scala.collection.JavaConverters;
 
 public class TestForwardCompatibility {
   private static final Configuration CONF = new Configuration();
@@ -127,7 +129,7 @@ public class TestForwardCompatibility {
   }
 
   @Test
-  public void testSparkStreamingWriteFailsUnknownTransform() throws IOException {
+  public void testSparkStreamingWriteFailsUnknownTransform() throws IOException, TimeoutException {
     File parent = temp.newFolder("avro");
     File location = new File(parent, "test");
     File dataFolder = new File(location, "data");
@@ -213,10 +215,10 @@ public class TestForwardCompatibility {
   }
 
   private <T> MemoryStream<T> newMemoryStream(int id, SQLContext sqlContext, Encoder<T> encoder) {
-    return new MemoryStream<>(id, sqlContext, encoder);
+    return new MemoryStream<>(id, sqlContext, Option.empty(), encoder);
   }
 
   private <T> void send(List<T> records, MemoryStream<T> stream) {
-    stream.addData(JavaConversions.asScalaBuffer(records));
+    stream.addData(JavaConverters.asScalaBuffer(records));
   }
 }
