@@ -16,9 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark.source;
 
+import static org.apache.iceberg.expressions.Expressions.ref;
+
 import java.io.File;
 import java.util.Collections;
 import java.util.List;
@@ -58,8 +59,6 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 
-import static org.apache.iceberg.expressions.Expressions.ref;
-
 @RunWith(Parameterized.class)
 public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
   public TestStructuredStreamingRead3(
@@ -70,59 +69,49 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
   private Table table;
 
   /**
-   * test data to be used by multiple writes
-   * each write creates a snapshot and writes a list of records
+   * test data to be used by multiple writes each write creates a snapshot and writes a list of
+   * records
    */
-  private static final List<List<SimpleRecord>> TEST_DATA_MULTIPLE_SNAPSHOTS = Lists.newArrayList(
+  private static final List<List<SimpleRecord>> TEST_DATA_MULTIPLE_SNAPSHOTS =
       Lists.newArrayList(
-          new SimpleRecord(1, "one"),
-          new SimpleRecord(2, "two"),
-          new SimpleRecord(3, "three")),
-      Lists.newArrayList(
-          new SimpleRecord(4, "four"),
-          new SimpleRecord(5, "five")),
-      Lists.newArrayList(
-          new SimpleRecord(6, "six"),
-          new SimpleRecord(7, "seven")));
+          Lists.newArrayList(
+              new SimpleRecord(1, "one"), new SimpleRecord(2, "two"), new SimpleRecord(3, "three")),
+          Lists.newArrayList(new SimpleRecord(4, "four"), new SimpleRecord(5, "five")),
+          Lists.newArrayList(new SimpleRecord(6, "six"), new SimpleRecord(7, "seven")));
 
   /**
-   * test data - to be used for multiple write batches
-   * each batch inturn will have multiple snapshots
+   * test data - to be used for multiple write batches each batch inturn will have multiple
+   * snapshots
    */
-  private static final List<List<List<SimpleRecord>>> TEST_DATA_MULTIPLE_WRITES_MULTIPLE_SNAPSHOTS = Lists.newArrayList(
+  private static final List<List<List<SimpleRecord>>> TEST_DATA_MULTIPLE_WRITES_MULTIPLE_SNAPSHOTS =
       Lists.newArrayList(
           Lists.newArrayList(
-              new SimpleRecord(1, "one"),
-              new SimpleRecord(2, "two"),
-              new SimpleRecord(3, "three")),
+              Lists.newArrayList(
+                  new SimpleRecord(1, "one"),
+                  new SimpleRecord(2, "two"),
+                  new SimpleRecord(3, "three")),
+              Lists.newArrayList(new SimpleRecord(4, "four"), new SimpleRecord(5, "five"))),
           Lists.newArrayList(
-              new SimpleRecord(4, "four"),
-              new SimpleRecord(5, "five"))),
-      Lists.newArrayList(
+              Lists.newArrayList(new SimpleRecord(6, "six"), new SimpleRecord(7, "seven")),
+              Lists.newArrayList(new SimpleRecord(8, "eight"), new SimpleRecord(9, "nine"))),
           Lists.newArrayList(
-              new SimpleRecord(6, "six"),
-              new SimpleRecord(7, "seven")),
-          Lists.newArrayList(
-              new SimpleRecord(8, "eight"),
-              new SimpleRecord(9, "nine"))),
-      Lists.newArrayList(
-          Lists.newArrayList(
-              new SimpleRecord(10, "ten"),
-              new SimpleRecord(11, "eleven"),
-              new SimpleRecord(12, "twelve")),
-          Lists.newArrayList(
-              new SimpleRecord(13, "thirteen"),
-              new SimpleRecord(14, "fourteen")),
-          Lists.newArrayList(
-              new SimpleRecord(15, "fifteen"),
-              new SimpleRecord(16, "sixteen"))));
+              Lists.newArrayList(
+                  new SimpleRecord(10, "ten"),
+                  new SimpleRecord(11, "eleven"),
+                  new SimpleRecord(12, "twelve")),
+              Lists.newArrayList(
+                  new SimpleRecord(13, "thirteen"), new SimpleRecord(14, "fourteen")),
+              Lists.newArrayList(
+                  new SimpleRecord(15, "fifteen"), new SimpleRecord(16, "sixteen"))));
 
   @Before
   public void setupTable() {
-    sql("CREATE TABLE %s " +
-        "(id INT, data STRING) " +
-        "USING iceberg " +
-        "PARTITIONED BY (bucket(3, id))", tableName);
+    sql(
+        "CREATE TABLE %s "
+            + "(id INT, data STRING) "
+            + "USING iceberg "
+            + "PARTITIONED BY (bucket(3, id))",
+        tableName);
     this.table = validationCatalog.loadTable(tableIdent);
   }
 
@@ -163,17 +152,19 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
   @Test
   public void testReadingStreamFromTimestamp() throws Exception {
-    List<SimpleRecord> dataBeforeTimestamp = Lists.newArrayList(
-        new SimpleRecord(-2, "minustwo"),
-        new SimpleRecord(-1, "minusone"),
-        new SimpleRecord(0, "zero"));
+    List<SimpleRecord> dataBeforeTimestamp =
+        Lists.newArrayList(
+            new SimpleRecord(-2, "minustwo"),
+            new SimpleRecord(-1, "minusone"),
+            new SimpleRecord(0, "zero"));
 
     appendData(dataBeforeTimestamp);
 
     table.refresh();
     long streamStartTimestamp = table.currentSnapshot().timestampMillis() + 1;
 
-    StreamingQuery query = startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, Long.toString(streamStartTimestamp));
+    StreamingQuery query =
+        startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, Long.toString(streamStartTimestamp));
 
     List<SimpleRecord> empty = rowsAvailable(query);
     Assertions.assertThat(empty.isEmpty()).isTrue();
@@ -190,21 +181,25 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
   public void testReadingStreamFromFutureTimetsamp() throws Exception {
     long futureTimestamp = System.currentTimeMillis() + 10000;
 
-    StreamingQuery query = startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, Long.toString(futureTimestamp));
+    StreamingQuery query =
+        startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, Long.toString(futureTimestamp));
 
     List<SimpleRecord> actual = rowsAvailable(query);
     Assertions.assertThat(actual.isEmpty()).isTrue();
 
-    List<SimpleRecord> data = Lists.newArrayList(
-        new SimpleRecord(-2, "minustwo"),
-        new SimpleRecord(-1, "minusone"),
-        new SimpleRecord(0, "zero"));
+    List<SimpleRecord> data =
+        Lists.newArrayList(
+            new SimpleRecord(-2, "minustwo"),
+            new SimpleRecord(-1, "minusone"),
+            new SimpleRecord(0, "zero"));
 
     // Perform several inserts that should not show up because the fromTimestamp has not elapsed
-    IntStream.range(0, 3).forEach(x -> {
-      appendData(data);
-      Assertions.assertThat(rowsAvailable(query).isEmpty()).isTrue();
-    });
+    IntStream.range(0, 3)
+        .forEach(
+            x -> {
+              appendData(data);
+              Assertions.assertThat(rowsAvailable(query).isEmpty()).isTrue();
+            });
 
     waitUntilAfter(futureTimestamp);
 
@@ -216,16 +211,16 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
   @Test
   public void testReadingStreamFromTimestampFutureWithExistingSnapshots() throws Exception {
-    List<SimpleRecord> dataBeforeTimestamp = Lists.newArrayList(
-        new SimpleRecord(1, "one"),
-        new SimpleRecord(2, "two"),
-        new SimpleRecord(3, "three"));
+    List<SimpleRecord> dataBeforeTimestamp =
+        Lists.newArrayList(
+            new SimpleRecord(1, "one"), new SimpleRecord(2, "two"), new SimpleRecord(3, "three"));
     appendData(dataBeforeTimestamp);
 
     long streamStartTimestamp = System.currentTimeMillis() + 2000;
 
     // Start the stream with a future timestamp after the current snapshot
-    StreamingQuery query = startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, Long.toString(streamStartTimestamp));
+    StreamingQuery query =
+        startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, Long.toString(streamStartTimestamp));
     List<SimpleRecord> actual = rowsAvailable(query);
     Assert.assertEquals(Collections.emptyList(), actual);
 
@@ -233,7 +228,8 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
     waitUntilAfter(streamStartTimestamp);
     List<List<SimpleRecord>> expected = TEST_DATA_MULTIPLE_SNAPSHOTS;
     appendDataAsMultipleSnapshots(expected);
-    Assertions.assertThat(rowsAvailable(query)).containsExactlyInAnyOrderElementsOf(Iterables.concat(expected));
+    Assertions.assertThat(rowsAvailable(query))
+        .containsExactlyInAnyOrderElementsOf(Iterables.concat(expected));
   }
 
   @Test
@@ -246,7 +242,8 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
     long firstSnapshotTime = table.currentSnapshot().timestampMillis();
 
     // Start stream giving the first Snapshot's time as the start point
-    StreamingQuery stream = startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, Long.toString(firstSnapshotTime));
+    StreamingQuery stream =
+        startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, Long.toString(firstSnapshotTime));
 
     // Append rest of expected data
     for (int i = 1; i < expected.size(); i++) {
@@ -259,14 +256,11 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
   @Test
   public void testReadingStreamWithExpiredSnapshotFromTimestamp() throws TimeoutException {
-    List<SimpleRecord> firstSnapshotRecordList = Lists.newArrayList(
-        new SimpleRecord(1, "one"));
+    List<SimpleRecord> firstSnapshotRecordList = Lists.newArrayList(new SimpleRecord(1, "one"));
 
-    List<SimpleRecord> secondSnapshotRecordList = Lists.newArrayList(
-        new SimpleRecord(2, "two"));
+    List<SimpleRecord> secondSnapshotRecordList = Lists.newArrayList(new SimpleRecord(2, "two"));
 
-    List<SimpleRecord> thirdSnapshotRecordList = Lists.newArrayList(
-        new SimpleRecord(3, "three"));
+    List<SimpleRecord> thirdSnapshotRecordList = Lists.newArrayList(new SimpleRecord(3, "three"));
 
     List<SimpleRecord> expectedRecordList = Lists.newArrayList();
     expectedRecordList.addAll(secondSnapshotRecordList);
@@ -277,13 +271,14 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
     long firstSnapshotid = table.currentSnapshot().snapshotId();
     long firstSnapshotCommitTime = table.currentSnapshot().timestampMillis();
 
-
     appendData(secondSnapshotRecordList);
     appendData(thirdSnapshotRecordList);
 
     table.expireSnapshots().expireSnapshotId(firstSnapshotid).commit();
 
-    StreamingQuery query = startStream(SparkReadOptions.STREAM_FROM_TIMESTAMP, String.valueOf(firstSnapshotCommitTime));
+    StreamingQuery query =
+        startStream(
+            SparkReadOptions.STREAM_FROM_TIMESTAMP, String.valueOf(firstSnapshotCommitTime));
     List<SimpleRecord> actual = rowsAvailable(query);
     Assertions.assertThat(actual).containsExactlyInAnyOrderElementsOf(expectedRecordList);
   }
@@ -294,21 +289,24 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
     File writerCheckpoint = new File(writerCheckpointFolder, "writer-checkpoint");
     File output = temp.newFolder();
 
-    DataStreamWriter querySource = spark.readStream()
-        .format("iceberg")
-        .load(tableName)
-        .writeStream()
-        .option("checkpointLocation", writerCheckpoint.toString())
-        .format("parquet")
-        .queryName("checkpoint_test")
-        .option("path", output.getPath());
+    DataStreamWriter querySource =
+        spark
+            .readStream()
+            .format("iceberg")
+            .load(tableName)
+            .writeStream()
+            .option("checkpointLocation", writerCheckpoint.toString())
+            .format("parquet")
+            .queryName("checkpoint_test")
+            .option("path", output.getPath());
 
     StreamingQuery startQuery = querySource.start();
     startQuery.processAllAvailable();
     startQuery.stop();
 
     List<SimpleRecord> expected = Lists.newArrayList();
-    for (List<List<SimpleRecord>> expectedCheckpoint : TEST_DATA_MULTIPLE_WRITES_MULTIPLE_SNAPSHOTS) {
+    for (List<List<SimpleRecord>> expectedCheckpoint :
+        TEST_DATA_MULTIPLE_WRITES_MULTIPLE_SNAPSHOTS) {
       // New data was added while the stream was down
       appendDataAsMultipleSnapshots(expectedCheckpoint);
       expected.addAll(Lists.newArrayList(Iterables.concat(Iterables.concat(expectedCheckpoint))));
@@ -319,28 +317,23 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
       restartedQuery.stop();
 
       // Read data added by the stream
-      List<SimpleRecord> actual = spark.read()
-          .load(output.getPath())
-          .as(Encoders.bean(SimpleRecord.class))
-          .collectAsList();
+      List<SimpleRecord> actual =
+          spark.read().load(output.getPath()).as(Encoders.bean(SimpleRecord.class)).collectAsList();
       Assertions.assertThat(actual).containsExactlyInAnyOrderElementsOf(Iterables.concat(expected));
     }
   }
 
   @Test
   public void testParquetOrcAvroDataInOneTable() throws Exception {
-    List<SimpleRecord> parquetFileRecords = Lists.newArrayList(
-        new SimpleRecord(1, "one"),
-        new SimpleRecord(2, "two"),
-        new SimpleRecord(3, "three"));
+    List<SimpleRecord> parquetFileRecords =
+        Lists.newArrayList(
+            new SimpleRecord(1, "one"), new SimpleRecord(2, "two"), new SimpleRecord(3, "three"));
 
-    List<SimpleRecord> orcFileRecords = Lists.newArrayList(
-        new SimpleRecord(4, "four"),
-        new SimpleRecord(5, "five"));
+    List<SimpleRecord> orcFileRecords =
+        Lists.newArrayList(new SimpleRecord(4, "four"), new SimpleRecord(5, "five"));
 
-    List<SimpleRecord> avroFileRecords = Lists.newArrayList(
-        new SimpleRecord(6, "six"),
-        new SimpleRecord(7, "seven"));
+    List<SimpleRecord> avroFileRecords =
+        Lists.newArrayList(new SimpleRecord(6, "six"), new SimpleRecord(7, "seven"));
 
     appendData(parquetFileRecords);
     appendData(orcFileRecords, "orc");
@@ -348,7 +341,8 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
     StreamingQuery query = startStream();
     Assertions.assertThat(rowsAvailable(query))
-        .containsExactlyInAnyOrderElementsOf(Iterables.concat(parquetFileRecords, orcFileRecords, avroFileRecords));
+        .containsExactlyInAnyOrderElementsOf(
+            Iterables.concat(parquetFileRecords, orcFileRecords, avroFileRecords));
   }
 
   @Test
@@ -371,18 +365,23 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
     Schema deleteRowSchema = table.schema().select("data");
     Record dataDelete = GenericRecord.create(deleteRowSchema);
-    List<Record> dataDeletes = Lists.newArrayList(
-        dataDelete.copy("data", "one") // id = 1
-    );
+    List<Record> dataDeletes =
+        Lists.newArrayList(
+            dataDelete.copy("data", "one") // id = 1
+            );
 
-    DeleteFile eqDeletes = FileHelpers.writeDeleteFile(
-        table, Files.localOutput(temp.newFile()), TestHelpers.Row.of(0), dataDeletes, deleteRowSchema);
+    DeleteFile eqDeletes =
+        FileHelpers.writeDeleteFile(
+            table,
+            Files.localOutput(temp.newFile()),
+            TestHelpers.Row.of(0),
+            dataDeletes,
+            deleteRowSchema);
 
-    table.newRowDelta()
-        .addDeletes(eqDeletes)
-        .commit();
+    table.newRowDelta().addDeletes(eqDeletes).commit();
 
-    // check pre-condition - that the above Delete file write - actually resulted in snapshot of type OVERWRITE
+    // check pre-condition - that the above Delete file write - actually resulted in snapshot of
+    // type OVERWRITE
     Assert.assertEquals(DataOperations.OVERWRITE, table.currentSnapshot().operation());
 
     StreamingQuery query = startStream();
@@ -391,8 +390,7 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
         "Streaming should fail with IllegalStateException, as the snapshot is not of type APPEND",
         IllegalStateException.class,
         "Cannot process overwrite snapshot",
-        () -> query.processAllAvailable()
-    );
+        () -> query.processAllAvailable());
   }
 
   @Test
@@ -402,9 +400,7 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
     appendDataAsMultipleSnapshots(expected);
 
     // this should create a snapshot with type Replace.
-    table.rewriteManifests()
-        .clusterBy(f -> 1)
-        .commit();
+    table.rewriteManifests().clusterBy(f -> 1).commit();
 
     // check pre-condition
     Assert.assertEquals(DataOperations.REPLACE, table.currentSnapshot().operation());
@@ -416,21 +412,17 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
   @Test
   public void testReadStreamWithSnapshotTypeDeleteErrorsOut() throws Exception {
-    table.updateSpec()
-        .removeField("id_bucket")
-        .addField(ref("id"))
-        .commit();
+    table.updateSpec().removeField("id_bucket").addField(ref("id")).commit();
 
     // fill table with some data
     List<List<SimpleRecord>> dataAcrossSnapshots = TEST_DATA_MULTIPLE_SNAPSHOTS;
     appendDataAsMultipleSnapshots(dataAcrossSnapshots);
 
     // this should create a snapshot with type delete.
-    table.newDelete()
-        .deleteFromRowFilter(Expressions.equal("id", 4))
-        .commit();
+    table.newDelete().deleteFromRowFilter(Expressions.equal("id", 4)).commit();
 
-    // check pre-condition - that the above delete operation on table resulted in Snapshot of Type DELETE.
+    // check pre-condition - that the above delete operation on table resulted in Snapshot of Type
+    // DELETE.
     Assert.assertEquals(DataOperations.DELETE, table.currentSnapshot().operation());
 
     StreamingQuery query = startStream();
@@ -439,27 +431,22 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
         "Streaming should fail with IllegalStateException, as the snapshot is not of type APPEND",
         IllegalStateException.class,
         "Cannot process delete snapshot",
-        () -> query.processAllAvailable()
-    );
+        () -> query.processAllAvailable());
   }
 
   @Test
   public void testReadStreamWithSnapshotTypeDeleteAndSkipDeleteOption() throws Exception {
-    table.updateSpec()
-        .removeField("id_bucket")
-        .addField(ref("id"))
-        .commit();
+    table.updateSpec().removeField("id_bucket").addField(ref("id")).commit();
 
     // fill table with some data
     List<List<SimpleRecord>> dataAcrossSnapshots = TEST_DATA_MULTIPLE_SNAPSHOTS;
     appendDataAsMultipleSnapshots(dataAcrossSnapshots);
 
     // this should create a snapshot with type delete.
-    table.newDelete()
-        .deleteFromRowFilter(Expressions.equal("id", 4))
-        .commit();
+    table.newDelete().deleteFromRowFilter(Expressions.equal("id", 4)).commit();
 
-    // check pre-condition - that the above delete operation on table resulted in Snapshot of Type DELETE.
+    // check pre-condition - that the above delete operation on table resulted in Snapshot of Type
+    // DELETE.
     Assert.assertEquals(DataOperations.DELETE, table.currentSnapshot().operation());
 
     StreamingQuery query = startStream(SparkReadOptions.STREAMING_SKIP_DELETE_SNAPSHOTS, "true");
@@ -469,21 +456,17 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
   @Test
   public void testReadStreamWithSnapshotTypeDeleteAndSkipOverwriteOption() throws Exception {
-    table.updateSpec()
-        .removeField("id_bucket")
-        .addField(ref("id"))
-        .commit();
+    table.updateSpec().removeField("id_bucket").addField(ref("id")).commit();
 
     // fill table with some data
     List<List<SimpleRecord>> dataAcrossSnapshots = TEST_DATA_MULTIPLE_SNAPSHOTS;
     appendDataAsMultipleSnapshots(dataAcrossSnapshots);
 
     // this should create a snapshot with type overwrite.
-    table.newOverwrite()
-        .overwriteByRowFilter(Expressions.greaterThan("id", 4))
-        .commit();
+    table.newOverwrite().overwriteByRowFilter(Expressions.greaterThan("id", 4)).commit();
 
-    // check pre-condition - that the above delete operation on table resulted in Snapshot of Type OVERWRITE.
+    // check pre-condition - that the above delete operation on table resulted in Snapshot of Type
+    // OVERWRITE.
     Assert.assertEquals(DataOperations.OVERWRITE, table.currentSnapshot().operation());
 
     StreamingQuery query = startStream(SparkReadOptions.STREAMING_SKIP_OVERWRITE_SNAPSHOTS, "true");
@@ -492,8 +475,8 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
   }
 
   /**
-   * appends each list as a Snapshot on the iceberg table at the given location.
-   * accepts a list of lists - each list representing data per snapshot.
+   * appends each list as a Snapshot on the iceberg table at the given location. accepts a list of
+   * lists - each list representing data per snapshot.
    */
   private void appendDataAsMultipleSnapshots(List<List<SimpleRecord>> data) {
     for (List<SimpleRecord> l : data) {
@@ -507,7 +490,8 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
   private void appendData(List<SimpleRecord> data, String format) {
     Dataset<Row> df = spark.createDataFrame(data, SimpleRecord.class);
-    df.select("id", "data").write()
+    df.select("id", "data")
+        .write()
         .format("iceberg")
         .option("write-format", format)
         .mode("append")
@@ -517,7 +501,8 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
   private static final String MEMORY_TABLE = "_stream_view_mem";
 
   private StreamingQuery startStream(Map<String, String> options) throws TimeoutException {
-    return spark.readStream()
+    return spark
+        .readStream()
         .options(options)
         .format("iceberg")
         .load(tableName)
@@ -539,9 +524,9 @@ public final class TestStructuredStreamingRead3 extends SparkCatalogTestBase {
 
   private List<SimpleRecord> rowsAvailable(StreamingQuery query) {
     query.processAllAvailable();
-    return spark.sql("select * from " + MEMORY_TABLE)
+    return spark
+        .sql("select * from " + MEMORY_TABLE)
         .as(Encoders.bean(SimpleRecord.class))
         .collectAsList();
   }
-
 }
